@@ -22,7 +22,7 @@
     Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA
 
 **
-** $Id: datatype.c,v 1.24 2002/10/23 15:05:20 le_zas Exp $
+** $Id: datatype.c,v 1.25 2004/08/27 18:32:51 ostborn Exp $
 */
 
 #include <stdio.h>
@@ -37,6 +37,8 @@
 
 /* begin of BrokenLink */
 
+extern size_t mem_mdata_type_count[M_DATA_TYPE_IPPLWATCH];
+
 int mdata_BrokenLink_to_xml(gzFile *fd, mdata *data) {
 #define WR(x,f) \
 	gzprintf(fd, "<%s>%"#f"</%s>\n", #x, data->data.brokenlink.x, #x);
@@ -65,8 +67,6 @@ int mdata_BrokenLink_free(mdata *data) {
 	if (!data) return -1;
 	if (data->type != M_DATA_TYPE_BROKENLINK) return -1;
 
-	if (data->data.brokenlink.referrer)	free(data->data.brokenlink.referrer);
-
 	return 0;
 }
 
@@ -75,7 +75,7 @@ int mdata_BrokenLink_setdata(mdata *data, const char *str, int count, int type,
 
 	assert(str);
 
-	data->key	= strdup(str);
+	data->key = str;
 	assert(data->key);
 
 	if (data->type == M_DATA_TYPE_UNSET)
@@ -86,12 +86,9 @@ int mdata_BrokenLink_setdata(mdata *data, const char *str, int count, int type,
 	data->data.brokenlink.timestamp = timestamp;
 
 
-	if (referrer) {
-		data->data.brokenlink.referrer = strdup(referrer);
-		assert(data->data.brokenlink.referrer);
-	} else {
-		data->data.brokenlink.referrer = NULL;
-	}
+	data->data.brokenlink.referrer = referrer;
+	
+	mem_mdata_type_count[data->type]++;
 
 	return 0;
 }
