@@ -22,7 +22,7 @@
     Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA
 
 **
-** $Id: datatype.c,v 1.14 2002/10/23 15:05:21 le_zas Exp $
+** $Id: datatype.c,v 1.15 2004/08/27 18:32:51 ostborn Exp $
 */
 
 #include <stdio.h>
@@ -36,6 +36,7 @@
 #include "mconfig.h"
 
 /* begin of Count */
+extern size_t mem_mdata_type_count[M_DATA_TYPE_IPPLWATCH];
 
 int mdata_Count_to_xml(gzFile *fd, mdata *data) {
 #define WR(x,f) \
@@ -58,7 +59,7 @@ int mdata_Count_free(mdata *data) {
 
 int mdata_Count_setdata(mdata *data, const char *str, int count, int type) {
 
-	data->key = strdup(str);
+	data->key = str;
 	assert(data->key);
 
 	if (data->type == M_DATA_TYPE_UNSET)
@@ -67,6 +68,8 @@ int mdata_Count_setdata(mdata *data, const char *str, int count, int type) {
 
 	data->data.count.count		= count;
 	data->data.count.grouped	= type;
+	
+	mem_mdata_type_count[data->type]++;
 
 	return 0;
 }
