@@ -22,7 +22,7 @@
     Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA
 
 **
-** $Id: datatype.c,v 1.12 2003/02/24 17:18:21 ostborn Exp $
+** $Id: datatype.c,v 1.13 2004/08/27 18:32:52 ostborn Exp $
 */
 
 #include <stdio.h>
@@ -58,7 +58,7 @@ int mdata_Match_setdata(mdata *data, const char *str, const char *match) {
 	const char *errstr;
 	int errofs;
 
-	data->key = strdup(str);
+	data->key = str;
 	assert(data->key);
 
 	data->data.match.match	= pcre_compile(match, 0, &errstr, &errofs, NULL);
