@@ -22,7 +22,7 @@
     Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA
 
 **
-** $Id: datatype.c,v 1.12 2002/10/23 15:05:23 le_zas Exp $
+** $Id: datatype.c,v 1.13 2004/08/27 18:32:53 ostborn Exp $
 */
 
 #include <stdio.h>
@@ -62,7 +62,7 @@ int mdata_Netmask_setdata(mdata *data, const char *str,
 			  unsigned long hostmask,
 			  unsigned long netmask) {
 
-	data->key = strdup(str);
+	data->key = str;
 	assert(data->key);
 
 	if (data->type == M_DATA_TYPE_UNSET)
