@@ -22,7 +22,7 @@
     Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA
 
 **
-** $Id: datatype.c,v 1.9 2002/10/23 15:05:23 le_zas Exp $
+** $Id: datatype.c,v 1.10 2004/08/27 18:32:53 ostborn Exp $
 */
 
 #include <stdio.h>
@@ -55,7 +55,7 @@ int mdata_Query_setdata(mdata *data, const char *str, adns_query *query) {
 int mdata_Query_setdata(mdata *data, const char *str, void *query) {
 #endif
 
-	data->key = strdup(str);
+	data->key = str;
 	assert(data->key);
 
 #ifdef HAVE_LIBADNS
