@@ -22,7 +22,7 @@
     Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA
 
 **
-** $Id: datatype.c,v 1.4 2003/07/18 11:39:40 ostborn Exp $
+** $Id: datatype.c,v 1.5 2004/08/27 18:32:54 ostborn Exp $
 */
 
 #include <stdio.h>
@@ -37,6 +37,7 @@
 #include "datatype.h"
 
 /* begin of String */
+extern size_t mem_mdata_type_count[M_DATA_TYPE_IPPLWATCH];
 
 int mdata_String_to_xml(gzFile *fd, mdata *data) {
 #define WR(x,f) \
@@ -62,13 +63,14 @@ int mdata_String_setdata(mdata *data, const char *str, const char *string) {
 	assert(string);
 	assert(str);
 	
-	data->key = strdup(str);
+	data->key = str;
 	assert(data->key);
 
 	if (data->type == M_DATA_TYPE_UNSET)
 		data->type		= M_DATA_TYPE_STRING;
 
 	data->data.string.string	= strdup(string);
+	mem_mdata_type_count[data->type]++;
 	return 0;
 }
 
