@@ -22,7 +22,7 @@
     Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA
 
 **
-** $Id: datatype.c,v 1.18 2002/11/06 14:18:59 ostborn Exp $
+** $Id: datatype.c,v 1.19 2004/08/27 18:32:54 ostborn Exp $
 */
 
 #include <stdio.h>
@@ -63,7 +63,7 @@ int mdata_SubList_free(mdata *data) {
 
 int mdata_SubList_setdata(mdata *data, const char *str, mlist *list, int count) {
 
-	data->key = strdup(str);
+	data->key = str;
 	assert(data->key);
 
 	data->data.sublist.sublist = list ? list : mlist_init();
@@ -122,8 +122,9 @@ int mdata_SubList_from_xml(void *user_data, int tagtype, const xmlChar *value, c
 		case M_DATA_FIELDTYPE_HASH: {
 			mhash *h = m->st[m->st_depth-2].data;
 			mdata *data = m->st[m->st_depth-1].data;
-			mlist *l;
 #if 0
+			mlist *l;
+
 			for (l = data->data.sublist.sublist; l && l->data; l = l->next) {
 				char *die = NULL;
 
