@@ -22,7 +22,7 @@
     Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA
 
 **
-** $Id: datatype.c,v 1.13 2003/01/06 11:11:43 ostborn Exp $
+** $Id: datatype.c,v 1.14 2004/08/27 18:32:54 ostborn Exp $
 */
 
 #include <stdio.h>
@@ -48,6 +48,8 @@ int mdata_Traffic_free(mdata *data) {
 	if (data->data.traffic->dst) free(data->data.traffic->dst);
 	
 	free(data->data.traffic);
+	
+	free(data->key);
 
 	return 0;
 }
@@ -65,7 +67,7 @@ int mdata_Traffic_setdata(mdata *data, const char *str,
 			  int dst_interface
 			  ) {
 
-	data->key = strdup(str);
+	data->key = str;
 	assert(data->key);
 
 	data->data.traffic->src = strdup(src);
