@@ -22,7 +22,7 @@
     Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA
 
 **
-** $Id: datatype.c,v 1.27 2003/01/06 11:11:44 ostborn Exp $
+** $Id: datatype.c,v 1.28 2004/08/27 18:32:55 ostborn Exp $
 */
 
 #include <stdio.h>
@@ -42,6 +42,7 @@
 #include "ctype.h"
 
 /* begin of Visit */
+extern size_t mem_mdata_type_count[M_DATA_TYPE_IPPLWATCH];
 
 /*
  *
@@ -94,7 +95,6 @@ int mdata_Visit_free(mdata *data) {
 	if (!data) return -1;
 	if (data->type != M_DATA_TYPE_VISIT) return -1;
 
-	if (data->data.visit->useragent) free(data->data.visit->useragent);
 	if (data->data.visit->hits) mlist_free(data->data.visit->hits);
 	
 	free(data->data.visit);
@@ -107,7 +107,7 @@ int mdata_Visit_setdata(mdata *data, const char *str,
 			int count, time_t timestamp,
 			time_t timediff, int type) {
 
-	data->key = strdup(str);
+	data->key = str;
 	assert(data->key);
 
 	if (data->type == M_DATA_TYPE_UNSET)
@@ -118,13 +118,8 @@ int mdata_Visit_setdata(mdata *data, const char *str,
 	data->data.visit->timestamp	= timestamp;
 	data->data.visit->timediff	= timediff;
 
-	if (useragent) {
-		data->data.visit->useragent = strdup(useragent);
-		assert(data->data.visit->useragent);
-	} else {
-		data->data.visit->useragent = strdup("");
-		assert(data->data.visit->useragent);
-	}
+	data->data.visit->useragent     = useragent;
+	mem_mdata_type_count[data->type]++;
 
 /*	data->data.visit->hits = mlist_init();*/
 #if 0
