@@ -22,7 +22,7 @@
     Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA
 
 **
-** $Id: datatype.c,v 1.14 2002/10/23 15:05:25 le_zas Exp $
+** $Id: datatype.c,v 1.15 2004/08/27 18:32:56 ostborn Exp $
 */
 
 #include <stdio.h>
@@ -39,6 +39,7 @@
 #include "misc.h"
 
 /* begin of Visited */
+extern size_t mem_mdata_type_count[M_DATA_TYPE_IPPLWATCH];
 
 int mdata_Visited_to_xml(gzFile *fd, mdata *data) {
 #define WR(x,f) \
@@ -70,7 +71,7 @@ int mdata_Visited_setdata(mdata *data, const char *str, int count, int type, dou
 	}
 
 
-	data->key = strdup(str);
+	data->key = str;
 	assert(data->key);
 
 	if (data->type == M_DATA_TYPE_UNSET)
@@ -79,6 +80,8 @@ int mdata_Visited_setdata(mdata *data, const char *str, int count, int type, dou
 	data->data.visited.count	= count;
 	data->data.visited.grouped	= type;
 	data->data.visited.vcount	= vcount;
+	
+	mem_mdata_type_count[data->type]++;
 
 	return 0;
 }
