@@ -22,7 +22,7 @@
     Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA
 
 **
-** $Id: datatype.c,v 1.21 2003/01/06 11:11:44 ostborn Exp $
+** $Id: datatype.c,v 1.22 2004/08/27 18:32:56 ostborn Exp $
 */
 
 #include <stdio.h>
@@ -74,7 +74,7 @@ int mdata_WebHist_setdata(mdata *data, const char *str,
 	unsigned int month, unsigned int week,
 	unsigned int days_passed, double xfersize ) {
 
-	data->key = strdup(str);
+	data->key = str;
 	assert(data->key);
 
 	if (data->type == M_DATA_TYPE_UNSET)
@@ -315,7 +315,7 @@ mdata  *mdata_WebHist_create_by_state(mstate *state) {
 			if (staweb->days[i].hits) last_day = i+1;
 		}
 	}
-	mdata_WebHist_setdata(data, buf,
+	mdata_WebHist_setdata(data, strdup(buf),
 		hits, files,
 		pages, visits,
 		hosts, state->year,
