@@ -22,7 +22,7 @@
     Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA
 
 **
-** $Id: plugin_config.c,v 1.8 2003/04/18 18:32:26 ostborn Exp $
+** $Id: plugin_config.c,v 1.9 2003/07/18 11:38:10 ostborn Exp $
 */
 
 #include <stdlib.h>
@@ -239,12 +239,44 @@ int mplugins_input_bsdftpd_dlinit(mconfig *ext_conf) {
 /* destructor */
 
 int mplugins_input_bsdftpd_dlclose(mconfig *ext_conf) {
+	int i;
 	config_input *conf = ext_conf->plugin_conf;
 
 /* clean up everything you have opened, reserved */
 	mclose(&(conf->inputfile));
+	
+	pcre_free(conf->match_bsdftpd_rmdir);
+	pcre_free(conf->match_bsdftpd_rename);
+	pcre_free(conf->match_bsdftpd_user);
+	pcre_free(conf->match_bsdftpd_delete);
+	pcre_free(conf->match_bsdftpd_get);
+	pcre_free(conf->match_bsdftpd_mkdir);
+	pcre_free(conf->match_bsdftpd_append);
+	pcre_free(conf->match_bsdftpd_put);
+	pcre_free(conf->match_bsdftpd_connection);
+	pcre_free(conf->match_bsdftpd_anonymous_login_refused);
+	pcre_free(conf->match_bsdftpd_anonymous_login_success);
+	pcre_free(conf->match_bsdftpd_syslog_timestamp);
+	pcre_free(conf->match_bsdftpd_user_login_success);
+	pcre_free(conf->match_bsdftpd_user_login_failed);
+	pcre_free(conf->match_bsdftpd_user_login_refused);
+	pcre_free(conf->match_bsdftpd_syslog_pre);
 
 	buffer_free(conf->buf);
+	
+	if (conf->inputfilename) free(conf->inputfilename);
+	
+	for (i = 0; i < conf->connection_size; i++) {
+		if (conf->connections[i] != NULL) {
+			if (conf->connections[i]->username) free(conf->connections[i]->username);
+			if (conf->connections[i]->hostname) free(conf->connections[i]->hostname);
+			if (conf->connections[i]->ip)       free(conf->connections[i]->ip);
+
+			free(conf->connections[i]);
+		}
+	}
+	
+	free(conf->connections);
 
 	free(ext_conf->plugin_conf);
 	ext_conf->plugin_conf = NULL;
