@@ -22,7 +22,7 @@
     Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA
 
 **
-** $Id: parse.c,v 1.79 2003/08/25 10:51:55 ostborn Exp $
+** $Id: parse.c,v 1.82 2004/08/27 18:38:49 ostborn Exp $
 */
 
 #define _GNU_SOURCE
@@ -153,11 +153,11 @@ int parse_useragent(mconfig *ext_conf,const char *str, mlogrec *record) {
 			
 			if (minus) {
 				if (*(conf->ua_cache[i].ua_os)) {
-					buffer_strcpy_len(recext->req_useragent, conf->ua_cache[i].ua_os, minus - conf->ua_cache[i].ua_os);
+					buffer_copy_string_len(recext->req_useragent, conf->ua_cache[i].ua_os, minus - conf->ua_cache[i].ua_os);
 				}
 				minus++;
 				if (*minus) {
-					buffer_strcpy(recext->req_useros, minus);
+					buffer_copy_string(recext->req_useros, minus);
 				}
 			}
 			
@@ -208,10 +208,10 @@ int parse_useragent(mconfig *ext_conf,const char *str, mlogrec *record) {
 			*minus++ = '\0';
 
 			if (*ua_os) {
-				buffer_strcpy(recext->req_useragent, ua_os);
+				buffer_copy_string(recext->req_useragent, ua_os);
 			}
 			if (*minus) {
-				buffer_strcpy(recext->req_useros, minus);
+				buffer_copy_string(recext->req_useros, minus);
 			}
 		} else {
 			fprintf(stderr, "%s.%d: incorrect match for %s, ';' is missing in group-string\n", __FILE__, __LINE__, ua_os);
@@ -280,20 +280,20 @@ int parse_url(mconfig *ext_conf,const char *str, mlogrec_web *record) {
 	}
 	
 	if (protocol) {
-		buffer_strcpy_len(record->req_url, uri, protocol - uri);
+		buffer_copy_string_len(record->req_url, uri, protocol - uri);
 		if ((get = memchr(uri, '?', protocol - uri))) {
-			buffer_strcpy_len(record->req_getvars, get+1, protocol - (get + 1));
+			buffer_copy_string_len(record->req_getvars, get+1, protocol - (get + 1));
 		}
 		
-		buffer_strcpy_len(record->req_protocol, protocol, protocol_end + 1 - protocol);
+		buffer_copy_string_len(record->req_protocol, protocol, protocol_end + 1 - protocol);
 	} else {
-		buffer_strcpy(record->req_url, uri);
+		buffer_copy_string(record->req_url, uri);
 		if ((get = strchr(uri, '?'))) {
-			buffer_strcpy(record->req_getvars, get+1);
+			buffer_copy_string(record->req_getvars, get+1);
 		}
 	}
 
-	buffer_strcpy_len(record->req_method, str, method_end - str);
+	buffer_copy_string_len(record->req_method, str, method_end - str);
 
 	return M_RECORD_NO_ERROR;
 
@@ -302,10 +302,10 @@ int parse_url(mconfig *ext_conf,const char *str, mlogrec_web *record) {
 int parse_referrer(mconfig *ext_conf,const char *str, mlogrec_web_extclf *record) {
 	char *get;
 	if (NULL != (get = strchr(str, '?'))) {
-		buffer_strcpy(record->ref_url, str);
-		buffer_strcpy(record->ref_getvars, get+1);
+		buffer_copy_string(record->ref_url, str);
+		buffer_copy_string(record->ref_getvars, get+1);
 	} else {
-		buffer_strcpy(record->ref_url, str);
+		buffer_copy_string(record->ref_url, str);
 	}
 
 	return 0;
@@ -355,12 +355,12 @@ int parse_record_pcre(mconfig *ext_conf, mlogrec *record, buffer *b) {
 		pcre_get_substring_list(b->ptr, ovector, n, &list);
 
 		if (is_ip(list[1])) {
-			buffer_strcpy(recweb->req_host_ip, (char *)list[1]);
+			buffer_copy_string(recweb->req_host_ip, (char *)list[1]);
 		} else {
-			buffer_strcpy(recweb->req_host_name, (char *)list[1]);
+			buffer_copy_string(recweb->req_host_name, (char *)list[1]);
 		}
 
-		buffer_strcpy(recweb->req_user, (char *)list[3]);
+		buffer_copy_string(recweb->req_user, (char *)list[3]);
 
 		switch ((ret = parse_timestamp(ext_conf, list[4], record))) {
 		case M_RECORD_NO_ERROR:
@@ -529,19 +529,19 @@ int parse_record_dynamic(mconfig *ext_conf, mlogrec *record, buffer *b) {
 		case M_CLF_FIELD_REQ_HOST:
 			if (is_ip(list[i+1])) {
 				if (!recweb->req_host_ip->used) {
-					buffer_strcpy(recweb->req_host_ip, (char *)list[i+1]);
+					buffer_copy_string(recweb->req_host_ip, (char *)list[i+1]);
 				}
 			} else {
-				buffer_strcpy(recweb->req_host_name, (char *)list[i+1]);
+				buffer_copy_string(recweb->req_host_name, (char *)list[i+1]);
 			}
 			break;
 		case M_CLF_FIELD_REMOTE_IP:
 			if (!recweb->req_host_ip->used) {
-				buffer_strcpy(recweb->req_host_ip, (char *)list[i+1]);
+				buffer_copy_string(recweb->req_host_ip, (char *)list[i+1]);
 			}
 			break;
 		case M_CLF_FIELD_USERNAME:
-			buffer_strcpy(recweb->req_user, (char *)list[i+1]);
+			buffer_copy_string(recweb->req_user, (char *)list[i+1]);
 			break;
 		case M_CLF_FIELD_STATUS:
 			recweb->req_status = strtol(list[i+1], NULL, 10);
@@ -549,14 +549,17 @@ int parse_record_dynamic(mconfig *ext_conf, mlogrec *record, buffer *b) {
 		case M_CLF_FIELD_DURATION:
 			recext->duration = strtol(list[i+1], NULL, 10);
 			break;
+		case M_CLF_FIELD_DURATION_US:
+			recext->duration = strtol(list[i+1], NULL, 10) / 1000000;
+			break;
 		case M_CLF_FIELD_BYTES_SEND:
 			recweb->xfersize = strtod(list[i+1], NULL);
 			break;
 		case M_CLF_FIELD_SERVER_PORT:
-			buffer_strcpy(recext->srv_port, (char *)list[i+1]);
+			buffer_copy_string(recext->srv_port, (char *)list[i+1]);
 			break;
 		case M_CLF_FIELD_SERVER_IP:
-			buffer_strcpy(recext->srv_host, (char *)list[i+1]);
+			buffer_copy_string(recext->srv_host, (char *)list[i+1]);
 			jlen = recext->srv_host->used;
 			for(j = 0; j < jlen; j++) {
 				recext->srv_host->ptr[j] = tolower(recext->srv_host->ptr[j]);
@@ -646,11 +649,19 @@ int mplugins_input_clf_get_next_record(mconfig *ext_conf, mlogrec *record) {
 		ret = parse_record_pcre   (ext_conf, record, conf->buf);
 	}
 	
+	if (record->timestamp < 0) {
+		fprintf(stderr, "%s.%d: %ld %s\n", 
+			__FILE__, __LINE__, 
+			record->timestamp,
+			conf->buf->ptr );
+	}
+	
 	if (ret == M_RECORD_CORRUPT) {
 		M_DEBUG1(ext_conf->debug_level, M_DEBUG_SECTION_PARSING, M_DEBUG_LEVEL_WARNINGS,
 			 "affected Record: %s\n",
 			 conf->buf->ptr
 			 );
 	}
+	
 	return ret;
 }
