@@ -2,7 +2,7 @@
 ** Modular Logfile Analyzer
 ** Copyright 2000 Jan Kneschke <jan@kneschke.de>
 **
-** Homepage: http://www.kneschke.de/projekte/modlogan
+** Homepage: http://www.modlogan.org
 **
 
     This program is free software; you can redistribute it and/or modify
@@ -22,7 +22,7 @@
     Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA
 
 **
-** $Id: plugin_config.h,v 1.1 2001/08/05 23:04:28 jk Exp $
+** $Id: plugin_config.h,v 1.5 2002/10/23 15:05:28 le_zas Exp $
 */
 #ifndef _INPUT_PLUGIN_CONFIG_H_
 #define _INPUT_PLUGIN_CONFIG_H_
@@ -30,16 +30,20 @@
 #include <stdio.h>
 #include <pcre.h>
 
+
 #include "mconfig.h"
 #include "mrecord.h"
 
+#ifdef HAVE_FLOWTOOLS
 #include "ftlib.h"
+#endif
 
 typedef struct {
 	FILE	*inputfile;
 	char	*inputfilename;
-	
+#ifdef HAVE_FLOWTOOLS
 	struct ftio ftio;
+#endif
 
 } config_input;
 
