@@ -2,7 +2,7 @@
 ** Modular Logfile Analyzer
 ** Copyright 2000 Jan Kneschke <jan@kneschke.de>
 **
-** Homepage: http://www.kneschke.de/projekte/modlogan
+** Homepage: http://www.modlogan.org
 **
 
     This program is free software; you can redistribute it and/or modify
@@ -22,7 +22,7 @@
     Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA
 
 **
-** $Id: plugin_config.h,v 1.4 2001/08/06 22:56:03 jk Exp $
+** $Id: plugin_config.h,v 1.6 2003/04/18 18:36:06 ostborn Exp $
 */
 #ifndef _INPUT_PLUGIN_CONFIG_H_
 #define _INPUT_PLUGIN_CONFIG_H_
@@ -30,13 +30,15 @@
 #include <stdio.h>
 #include <pcre.h>
 
-typedef struct {
-	FILE	*inputfile;
-	char	*inputfilename;
+#include "mconfig.h"
+#include "mrecord.h"
+#include "mio.h"
 
-	char	*buffer;
-	int	buf_len;
-	int	buf_inc;
+typedef struct {
+	char	*inputfilename;
+	
+	mfile	inputfile;
+	buffer	*buf;
 
 	pcre	*match_syslog;
 	pcre	*match_ipchains;
