@@ -22,7 +22,7 @@
     Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA
 
 **
-** $Id: parse.c,v 1.13 2003/04/18 18:37:45 ostborn Exp $
+** $Id: parse.c,v 1.14 2004/03/18 02:31:51 ostborn Exp $
 */
 
 #include <stdlib.h>
@@ -162,9 +162,9 @@ int parse_useragent(mconfig *ext_conf,const char *str, mlogrec_web_extclf *recor
 
 				*pc2 = '\0';
 				if (!record->req_useragent && find_ua(ext_conf, pc1)) {
-					buffer_strcpy(record->req_useragent, pc1);
+					buffer_copy_string(record->req_useragent, pc1);
 				} else if (!record->req_useros && find_os(ext_conf, pc1)) {
-					buffer_strcpy(record->req_useros, pc1);
+					buffer_copy_string(record->req_useros, pc1);
 				}
 				pc1 = ++pc2;
 			}
@@ -181,7 +181,7 @@ int parse_useragent(mconfig *ext_conf,const char *str, mlogrec_web_extclf *recor
 				printf("UA- unknown: %s\n", pc4);
 			}
 #endif
-			buffer_strcpy(record->req_useragent, pc1);
+			buffer_copy_string(record->req_useragent, pc1);
 
 			pc1 = pc2 = (pc3+1);
 
@@ -202,7 +202,7 @@ int parse_useragent(mconfig *ext_conf,const char *str, mlogrec_web_extclf *recor
 
 
 				if (!record->req_useros && find_os(ext_conf, pc1)) {
-					buffer_strcpy(record->req_useros, pc1);
+					buffer_copy_string(record->req_useros, pc1);
 				}
 				pc1 = ++pc2;
 			}
@@ -218,7 +218,7 @@ int parse_useragent(mconfig *ext_conf,const char *str, mlogrec_web_extclf *recor
 		}
 #endif
 	} else {
-		buffer_strcpy(record->req_useragent, str);
+		buffer_copy_string(record->req_useragent, str);
 	}
 
 	free(buf_copy);
@@ -245,10 +245,10 @@ int parse_referrer(mconfig *ext_conf,const char *str, mlogrec_web_extclf *record
 		/* everything has matched, take the different pieces and be happy :) */
 		pcre_get_substring_list(str, ovector, n, &list);
 
-		buffer_strcpy(record->ref_url, (char *)list[1]);
+		buffer_copy_string(record->ref_url, (char *)list[1]);
 
 		if (n > 3) {
-			buffer_strcpy(record->ref_getvars, (char *)list[3]);
+			buffer_copy_string(record->ref_getvars, (char *)list[3]);
 		}
 #ifdef DEBUG_INPUT
 		fprintf(stderr, "%s.%d: %s, %s\n", __FILE__, __LINE__, record->ref_url, record->ref_getvars);
@@ -402,14 +402,14 @@ int parse_msmedia_field_info(mconfig *ext_conf, const char *_buffer) {
 
 	for (i = 0; i < pos; i++) {
 		if (match_buf->used == 0) {
-			buffer_strcat(match_buf, "^");
+			buffer_append_string(match_buf, "^");
 		} else {
-			buffer_strcat(match_buf, " ");
+			buffer_append_string(match_buf, " ");
 		}
-		buffer_strcat(match_buf, def[conf->trans_fields[i]].match);
+		buffer_append_string(match_buf, def[conf->trans_fields[i]].match);
 	}
 
-	buffer_strcat(match_buf, "$");
+	buffer_append_string(match_buf, "$");
 
 	if ((conf->match_clf = pcre_compile(match_buf->ptr,
 		0, &errptr, &erroffset, NULL)) == NULL) {
@@ -546,10 +546,10 @@ int parse_record_pcre(mconfig *ext_conf, mlogrec *record, buffer *b) {
 			_time = list[i+1];
 			break;
 		case M_MSMEDIA_FIELD_CLIENT_IP:
-			buffer_strcpy(recweb->req_host_ip, (char *)list[i+1]);
+			buffer_copy_string(recweb->req_host_ip, (char *)list[i+1]);
 			break;
 		case M_MSMEDIA_FIELD_URI_STEM:
-			buffer_strcpy(recweb->req_url, (char *)list[i+1]);
+			buffer_copy_string(recweb->req_url, (char *)list[i+1]);
 			break;
 		case M_MSMEDIA_FIELD_CLIENT_STATUS:
 			recweb->req_status = strtol(list[i+1], NULL,10);
@@ -558,10 +558,10 @@ int parse_record_pcre(mconfig *ext_conf, mlogrec *record, buffer *b) {
 			recweb->xfersize = strtod(list[i+1], NULL);
 			break;
 		case M_MSMEDIA_FIELD_SERVER_IP:
-			buffer_strcpy(recext->srv_host, (char *)list[i+1]);
+			buffer_copy_string(recext->srv_host, (char *)list[i+1]);
 			break;
 		case M_MSMEDIA_FIELD_PROTOCOL:
-			buffer_strcpy(recweb->req_protocol, (char *)list[i+1]);
+			buffer_copy_string(recweb->req_protocol, (char *)list[i+1]);
 			break;
 		case M_MSMEDIA_FIELD_USER_AGENT:
 			if (parse_useragent(ext_conf, list[i+1], recext)  == -1) {
