@@ -2,7 +2,7 @@
 ** Modular Logfile Analyzer
 ** Copyright 2000 Jan Kneschke <jan@kneschke.de>
 **
-** Homepage: http://www.kneschke.de/projekte/modlogan
+** Homepage: http://www.modlogan.org
 **
 
     This program is free software; you can redistribute it and/or modify
@@ -22,17 +22,13 @@
     Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA
 
 **
-** $Id: plugin_config.h,v 1.1 2000/04/23 22:54:55 jk Exp $
+** $Id: plugin_config.h,v 1.3 2003/04/18 18:40:40 ostborn Exp $
 */
 #ifndef _INPUT_PLUGIN_CONFIG_H_
 #define _INPUT_PLUGIN_CONFIG_H_
 
-#include <stdio.h>
-#include "mlist.h"
-
-
 typedef struct {
 	int dummy;
 } config_input;
 
-#endif
\ No newline at end of file
+#endif
