@@ -22,7 +22,7 @@
     Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA
 
 **
-** $Id: parse.c,v 1.6 2003/04/18 18:40:41 ostborn Exp $
+** $Id: parse.c,v 1.7 2004/03/18 02:31:51 ostborn Exp $
 */
 
 #include <stdlib.h>
@@ -97,9 +97,9 @@ int parse_record_pcre(mconfig *ext_conf, mlogrec *record, buffer *b) {
 
 		record->timestamp = strtol(list[1], NULL, 10);
 
-		buffer_strcpy(recweb->req_user, (char *)list[3]);
+		buffer_copy_string(recweb->req_user, (char *)list[3]);
 
-		buffer_strcpy(recweb->req_host_ip, (char *)list[4]);
+		buffer_copy_string(recweb->req_host_ip, (char *)list[4]);
 
 		switch(*list[5]) {
 		case 'D':
@@ -116,7 +116,7 @@ int parse_record_pcre(mconfig *ext_conf, mlogrec *record, buffer *b) {
 
 		recftp->trans_duration = strtol(list[7], NULL,10);
 
-		buffer_strcpy(recweb->req_url, (char *)list[8]);
+		buffer_copy_string(recweb->req_url, (char *)list[8]);
 
 		free(list);
 	}
