@@ -22,7 +22,7 @@
     Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA
 
 **
-** $Id: parse.c,v 1.13 2003/04/18 18:38:14 ostborn Exp $
+** $Id: parse.c,v 1.14 2003/07/18 11:38:10 ostborn Exp $
 */
 
 #include <stdlib.h>
@@ -764,7 +764,30 @@ int mplugins_input_qmail_get_next_record(mconfig *ext_conf, mlogrec *record) {
 	if (record == NULL) return M_RECORD_HARD_ERROR;
 
 	/* fill the line buffer */
-	if (NULL == mgets(&(conf->inputfile), conf->buf)) return M_RECORD_EOF;
+	if (NULL == mgets(&(conf->inputfile), conf->buf)) {
+		/* the last record, clean up qr und ql */
+		int j;
+		for (j = 0; j < qr.maxsize; j++) {
+			if (qr.recp[j] != NULL) {
+				if (qr.recp[j]->status_text) free(qr.recp[j]->status_text);
+				if (qr.recp[j]->receipent)    free(qr.recp[j]->receipent);
+				free(qr.recp[j]);
+			}
+		}
+		
+		if (qr.recp) free(qr.recp);
+		
+		for (j = 0; j < ql.maxsize; j++) {
+			if (ql.queue[j] != NULL) {
+				if (ql.queue[j]->sender) free(ql.queue[j]->sender);
+				free(ql.queue[j]);
+			}
+		}
+		
+		if (ql.queue) free(ql.queue);
+		
+		return M_RECORD_EOF;
+	}
 	
 	ret = parse_record_pcre   (ext_conf, record, conf->buf);
 	
@@ -774,5 +797,6 @@ int mplugins_input_qmail_get_next_record(mconfig *ext_conf, mlogrec *record) {
 			 conf->buf->ptr
 			 );
 	}
+	
 	return ret;
 }
