@@ -22,7 +22,7 @@
     Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA
 
 **
-** $Id: plugin_config.c,v 1.13 2003/04/18 18:38:14 ostborn Exp $
+** $Id: plugin_config.c,v 1.14 2003/07/18 11:38:11 ostborn Exp $
 */
 
 #include <stdlib.h>
@@ -173,6 +173,8 @@ int mplugins_input_qmail_dlclose(mconfig *ext_conf) {
 	mclose(&(conf->inputfile));
 
 	pcre_free(conf->match_qmail_syslog_pre);
+	pcre_free(conf->match_qmail_tai64n_timestamp);
+	pcre_free(conf->match_qmail_external_syslog_timestamp);
 	pcre_free(conf->match_qmail_new);
 	pcre_free(conf->match_qmail_end);
 	pcre_free(conf->match_qmail_delivery);
@@ -180,8 +182,11 @@ int mplugins_input_qmail_dlclose(mconfig *ext_conf) {
 	pcre_free(conf->match_qmail_starting);
 	pcre_free(conf->match_qmail_info);
 	pcre_free(conf->match_qmail_bounce);
+	pcre_free(conf->match_qmail_triple_bounce);
 	pcre_free(conf->match_qmail_status_smtp);
 	pcre_free(conf->match_qmail_status_dsn);
+	
+	if (conf->inputfilename) free(conf->inputfilename);
 
 	buffer_free(conf->buf);
 
