@@ -22,7 +22,7 @@
     Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA
 
 **
-** $Id: parse.c,v 1.11 2003/04/18 18:40:41 ostborn Exp $
+** $Id: parse.c,v 1.12 2004/03/18 02:31:51 ostborn Exp $
 */
 
 #include <stdlib.h>
@@ -183,23 +183,23 @@ int parse_record_pcre(mconfig *ext_conf, mlogrec *record, buffer *b) {
 
 		record->timestamp = strtol(list[5], NULL, 10);
 
-		buffer_strcpy(recweb->req_url, (char *)list[4]);
+		buffer_copy_string(recweb->req_url, (char *)list[4]);
 
 		/* 21/22 */
-		buffer_strcpy(recweb->req_protocol, (char *)list[21]);
+		buffer_copy_string(recweb->req_protocol, (char *)list[21]);
 
-		buffer_strcpy(recweb->req_host_ip, (char *)list[1]);
+		buffer_copy_string(recweb->req_host_ip, (char *)list[1]);
 
 		recweb->req_status = strtol(list[8], NULL,10);
 		recweb->xfersize = strtol(list[26], NULL,10);
 
-		buffer_strcpy(recext->ref_url, (char *)list[13]);
+		buffer_copy_string(recext->ref_url, (char *)list[13]);
 
-		buffer_strcpy(recext->req_useragent, (char *)list[12]);
+		buffer_copy_string(recext->req_useragent, (char *)list[12]);
 
-		buffer_strcpy(recext->req_useros, (char *)list[15]);
+		buffer_copy_string(recext->req_useros, (char *)list[15]);
 
-		buffer_strcpy(recext->srv_host, (char *)list[40]);
+		buffer_copy_string(recext->srv_host, (char *)list[40]);
 
 		recext->duration = strtol(list[6], NULL, 10);
 
