@@ -22,7 +22,7 @@
     Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA
 
 **
-** $Id: parse.c,v 1.15 2003/04/18 18:40:42 ostborn Exp $
+** $Id: parse.c,v 1.16 2004/03/18 02:31:51 ostborn Exp $
 */
 
 #include <stdlib.h>
@@ -116,9 +116,9 @@ int parse_useragent(mconfig *ext_conf,const char *str, mlogrec_web_extclf *recor
 
 				*pc2 = '\0';
 				if (!record->req_useragent && find_ua(ext_conf, pc1)) {
-					buffer_strcpy(record->req_useragent, pc1);
+					buffer_copy_string(record->req_useragent, pc1);
 				} else if (!record->req_useros && find_os(ext_conf, pc1)) {
-					buffer_strcpy(record->req_useros, pc1);
+					buffer_copy_string(record->req_useros, pc1);
 				}
 				pc1 = ++pc2;
 			}
@@ -131,7 +131,7 @@ int parse_useragent(mconfig *ext_conf,const char *str, mlogrec_web_extclf *recor
 
 			*pc2 = '\0';
 
-			buffer_strcpy(record->req_useragent, pc1);
+			buffer_copy_string(record->req_useragent, pc1);
 
 			pc1 = pc2 = (pc3+1);
 
@@ -151,14 +151,14 @@ int parse_useragent(mconfig *ext_conf,const char *str, mlogrec_web_extclf *recor
 				*pc2 = '\0';
 
 				if (!record->req_useros && find_os(ext_conf, pc1)) {
-					buffer_strcpy(record->req_useros, pc1);
+					buffer_copy_string(record->req_useros, pc1);
 				}
 				pc1 = ++pc2;
 			}
 		}
 
 	} else {
-		buffer_strcpy(record->req_useragent, str);
+		buffer_copy_string(record->req_useragent, str);
 	}
 
 	free(buf_copy);
@@ -233,12 +233,12 @@ int parse_url(mconfig *ext_conf,const char *str, mlogrec_web *record) {
 	
 	switch (n) {
 	case 5:
-		buffer_strcpy(record->req_protocol, list[4]);
+		buffer_copy_string(record->req_protocol, list[4]);
 	case 4:
-		if (*list[3]) buffer_strcpy(record->req_getvars, list[3]);
+		if (*list[3]) buffer_copy_string(record->req_getvars, list[3]);
 	case 3:
-		buffer_strcpy(record->req_method, list[1]);
-		buffer_strcpy(record->req_url, list[2]);
+		buffer_copy_string(record->req_method, list[1]);
+		buffer_copy_string(record->req_url, list[2]);
 		
 #ifdef DEBUG_INPUT
 		for (i = 0; i < n ; i++) {
@@ -313,7 +313,7 @@ int parse_record_pcre(mconfig *ext_conf, mlogrec *record, buffer *b) {
 	   10 - statistics
 	   11-16 - currently unknown
 	*/
-		buffer_strcpy(recweb->req_host_ip, (char *)list[1]);
+		buffer_copy_string(recweb->req_host_ip, (char *)list[1]);
 
 		if (parse_timestamp(ext_conf, list[4], record) == -1) {
 			free(list);
