@@ -22,7 +22,7 @@
     Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA
 
 **
-** $Id: plugin_config.c,v 1.16 2003/04/18 18:40:42 ostborn Exp $
+** $Id: plugin_config.c,v 1.17 2003/07/18 07:23:56 ostborn Exp $
 */
 
 #include <stdlib.h>
@@ -144,15 +144,18 @@ int mplugins_input_realserver_dlinit(mconfig *ext_conf) {
 
 int mplugins_input_realserver_dlclose(mconfig *ext_conf) {
 	config_input *conf = ext_conf->plugin_conf;
-
+	
 	mclose(&(conf->inputfile));
 
 	mlist_free(conf->match_os);
 	mlist_free(conf->match_ua);
 
 	pcre_free(conf->match_clf);
+	pcre_free(conf->match_timestamp);
+	pcre_free(conf->match_url);
 
 	buffer_free(conf->buf);
+	if (conf->inputfilename) free(conf->inputfilename);
 
 	free(ext_conf->plugin_conf);
 	ext_conf->plugin_conf = NULL;
