@@ -22,7 +22,7 @@
     Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA
 
 **
-** $Id: parse.c,v 1.10 2003/04/18 18:40:43 ostborn Exp $
+** $Id: parse.c,v 1.11 2003/09/05 06:42:43 miham Exp $
 */
 
 #include <stdlib.h>
@@ -134,7 +134,7 @@ int parse_record_pcre(mconfig *ext_conf, mlogrec *record, buffer *b) {
 
 	if ((n = pcre_exec(conf->match_syslog, NULL, b->ptr, b->used - 1, 0, 0, ovector, 3 * N)) < 0) {
 		if (n == PCRE_ERROR_NOMATCH) {
-#if 0
+#if 1
 			fprintf(stderr, "%s.%d: syslog prefix doesn't match: %s\n", __FILE__, __LINE__, b->ptr);
 #endif
 			return M_RECORD_IGNORED;
@@ -197,6 +197,13 @@ int parse_record_pcre(mconfig *ext_conf, mlogrec *record, buffer *b) {
 			switch (match) {
 			case M_SENDMAIL_FROM:
 				{
+#if 0
+        printf( "MATCH_FROM\n" );
+				for (i = 1; i < n; i++) {
+					printf("%d: %s; ", i, list[i]);
+				}
+        printf("\n");
+#endif
 					mlogrec_mail * recmail = mrecord_init_mail();
 
 					record->ext_type = M_RECORD_TYPE_MAIL;
@@ -217,21 +224,34 @@ int parse_record_pcre(mconfig *ext_conf, mlogrec *record, buffer *b) {
 				/* check if all rcpt are successfull */
 				/* if yes, remove queue-id */
 #if 0
-				for (i = 0; i < n; i++) {
-					printf("%d: %s\n", i, list[i]);
+        printf( "MATCH_TO\n" );
+				for (i = 1; i < n; i++) {
+					printf("%d: %s; ", i, list[i]);
 				}
+        printf("\n");
 #endif
 				break;
 			case M_SENDMAIL_WARNING:
 			case M_SENDMAIL_NOQUEUE:
+#if 0
+        printf( (match == M_SENDMAIL_WARNING) ? "MATCH_WARNING\n" : "MATCH_NOQUEUE\n" );
+        printf( "Queue id = '%s'\n", queue_id );
+				for (i = 1; i < n; i++) {
+					printf("%d: %s; ", i, list[i]);
+				}
+        printf("\n");
+#endif
 
 				break;
 			default:
-#if 1
-				for (i = 0; i < n; i++) {
-					printf("%d: %s\n", i, list[i]);
+#if 0
+        printf( "FAILED PATTERN!\n" );
+				for (i = 1; i < n; i++) {
+					printf("%d: %s; ", i, list[i]);
 				}
+        printf("\n");
 #endif
+				break;
 			}
 			free(list);
 
