@@ -22,7 +22,7 @@
     Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA
 
 **
-** $Id: plugin_config.c,v 1.8 2003/04/18 18:40:43 ostborn Exp $
+** $Id: plugin_config.c,v 1.10 2003/09/05 06:42:43 miham Exp $
 */
 
 #include <stdlib.h>
@@ -87,7 +87,7 @@ int mplugins_input_sendmail_dlinit(mconfig *ext_conf) {
 	}
 
 	if ((conf->match_sendmail_to =
-	     pcre_compile("to=(.+?), .*dsn=(.+), stat=((Sent) \\((.+?)\\)|(Deferred): (.+)|(Service unavailable)|(queued))",
+	     pcre_compile("to=([^ ]*) .*mailer=([^,]+), .*dsn=([^,]+), stat=((Sent)|(Sent) \\((.+?)\\)|(Deferred): (.+)|(Service unavailable)|(queued))",
 			  0, &errptr, &erroffset, NULL)) == NULL) {
 
 		fprintf(stderr, "%s.%d: rexexp compilation error at %s\n", __FILE__, __LINE__, errptr);
@@ -110,6 +110,13 @@ int mplugins_input_sendmail_dlinit(mconfig *ext_conf) {
 		return -1;
 	}
 
+  if ((conf->match_sendmail_recipient = 
+       pcre_compile("<([-a-zA-Z0-9@.]+)>,", 0, &errptr, &erroffset, NULL)) == NULL) {
+
+		fprintf(stderr, "%s.%d: rexexp compilation error at %s\n", __FILE__, __LINE__, errptr);
+		return -1;
+	}
+
 	if ((conf->match_timestamp = pcre_compile(
 		"^([a-zA-Z]{3}) +([0-9]{1,2}) ([0-9]{2}):([0-9]{2}):([0-9]{2})",
 		0, &errptr, &erroffset, NULL)) == NULL) {
@@ -132,11 +139,16 @@ int mplugins_input_sendmail_dlclose(mconfig *ext_conf) {
 /* clean up everything you have opened, reserved */
 	mclose(&(conf->inputfile));
 
-	free(conf->match_sendmail_to);
-	free(conf->match_sendmail_from);
-	free(conf->match_syslog);
+	pcre_free(conf->match_sendmail_to);
+	pcre_free(conf->match_sendmail_from);
+	pcre_free(conf->match_sendmail_warning);
+	pcre_free(conf->match_sendmail_noqueue);
+	pcre_free(conf->match_timestamp);
+	pcre_free(conf->match_syslog);
 
 	buffer_free(conf->buf);
+	
+	if (conf->inputfilename) free(conf->inputfilename);
 
 	free(ext_conf->plugin_conf);
 	ext_conf->plugin_conf = NULL;
