@@ -2,7 +2,7 @@
 ** Modular Logfile Analyzer
 ** Copyright 2000 Jan Kneschke <jan@kneschke.de>
 **
-** Homepage: http://www.kneschke.de/projekte/modlogan
+** Homepage: http://www.modlogan.org
 **
 
     This program is free software; you can redistribute it and/or modify
@@ -22,24 +22,22 @@
     Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA
 
 **
-** $Id: plugin_config.h,v 1.3 2001/06/04 19:14:51 jk Exp $
+** $Id: plugin_config.h,v 1.5 2003/04/18 18:40:44 ostborn Exp $
 */
 #ifndef _INPUT_PLUGIN_CONFIG_H_
 #define _INPUT_PLUGIN_CONFIG_H_
 
-#include <stdio.h>
 #include <pcre.h>
 
 #include "mconfig.h"
 #include "mrecord.h"
+#include "mio.h"
 
 typedef struct {
-	FILE	*inputfile;
 	char	*inputfilename;
 
-	char	*buffer;
-	int	buf_len;
-	int	buf_inc;
+	mfile	inputfile;
+	buffer	*buf;
 
 	pcre	*match_skeleton;
 	pcre_extra	*match_skeleton_extra;
