@@ -22,7 +22,7 @@
     Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA
 
 **
-** $Id: parse.c,v 1.13 2003/04/18 18:40:44 ostborn Exp $
+** $Id: parse.c,v 1.14 2004/03/18 02:31:52 ostborn Exp $
 */
 
 #include <stdlib.h>
@@ -112,15 +112,15 @@ int parse_record_pcre(mconfig *ext_conf, mlogrec *record, buffer *b) {
 
 		record->timestamp = strtol(list[1], NULL, 10);
 
-		buffer_strcpy(recweb->req_host_ip, (char *)list[4]);
+		buffer_copy_string(recweb->req_host_ip, (char *)list[4]);
 
 		recweb->req_status = strtol(list[6], NULL,10);
 
 		recweb->xfersize = strtol(list[7], NULL,10);
 
-		buffer_strcpy(recweb->req_method, (char *)list[8]);
+		buffer_copy_string(recweb->req_method, (char *)list[8]);
 
-		buffer_strcpy(recweb->req_url, (char *)list[9]);
+		buffer_copy_string(recweb->req_url, (char *)list[9]);
 
 		pcre_free_substring_list(list);
 	}
