@@ -2,7 +2,7 @@
 ** Modular Logfile Analyzer
 ** Copyright 2000 Jan Kneschke <jan@kneschke.de>
 **
-** Homepage: http://www.kneschke.de/projekte/modlogan
+** Homepage: http://www.modlogan.org
 **
 
     This program is free software; you can redistribute it and/or modify
@@ -22,24 +22,23 @@
     Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA
 
 **
-** $Id: plugin_config.h,v 1.2 2001/06/04 22:11:14 jk Exp $
+** $Id: plugin_config.h,v 1.6 2003/04/18 18:40:44 ostborn Exp $
 */
 #ifndef _INPUT_PLUGIN_CONFIG_H_
 #define _INPUT_PLUGIN_CONFIG_H_
 
-#include <stdio.h>
 #include <pcre.h>
 
-#include "mlist.h"
+#include "mconfig.h"
+#include "mrecord.h"
+#include "mio.h"
 
 typedef struct {
-	FILE	*inputfile;
 	char	*inputfilename;
-	
-	char	*buffer;
-	int	buf_len;
-	int	buf_inc;
-	
+
+	mfile	inputfile;
+	buffer	*buf;
+
 	pcre	*match_squid;
 	pcre_extra	*match_squid_extra;
 } config_input;
