@@ -2,7 +2,7 @@
 ** Modular Logfile Analyzer
 ** Copyright 2000 Jan Kneschke <jan@kneschke.de>
 **
-** Homepage: http://www.kneschke.de/projekte/modlogan
+** Homepage: http://www.modlogan.org
 **
 
     This program is free software; you can redistribute it and/or modify
@@ -22,17 +22,22 @@
     Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA
 
 **
-** $Id: plugin_config.h,v 1.2 2001/06/04 22:11:14 jk Exp $
+** $Id: plugin_config.h,v 1.4 2003/04/18 18:40:45 ostborn Exp $
 */
 #ifndef _INPUT_PLUGIN_CONFIG_H_
 #define _INPUT_PLUGIN_CONFIG_H_
 
-#include <stdio.h>
 #include <pcre.h>
 
+#include "mio.h"
+#include "mconfig.h"
+#include "mrecord.h"
+
 typedef struct {
-	FILE	*inputfile;
 	char	*inputfilename;
+	
+	mfile	inputfile;
+	buffer	*buf;
 
 	char	*buffer;
 	int	buf_len;
