@@ -22,7 +22,7 @@
     Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA
 
 **
-** $Id: main.c,v 1.111 2003/08/25 10:27:37 ostborn Exp $
+** $Id: main.c,v 1.115 2004/08/27 20:07:37 ostborn Exp $
 */
 
 /**
@@ -33,8 +33,6 @@
  *
  */
 
-#include <libintl.h>
-#include <locale.h>
 #include <stdlib.h>
 #include <stdio.h>
 #include <time.h>
@@ -51,6 +49,8 @@
 
 #include "config.h"
 
+#include "gettext.h"
+
 #ifdef HAVE_GETOPT_H
 #include <getopt.h>
 #endif
@@ -82,6 +82,15 @@
 
 #define MSTATE_WRITE 1
 
+size_t mem_mhash_size = 0;
+size_t mem_mhash_count = 0;
+size_t mem_mlist_size = 0;
+size_t mem_mlist_count = 0;
+size_t mem_mdata_size = 0;
+size_t mem_mdata_count = 0;
+
+size_t mem_mdata_type_count[M_DATA_TYPE_IPPLWATCH] = { 0, };
+
 void show_version() {
 	printf("%s %s\n", PACKAGE, VERSION);
 	fflush(stdout);
@@ -157,22 +166,36 @@ int restore_internal_state (mconfig *conf, mlist *state_list) {
 			state = mstate_init();
 
 			if (mstate_read(conf, state, 0, 0, buf)) {
+				M_DEBUG0(conf->debug_level, M_DEBUG_SECTION_INIT, M_DEBUG_LEVEL_VERBOSE,
+					 "reading state failed");
+				
 				mstate_free(state);
 				state = NULL;
 			}
 		}
 
 		if (!hist || (conf->incremental && !state)) {
-			if (hist)	mlist_free(hist);
-			else fprintf(stderr, "%s.%d: reading history failed\n", __FILE__, __LINE__);
+			if (hist) {
+				mlist_free(hist);
+			} else {
+				M_DEBUG0(conf->debug_level, M_DEBUG_SECTION_INIT, M_DEBUG_LEVEL_VERBOSE,
+					 "reading history failed");
+			}
 
-			if (state)	mstate_free(state);
-			else if (conf->incremental) fprintf(stderr, "%s\n", _("Reading State file failed"));
+			if (state) {
+				mstate_free(state);
+			} else if (conf->incremental) {
+				M_DEBUG0(conf->debug_level, M_DEBUG_SECTION_INIT, M_DEBUG_LEVEL_VERBOSE,
+					 "reading state failed");
+			}
 
 			state = NULL;
 			hist = NULL;
 		} else {
-			mdata *data = mdata_State_create(buf, state, hist);
+			mdata *data;
+			const char *key = splaytree_insert(conf->strings, buf);
+			
+			data = mdata_State_create(key, state, hist);
 			mlist_insert(state_list, data);
 
 			M_DEBUG1(conf->debug_level, M_DEBUG_SECTION_INIT, M_DEBUG_LEVEL_VERBOSE,
@@ -252,6 +275,13 @@ int get_next_record (mconfig *conf, mlogrec *rec) {
 				if (func->get_next_record) {
 					if (recs[i]->record->timestamp == 0) {
 						recs[i]->rec_state = func->get_next_record(conf, recs[i]->record);
+						
+						if (recs[i]->record->timestamp < 0) {
+							fprintf(stderr, "%s.%d: %ld %ld\n", 
+								__FILE__, __LINE__, 
+								recs[i]->record->timestamp,
+								t);
+						}
 
 						last_rec_state = recs[i]->rec_state;
 
@@ -264,6 +294,11 @@ int get_next_record (mconfig *conf, mlogrec *rec) {
 						case M_RECORD_CORRUPT:
 						case M_RECORD_IGNORED:
 						case M_RECORD_HARD_ERROR:
+#if 0
+							M_DEBUG1(conf->debug_level, M_DEBUG_SECTION_PARSING, M_DEBUG_LEVEL_WARNINGS,
+								 "got %d\n",
+								 recs[i]->rec_state);
+#endif
 							return recs[i]->rec_state;
 						case M_RECORD_EOF:
 							break;
@@ -281,6 +316,13 @@ int get_next_record (mconfig *conf, mlogrec *rec) {
 					     (recs[i]->record->timestamp < t))) {  /* oldest timestamp */
 						t = recs[i]->record->timestamp; 
 						ndx = i;
+					} else {
+#if 0
+						fprintf(stderr, "%s.%d: %ld %ld %d\n", 
+							__FILE__, __LINE__, 
+							recs[i]->record->timestamp,
+							t, i);
+#endif
 					}
 				}
 			}
@@ -289,6 +331,13 @@ int get_next_record (mconfig *conf, mlogrec *rec) {
 			if (ndx != -1) {
 				mrecord_move(readahead[j]->record, recs[ndx]->record);
 				readahead[j]->rec_state = recs[ndx]->rec_state;
+				
+				if (recs[ndx]->record->timestamp < 0) {
+					fprintf(stderr, "%s.%d: %ld %ld %d\n", 
+						__FILE__, __LINE__, 
+						recs[ndx]->record->timestamp,
+						t, i);
+				}
 #if 0
 				fprintf(stderr, "%s.%d: readahead: filled slot %d, %d\n",
 					__FILE__, __LINE__,
@@ -308,7 +357,7 @@ int get_next_record (mconfig *conf, mlogrec *rec) {
 				rndx = j;
 			} else {
 #if 0
-				fprintf(stderr, "%s.%d: %d - %d\n", __FILE__, __LINE__, rt, readahead[j]->record->timestamp);
+				fprintf(stderr, "%s.%d: %ld - %ld\n", __FILE__, __LINE__, rt, readahead[j]->record->timestamp);
 #endif
 			}
 		} else {
@@ -321,7 +370,18 @@ int get_next_record (mconfig *conf, mlogrec *rec) {
 	if (rndx != -1) {
 		mrecord_move(rec, readahead[rndx]->record);
 		state = readahead[rndx]->rec_state;
+		if (state == M_RECORD_EOF) {
+			M_DEBUG1(conf->debug_level, M_DEBUG_SECTION_PARSING, M_DEBUG_LEVEL_WARNINGS,
+				 "got %d\n",
+				 state);
+		}
 	} else {
+#if 0
+		M_DEBUG0(conf->debug_level, M_DEBUG_SECTION_PARSING, M_DEBUG_LEVEL_WARNINGS,
+			 "got - not records\n");
+#endif
+		
+		
 		/* got no record, kill myself */
 		for (i = 0; i < conf->plugin_count; i++) {
 			mrecord_free(recs[i]->record);
@@ -349,7 +409,8 @@ int generate_monthly_output(mconfig *conf, mstate *state, const char *subpath) {
 
 	if (subpath) {
 		/* set the splitter */
-		mdata *data = mdata_String_create("splitby", subpath);
+		const char *key = splaytree_insert(conf->strings, "splitby");
+		mdata *data = mdata_String_create(key, subpath);
 		
 		if (data) {
 			mhash_insert_replace(conf->variables, data);
@@ -374,7 +435,8 @@ int generate_history_output(mconfig *conf, mlist *history, const char *subpath)
 	mplugin *func;
 
 	if (subpath) {
-		mdata *data = mdata_String_create("splitby", subpath);
+		const char *key = splaytree_insert(conf->strings, "splitby");
+		mdata *data = mdata_String_create(key, subpath);
 		
 		if (data) {
 			mhash_insert_replace(conf->variables, data);
@@ -574,7 +636,8 @@ int main (int argc, char **argv) {
 			break;
 #endif
 		case 'o': {
-			mdata *data = mdata_Count_create(optarg, 1, 0);
+			char *key = splaytree_insert(conf->strings, optarg);
+			mdata *data = mdata_Count_create(key, 1, 0);
 			/* add option to the config-file handling */
 			
 			mlist_insert_sorted(conf->cmdlineoptions, data);
@@ -670,7 +733,7 @@ int main (int argc, char **argv) {
 		M_DEBUG1(conf->debug_level, M_DEBUG_SECTION_INIT, M_DEBUG_LEVEL_VERBOSE,
 			 "Ignoring all records before %s", ctime(&l_stamp));
 	}
-
+	
 	M_DEBUG0(conf->debug_level, M_DEBUG_SECTION_INIT, M_DEBUG_LEVEL_NONE,
 		"NOTICE: startup - finished\n");
 
@@ -966,8 +1029,6 @@ int main (int argc, char **argv) {
 		}
 #endif
 
-		l = state_list;
-
 		for (l = state_list; l; l = l->next) {
 			mdata *data = l->data;
 			mdata *histdata = NULL;
@@ -1005,30 +1066,14 @@ int main (int argc, char **argv) {
 						 "no ext_type, but ext is set\n");
 					return -1;
 				}
-				continue;
+				break;
 			default:
 				M_DEBUG1(conf->debug_level, M_DEBUG_SECTION_MAINLOOP, M_DEBUG_LEVEL_ERRORS,
 					 "Unknown state-type: %d\n", state->ext_type);
-				return (-1);
+				return -1;
 			}
-#if 0
-			for (hl = data->data.state.history; hl; hl = hl->next) {
-				fprintf(stderr, "%s.%d: %s, %d, %d\n",
-					__FILE__, __LINE__,
-					hl->data->key, hl->data->type,
-					hl->data->data.hist.type);
-			}
-#endif
 			
 			if (histdata) mlist_insert_replace(data->data.state.history, histdata);
-#if 0
-			for (hl = data->data.state.history; hl; hl = hl->next) {
-				fprintf(stderr, "%s.%d: %s, %d, %d\n",
-					__FILE__, __LINE__,
-					hl->data->key, hl->data->type,
-					hl->data->data.hist.type);
-			}
-#endif			
 
 #if MSTATE_WRITE
 			if (!faulty && mstate_write(conf, data->data.state.state, M_STATE_WRITE_DEFAULT, *(data->key) ? data->key : NULL)) {
@@ -1046,16 +1091,23 @@ int main (int argc, char **argv) {
 			}
 #endif
 
-			/* generate reports */
-			if (!faulty && 0 != generate_monthly_output(conf, data->data.state.state, *(data->key) ? data->key : NULL)) {
-				fprintf(stderr, "%s.%d: output generation failed - no data this month?\n", __FILE__, __LINE__);
-				faulty = 1;
-			}
-
-			/* generate history */
-			if (!faulty && 0 != generate_history_output(conf, data->data.state.history, *(data->key) ? data->key : NULL)) {
-				fprintf(stderr, "%s.%d: history generation failed - going down hard\n", __FILE__, __LINE__);
-				faulty = 1;
+			if (state->ext_type != M_STATE_TYPE_UNSET) {
+				/* generate reports */
+				if (!faulty && 0 != generate_monthly_output(conf, data->data.state.state, *(data->key) ? data->key : NULL)) {
+					fprintf(stderr, "%s.%d: output generation failed for %s: no data this month?\n", 
+						__FILE__, __LINE__, data->key);
+					faulty = 1;
+				}
+				
+				/* generate history */
+				if (!faulty && 0 != generate_history_output(conf, data->data.state.history, *(data->key) ? data->key : NULL)) {
+					fprintf(stderr, "%s.%d: history generation failed for %s\n", 
+						__FILE__, __LINE__, data->key);
+					faulty = 1;
+				}
+			} else {
+				fprintf(stderr, "%s.%d: skipped monthly / history output generation for %s, no data\n", 
+						__FILE__, __LINE__, data->key);
 			}
 		}
 
@@ -1095,7 +1147,15 @@ int main (int argc, char **argv) {
 		       lines_ignored, "ignored records"
 		       );
 	}
-
+#if 0	
+	fprintf(stdout, "mhash: c: %d, s: %d\n", mem_mhash_count, mem_mhash_size);
+	fprintf(stdout, "mlist: c: %d, s: %d\n", mem_mlist_count, mem_mlist_size);
+	fprintf(stdout, "mdata: c: %d, s: %d\n", mem_mdata_count, mem_mdata_size);
+	
+	for (i = 0; i < M_DATA_TYPE_IPPLWATCH; i++) {
+		fprintf(stdout, "mdata %d: c: %d\n", i, mem_mdata_type_count[i]);
+	}
+#endif
 	mconfig_free(conf);
 	return 0;
 }
