@@ -22,13 +22,11 @@
     Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA
 
 **
-** $Id: mconfig.c,v 1.76 2003/07/31 23:56:08 ostborn Exp $
+** $Id: mconfig.c,v 1.77 2004/08/27 18:32:51 ostborn Exp $
 */
 
 #define _GNU_SOURCE
 
-#include <libintl.h>
-#include <locale.h>
 #include <stdlib.h>
 #include <stdio.h>
 #include <string.h>
@@ -145,7 +143,7 @@ int mconfig_insert_value(mconfig *ext_conf, void *dest, int type, const char *va
 #define N 20 + 1
 	int ovector[3 * N], n;
 	const char **list;
-
+	
 	switch(type) {
 	case M_CONFIG_TYPE_STRING: {
 		char *str = *(char **)(dest);
@@ -186,8 +184,9 @@ int mconfig_insert_value(mconfig *ext_conf, void *dest, int type, const char *va
 		case M_CONFIG_VALUE_APPEND: {
 			mdata *data;
 			mlist *l = *(mlist **)(dest);
+			char *key = splaytree_insert(ext_conf->strings, value);
 
-			data = mdata_Count_create(value, 1, M_DATA_STATE_PLAIN);
+			data = mdata_Count_create(key, 1, M_DATA_STATE_PLAIN);
 			mlist_insert(l, data);
 			break;
 		}
@@ -277,8 +276,9 @@ int mconfig_insert_value(mconfig *ext_conf, void *dest, int type, const char *va
 		case M_CONFIG_VALUE_APPEND: {
 			mdata *data;
 			mlist *l = *(mlist **)(dest);
+			char *key = splaytree_insert(ext_conf->strings, list[2]);
 
-			if (NULL == (data = mdata_Match_create((char *)list[1], (char *)list[2]))) {
+			if (NULL == (data = mdata_Match_create((char *)list[1], key))) {
 				return -1;
 			}
 			mlist_append(l, data);
@@ -299,7 +299,7 @@ int mconfig_insert_value(mconfig *ext_conf, void *dest, int type, const char *va
 			return -1;
 		}
 
-		free(list);
+		pcre_free_substring_list(list);
 		free(match);
 		break;
 	}
@@ -325,7 +325,7 @@ int mconfig_insert_value(mconfig *ext_conf, void *dest, int type, const char *va
 		}
 
 		pcre_get_substring_list(value, ovector, n, &list);
-
+		
 		switch(value_def) {
 		case M_CONFIG_VALUE_IGNORE:
 			fprintf(stderr,"%s.%d: ignore not supported for hiding type\n", __FILE__, __LINE__);
@@ -335,8 +335,12 @@ int mconfig_insert_value(mconfig *ext_conf, void *dest, int type, const char *va
 		case M_CONFIG_VALUE_APPEND: {
 			mdata *data;
 			mlist *l = *(mlist **)(dest);
-
-			data = mdata_Match_create((char *)list[1], "");
+			char *key;
+			
+			key = splaytree_insert(ext_conf->strings, "");
+			
+			assert(key);
+			data = mdata_Match_create(list[1], key);
 
 			mlist_append(l, data);
 			break;
@@ -353,7 +357,7 @@ int mconfig_insert_value(mconfig *ext_conf, void *dest, int type, const char *va
 			return -1;
 		}
 
-		free(list);
+		pcre_free_substring_list(list);
 		free(match);
 		break;
 	}
@@ -786,7 +790,8 @@ int mconfig_parse_section(mconfig *conf, const char *cf, const char *section, co
 
 			if (*value != '$' || (*value == '$' && *(value+1) == '$')) {
 				/* a plain string */
-				data = mdata_String_create(key, value);
+				char *dkey = splaytree_insert(conf->strings, key);
+				data = mdata_String_create(dkey, value);
 			} else {
 				/* a variable */
 				int j;
@@ -801,7 +806,8 @@ int mconfig_parse_section(mconfig *conf, const char *cf, const char *section, co
 				if (config_values[j].string) {
 					if (config_values[j].type == M_CONFIG_TYPE_STRING) {
 						if (*(char **)config_values[j].dest != NULL) {
-							data = mdata_String_create(key, *(char **)config_values[j].dest);
+							char *dkey = splaytree_insert(conf->strings, key);
+							data = mdata_String_create(dkey, *(char **)config_values[j].dest);
 						} else {
 							fprintf(stderr, "ERROR: var(%s, %s) failed because %s is empty\n",
 								key, value, value+1);
@@ -960,6 +966,7 @@ mconfig *mconfig_init() {
 #endif	
 
 	conf->cmdlineoptions = mlist_init();
+	conf->strings = splaytree_init();
 	
 	return conf;
 }
