@@ -22,7 +22,7 @@
     Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA
 
 **
-** $Id: mconfig.h,v 1.39 2003/01/04 16:16:49 ostborn Exp $
+** $Id: mconfig.h,v 1.40 2004/08/27 18:32:51 ostborn Exp $
 */
 
 #ifndef _M_CONFIG_H_
@@ -38,7 +38,7 @@
 #endif
 
 #include "mhash.h"
-
+#include "top-down-splay.h"
 #include "mdebug.h"
 
 #define M_CONFIG_TYPE_STRING		0
@@ -98,6 +98,8 @@ typedef struct {
 	/* list of plugins */
 	void *plugins;
 	int plugin_count;
+	
+	splaytree *strings;
 } mconfig;
 
 mconfig* mconfig_init();
