@@ -22,7 +22,7 @@
     Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA
 
 **
-** $Id: mdatatypes.c,v 1.68 2003/05/30 20:41:55 miham Exp $
+** $Id: mdatatypes.c,v 1.69 2004/08/27 20:07:37 ostborn Exp $
 */
 
 #include <stdio.h>
@@ -56,6 +56,10 @@
 #define M_DEBUG_SAX_ENTRY 0
 #define M_DEBUG_SAX_DISPATCH 0
 
+extern size_t mem_mdata_size;
+extern size_t mem_mdata_count;
+extern size_t mem_mdata_type_count[M_DATA_TYPE_IPPLWATCH];
+
 typedef struct {
 	int type;
 	const char *string;
@@ -136,7 +140,9 @@ int mdata_get_datatype_from_key(const char *key) {
 	}
 
 	/* if everything went well we shouldn't reach this point */
-	fprintf(stderr, "%s.%d: can't %s datatype '%s'\n", __FILE__, __LINE__, "get datatype for", key);
+	fprintf(stderr, "%s.%d: can't %s datatype '%s'\n", 
+		__FILE__, __LINE__, 
+		"get datatype for", key);
 
 	return M_DATA_TYPE_UNSET;
 }
@@ -178,7 +184,6 @@ void mdata_free(mdata *data) {
 		break;
 	}
 
-	if (data->key)	free(data->key);
 #ifdef DEBUG_DATATYPES
 	fprintf(stderr, "%s.%d: freeing ID '%d'\n", __FILE__, __LINE__, data->id);
 #endif
@@ -196,9 +201,6 @@ void mdata_free(mdata *data) {
 
 mdata *mdata_init () {
 	mdata *data;
-#if 0
-	static int id = 0;
-#endif
 	
 	data = malloc(sizeof(mdata));
 	assert(data);
@@ -207,9 +209,9 @@ mdata *mdata_init () {
 
 	data->key       = NULL;
 	data->type	= M_DATA_TYPE_UNSET;
-#if 0
-	data->id        = id++;
-#endif
+	
+	mem_mdata_count++;
+	mem_mdata_size += sizeof(mdata);
 
 	return data;
 }
@@ -252,6 +254,8 @@ int mdata_datatype_to_xml(gzFile *fd, mdata *data) {
 }
 
 mdata *mdata_datatype_init(int type) {
+	mem_mdata_type_count[type]++;
+	
 	switch (type) {
 	case M_DATA_TYPE_COUNT:      return mdata_Count_init();
 	case M_DATA_TYPE_VISITED:    return mdata_Visited_init();
@@ -310,65 +314,33 @@ int mdata_write(gzFile *fd, mdata *data) {
  */
 
 mdata_append_return mdata_append(mdata *dst, mdata *src) {
-	int ret = 0;
 	if (dst->type != src->type) return -1;
 
 	switch(src->type) {
-		case M_DATA_TYPE_COUNT:
-			ret = mdata_Count_append(dst, src);
-			break;
-		case M_DATA_TYPE_VISITED:
-			ret = mdata_Visited_append(dst, src);
-			break;
-		case M_DATA_TYPE_VISIT:
-			ret = mdata_Visit_append(dst, src);
-			break;
-		case M_DATA_TYPE_WEBHIST:
-			ret = mdata_WebHist_append(dst, src);
-			break;
-		case M_DATA_TYPE_MAILHIST:
-			ret = mdata_Mailhist_append(dst, src);
-			break;
-		case M_DATA_TYPE_RECORD:
-			ret = mdata_Record_append(dst, src);
-			break;
-		case M_DATA_TYPE_STATE:
-			ret = mdata_State_append(dst, src);
-			break;
-		case M_DATA_TYPE_MATCH:
-			ret = mdata_Match_append(dst, src);
-			break;
-		case M_DATA_TYPE_SUBLIST:
-			ret = mdata_SubList_append(dst, src);
-			break;
-		case M_DATA_TYPE_SPLIT:
-			ret = mdata_Split_append(dst, src);
-			break;
-		case M_DATA_TYPE_BROKENLINK:
-			ret = mdata_BrokenLink_append(dst, src);
-			break;
-		case M_DATA_TYPE_TRAFFIC:
-			ret = mdata_Traffic_append(dst, src);
-			break;
-		case M_DATA_TYPE_NETMASK:
-			ret = mdata_Netmask_append(dst, src);
-			break;
-		case M_DATA_TYPE_LOCATION:
-			ret = mdata_Location_append(dst, src);
-			break;
-		case M_DATA_TYPE_IPPLWATCH:
-			ret = mdata_IpplWatch_append(dst, src);
-			break;
-
-		case M_DATA_TYPE_UNSET:
-			fprintf(stderr, "%s.%d: can't %s unset datatype\n", __FILE__, __LINE__, "append");
-			break;
-		default:
-			fprintf(stderr, "%s.%d: can't %s datatype '%d'\n", __FILE__, __LINE__, "append", src->type);
-			break;
+	case M_DATA_TYPE_COUNT:     return mdata_Count_append(dst, src);
+	case M_DATA_TYPE_VISITED:   return mdata_Visited_append(dst, src);
+	case M_DATA_TYPE_VISIT:	    return mdata_Visit_append(dst, src);
+	case M_DATA_TYPE_WEBHIST:   return mdata_WebHist_append(dst, src);
+	case M_DATA_TYPE_MAILHIST:  return mdata_Mailhist_append(dst, src);
+	case M_DATA_TYPE_RECORD:    return mdata_Record_append(dst, src);
+	case M_DATA_TYPE_STATE:     return mdata_State_append(dst, src);
+	case M_DATA_TYPE_MATCH:     return mdata_Match_append(dst, src);
+	case M_DATA_TYPE_SUBLIST:   return mdata_SubList_append(dst, src);
+	case M_DATA_TYPE_SPLIT:     return mdata_Split_append(dst, src);
+	case M_DATA_TYPE_BROKENLINK:return mdata_BrokenLink_append(dst, src);
+	case M_DATA_TYPE_TRAFFIC:   return mdata_Traffic_append(dst, src);
+	case M_DATA_TYPE_NETMASK:   return mdata_Netmask_append(dst, src);
+	case M_DATA_TYPE_LOCATION:  return mdata_Location_append(dst, src);
+	case M_DATA_TYPE_IPPLWATCH: return mdata_IpplWatch_append(dst, src);
+	case M_DATA_TYPE_UNSET:
+		fprintf(stderr, "%s.%d: can't %s unset datatype\n", __FILE__, __LINE__, "append");
+		break;
+	default:
+		fprintf(stderr, "%s.%d: can't %s datatype '%d'\n", __FILE__, __LINE__, "append", src->type);
+		break;
 	}
 
-	return ret;
+	return 0;
 }
 
 /**
@@ -379,61 +351,31 @@ mdata_append_return mdata_append(mdata *dst, mdata *src) {
  */
 
 mdata *mdata_copy(mdata *src) {
-	mdata *dst = NULL;
 
 	switch(src->type) {
-		case M_DATA_TYPE_COUNT:
-			dst = mdata_Count_copy(src);
-			break;
-		case M_DATA_TYPE_VISITED:
-			dst = mdata_Visited_copy(src);
-			break;
-		case M_DATA_TYPE_WEBHIST:
-			dst = mdata_WebHist_copy(src);
-			break;
-		case M_DATA_TYPE_MAILHIST:
-			dst = mdata_Mailhist_copy(src);
-			break;
-		case M_DATA_TYPE_RECORD:
-			dst = mdata_Record_copy(src);
-			break;
-		case M_DATA_TYPE_STATE:
-			dst = mdata_State_copy(src);
-			break;
-		case M_DATA_TYPE_MATCH:
-			dst = mdata_Match_copy(src);
-			break;
-		case M_DATA_TYPE_SUBLIST:
-			dst = mdata_SubList_copy(src);
-			break;
-		case M_DATA_TYPE_SPLIT:
-			dst = mdata_Split_copy(src);
-			break;
-		case M_DATA_TYPE_BROKENLINK:
-			dst = mdata_BrokenLink_copy(src);
-			break;
-		case M_DATA_TYPE_TRAFFIC:
-			dst = mdata_Traffic_copy(src);
-			break;
-		case M_DATA_TYPE_NETMASK:
-			dst = mdata_Netmask_copy(src);
-			break;
-		case M_DATA_TYPE_IPPLWATCH:
-			dst = mdata_IpplWatch_copy(src);
-			break;
-		
-		case M_DATA_TYPE_LOCATION:
-			dst = mdata_Location_copy(src);
-			break;
-		case M_DATA_TYPE_UNSET:
-			fprintf(stderr, "%s.%d: can't %s unset datatype\n", __FILE__, __LINE__, "copy");
-			break;
-		default:
-			fprintf(stderr, "%s.%d: can't %s datatype '%d'\n", __FILE__, __LINE__, "copy", src->type);
-			break;
+	case M_DATA_TYPE_COUNT:    return mdata_Count_copy(src);
+	case M_DATA_TYPE_VISITED:  return mdata_Visited_copy(src);
+	case M_DATA_TYPE_WEBHIST:  return mdata_WebHist_copy(src);
+	case M_DATA_TYPE_MAILHIST: return mdata_Mailhist_copy(src);
+	case M_DATA_TYPE_RECORD:   return mdata_Record_copy(src);
+	case M_DATA_TYPE_STATE:    return mdata_State_copy(src);
+	case M_DATA_TYPE_MATCH:    return mdata_Match_copy(src);
+	case M_DATA_TYPE_SUBLIST:  return mdata_SubList_copy(src);
+	case M_DATA_TYPE_SPLIT:    return mdata_Split_copy(src);
+	case M_DATA_TYPE_BROKENLINK: return mdata_BrokenLink_copy(src);
+	case M_DATA_TYPE_TRAFFIC:  return mdata_Traffic_copy(src);
+	case M_DATA_TYPE_NETMASK:  return mdata_Netmask_copy(src);
+	case M_DATA_TYPE_IPPLWATCH: return mdata_IpplWatch_copy(src);
+	case M_DATA_TYPE_LOCATION: return mdata_Location_copy(src);
+	case M_DATA_TYPE_UNSET:
+		fprintf(stderr, "%s.%d: can't %s unset datatype\n", __FILE__, __LINE__, "copy");
+		break;
+	default:
+		fprintf(stderr, "%s.%d: can't %s datatype '%d'\n", __FILE__, __LINE__, "copy", src->type);
+		break;
 	}
 
-	return dst;
+	return NULL;
 }
 
 /**
@@ -454,42 +396,32 @@ int mdata_read(void *user_data, m_tag tagtype, const xmlChar *value, const xmlCh
 
 	switch(datatype) {
 	case M_DATA_TYPE_COUNT:
-		if (mdata_Count_from_xml(user_data, tagtype, value, attrs))
-			return -1;
+		if (mdata_Count_from_xml(user_data, tagtype, value, attrs)) return -1;
 		break;
 	case M_DATA_TYPE_VISITED:
-		if (mdata_Visited_from_xml(user_data, tagtype, value, attrs))
-			return -1;
+		if (mdata_Visited_from_xml(user_data, tagtype, value, attrs)) return -1;
 		break;
 	case M_DATA_TYPE_BROKENLINK:
-		if (mdata_BrokenLink_from_xml(user_data, tagtype, value, attrs))
-			return -1;
+		if (mdata_BrokenLink_from_xml(user_data, tagtype, value, attrs)) return -1;
 		break;
 	case M_DATA_TYPE_VISIT:
-		if (mdata_Visit_from_xml(user_data, tagtype, value, attrs))
-			return -1;
+		if (mdata_Visit_from_xml(user_data, tagtype, value, attrs)) return -1;
 		break;
 	case M_DATA_TYPE_WEBHIST:
-		if (mdata_WebHist_from_xml(user_data, tagtype, value, attrs))
-			return -1;
+		if (mdata_WebHist_from_xml(user_data, tagtype, value, attrs)) return -1;
 		break;
 	case M_DATA_TYPE_MAILHIST:
-		if (mdata_Mailhist_from_xml(user_data, tagtype, value, attrs))
-			return -1;
+		if (mdata_Mailhist_from_xml(user_data, tagtype, value, attrs)) return -1;
 		break;
 	case M_DATA_TYPE_SUBLIST:
-		if (mdata_SubList_from_xml(user_data, tagtype, value, attrs))
-			return -1;
+		if (mdata_SubList_from_xml(user_data, tagtype, value, attrs)) return -1;
 		break;
 	case M_DATA_TYPE_LOCATION:
-		if (mdata_Location_from_xml(user_data, tagtype, value, attrs))
-			return -1;
+		if (mdata_Location_from_xml(user_data, tagtype, value, attrs)) return -1;
 		break;
 	case M_DATA_TYPE_IPPLWATCH:
-		if (mdata_IpplWatch_from_xml(user_data, tagtype, value, attrs))
-			return -1;
+		if (mdata_IpplWatch_from_xml(user_data, tagtype, value, attrs)) return -1;
 		break;
-
 	case M_DATA_TYPE_UNSET:
 		M_DEBUG1(M_DEBUG_LEVEL_ERRORS, M_DEBUG_SECTION_INIT, M_DEBUG_LEVEL_ERRORS,
 			 "can't %s unset datatype\n",
@@ -603,9 +535,11 @@ int mdata_insert_value(void *user_data, m_tag tagtype, const xmlChar *value, con
 	mstate_stack *m = user_data;
 	int type;
 	void *dest;
+	mconfig *ext_conf;
 
 	type = m->st[m->st_depth-1].type;
 	dest = m->st[m->st_depth-1].data;
+	ext_conf = m->ext_conf;
 
 //	M_WP();
 
@@ -706,6 +640,7 @@ int mdata_insert_value(void *user_data, m_tag tagtype, const xmlChar *value, con
 		case M_DATA_FIELDTYPE_HASH: {
 			mdata *h;
 			int type;
+			char *urldec;
 
 			if (!attrs || !(0 == strcmp(attrs[0], "key"))) {
 				M_WP();
@@ -716,7 +651,11 @@ int mdata_insert_value(void *user_data, m_tag tagtype, const xmlChar *value, con
 			h = mdata_datatype_init(type);
 			assert(h);
 			
-			h->key = url_decode(attrs[1]);
+			urldec = url_decode(attrs[1]);
+			
+			h->key = splaytree_insert(ext_conf->strings, urldec);
+			
+			free(urldec);
 
 //			M_WP();
 
