@@ -22,11 +22,9 @@
     Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA
 
 **
-** $Id: mhash.c,v 1.22 2003/01/06 10:53:25 ostborn Exp $
+** $Id: mhash.c,v 1.23 2004/08/27 20:07:37 ostborn Exp $
 */
 
-#include <libintl.h>
-#include <locale.h>
 #include <stdlib.h>
 #include <stdio.h>
 #include <time.h>
@@ -41,20 +39,22 @@
 
 #define M_HASH_RESIZE_CHECK_DEFAULT 8
 
+extern size_t mem_mhash_size;
+extern size_t mem_mhash_count;
+
 int mhash_unfold(mhash *h, mlist *l ) {
 	int i = 0;
 	for ( i = 0; i < h->size; i++) {
 		if (h->data[i]->list) {
 			mlist *hl;
 
-			hl = h->data[i]->list;
-			while (hl) {
-				if (hl->data) {
-					mdata *data = mdata_copy(hl->data);
+			for (hl = h->data[i]->list; hl; hl = hl->next) {
+				mdata *data;
+				if (!hl->data) continue;
+				
+				data = mdata_copy(hl->data);
 
-					mlist_insert(l, data);
-				}
-				hl = hl->next;
+				mlist_insert(l, data);
 			}
 		}
 	}
@@ -198,14 +198,20 @@ mhash *mhash_init (int size) {
 	int i = 0;
 
 	mhash *h;
+	
+	mem_mhash_count++;
 
 	h = malloc(sizeof(mhash));
 	assert(h);
 	memset(h, 0, sizeof(mhash));
-
+	
+	mem_mhash_size += sizeof(mhash);
+	
 	h->size = size;
 	h->data = malloc(sizeof(mhash_data *) * h->size);
 	h->resize_check = M_HASH_RESIZE_CHECK_DEFAULT;
+	
+	mem_mhash_size += sizeof(mhash_data *) * h->size;
 
 	for (i = 0; i < h->size; i++) {
 		h->data[i] = malloc(sizeof(mhash_data));
@@ -213,7 +219,9 @@ mhash *mhash_init (int size) {
 		h->data[i]->list = mlist_init();
 		h->data[i]->size = 0;
 	}
-
+	
+	mem_mhash_size += sizeof(mhash_data) * h->size;
+	
 	return h;
 }
 
