@@ -22,9 +22,11 @@
     Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA
 
 **
-** $Id: mio.c,v 1.10 2003/07/18 07:23:56 ostborn Exp $
+** $Id: mio.c,v 1.13 2004/03/18 02:31:50 ostborn Exp $
 */
 
+#define _GNU_SOURCE
+
 #include <sys/types.h>
 #include <sys/stat.h>
 #include <fcntl.h>
@@ -122,10 +124,17 @@ int mopen (mfile *f, char *fn) {
 		} else {
 			struct stat st;
 			
+# ifdef O_LARGEFILE
 			if (-1 == (f->fd = open(fn, O_RDONLY))) {
 				fprintf(stderr, "%s\n", strerror(errno));
 				return -1;
 			}
+# else
+			if (-1 == (f->fd = open(fn, O_RDONLY|O_LARGEFILE))) {
+				fprintf(stderr, "%s\n", strerror(errno));
+				return -1;
+			}
+# endif
 			
 			stat(fn, &st);
 		
@@ -307,7 +316,7 @@ char *mgets (mfile *f, buffer *buf) {
 	if( e && (*e == '\n')) {
 		len = e - s;
 		
-		buffer_strcpy_len(buf, s, len);
+		buffer_copy_string_len(buf, s, len);
 			
 		/* skip the newline */
 		f->offset += len + 1;
@@ -343,6 +352,13 @@ char *mgets (mfile *f, buffer *buf) {
 					
 					s = f->ibuf->ptr;
 					len = f->ibuf->used;
+				} else if (f->access_type == MIO_MMAP) {
+					/* we only get here if the last line doesn't contain a newline
+					 * and this is illegal -> ignore it 
+					 */
+					
+					len = 0;
+					f->eof = 1;
 				}
 			} else if (f->file_type == MIO_GZIP) {
 #ifdef HAVE_LIBZ
@@ -460,14 +476,14 @@ char *mgets (mfile *f, buffer *buf) {
 
 				len = e - s;
 				
-				buffer_strcpy_len(buf, s, len);
+				buffer_copy_string_len(buf, s, len);
 				
 				/* skip the newline */
 				f->offset += len + 1;
 				
 				return buf->ptr;
 			} else if (e - s == len) {             /* last line is without a newline */
-				buffer_strcpy_len(buf, s, len);
+				buffer_copy_string_len(buf, s, len);
 				
 				f->offset += len;
 				
