@@ -22,7 +22,7 @@
     Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA
 
 **
-** $Id: misc.c,v 1.40 2003/04/18 18:20:02 ostborn Exp $
+** $Id: misc.c,v 1.41 2004/03/18 02:31:50 ostborn Exp $
 */
 
 #include <locale.h>
@@ -35,18 +35,6 @@
 
 #include "misc.h"
 #include "mlocale.h"
-/**
- * convert a hex value to a integer
- *
- * 'F' -> 15
- *
- * @param c hex caracter
- * @return the corresponding integer
- */
-
-int hex2int(unsigned char c) {
-	return (c >= '0' && c <= '9') ? c-'0' : (c|32)-'a'+10;
-}
 
 /**
  * convert URL-encoded string into a plain c-string
