@@ -22,11 +22,9 @@
     Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA
 
 **
-** $Id: mlist.c,v 1.26 2003/01/06 10:55:27 ostborn Exp $
+** $Id: mlist.c,v 1.27 2004/08/27 20:07:37 ostborn Exp $
 */
 
-#include <libintl.h>
-#include <locale.h>
 #include <stdlib.h>
 #include <stdio.h>
 #include <time.h>
@@ -38,6 +36,9 @@
 #include "mdatatypes.h"
 #include "mconfig.h"
 
+extern size_t mem_mlist_size;
+extern size_t mem_mlist_count;
+
 mlist* mlist_sort_full_by_string (mlist *l) {
 	return mlist_sort_limited_by_string(l, -1);
 }
@@ -103,7 +104,10 @@ mlist *mlist_init () {
 	l->prev = NULL;
 	l->next = NULL;
 	l->data = NULL;
-
+	
+	mem_mlist_count++;
+	mem_mlist_size += sizeof(mlist);
+	
 	return l;
 }
 
@@ -113,8 +117,6 @@ int mlist_free_entry(mlist *l) {
 
 	free(l);
 
-	l = NULL;
-
 	return 0;
 }
 
@@ -123,9 +125,7 @@ int mlist_free(mlist *l) {
 	if (!l) return 0;
 
 	/* rewind to the beginnig */
-	while (l->prev) {
-		l = l->prev;
-	}
+	for (;l->prev; l = l->prev);
 
 	/* erase the list */
 	while (l) {
@@ -133,7 +133,6 @@ int mlist_free(mlist *l) {
 		l = l->next;
 
 		mlist_free_entry(act);
-
 	}
 
 	return 0;
@@ -176,7 +175,7 @@ int mlist_insert (mlist *l, mdata *ins_data) {
 			if (mdata_append(data, ins_data) == M_DATA_APPENDED) {
 				inserted = 1;
 
-			/* the memory isn't used anymore */
+				/* the memory isn't used anymore */
 				mdata_free(ins_data);
 				ins_data = NULL;
 				break;
