@@ -22,13 +22,14 @@
     Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA
 
 **
-** $Id: mlocale.c,v 1.36 2003/01/06 10:56:13 ostborn Exp $
+** $Id: mlocale.c,v 1.38 2004/08/27 20:07:37 ostborn Exp $
 */
 
 #include <stdlib.h>
 #include <stdio.h>
 #include <string.h>
 #include <ctype.h>
+#include <locale.h>
 
 #include "mlocale.h"
 
@@ -220,6 +221,7 @@ char *misoname(const char *str) {
 /* .id */	case NDX2('i','d'):	return _("Indonesia");
 /* .ie */	case NDX2('i','e'):	return _("Ireland");
 /* .il */	case NDX2('i','l'):	return _("Israel");
+/* .im */	case NDX2('i','m'):	return _("Isle of Man");
 /* .in */	case NDX2('i','n'):	return _("India");
 /* .info */	case NDX4('i','n','f','o'):	return _("Informational (info)");
 /* .int */	case NDX3('i','n','t'):	return _("International (int)");
