@@ -22,7 +22,7 @@
     Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA
 
 **
-** $Id: mlocale.h,v 1.14 2003/01/06 10:56:13 ostborn Exp $
+** $Id: mlocale.h,v 1.15 2004/08/27 20:07:37 ostborn Exp $
 */
 
 #ifndef _M_LOCALE_H_
@@ -30,14 +30,7 @@
 
 #include "config.h"
 #include "mconfig.h"
-
-#ifdef HAVE_GETTEXT
-#include <libintl.h>
-#include <locale.h>
-#define _(String) gettext(String)
-#else
-#define _(String) String
-#endif
+#include "gettext.h"
 
 int init_locale(mconfig *conf);
 char *mhttpcodes(int status);
