@@ -22,7 +22,7 @@
     Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA
 
 **
-** $Id: mrecord.c,v 1.32 2003/07/18 11:39:16 ostborn Exp $
+** $Id: mrecord.c,v 1.33 2004/03/18 02:31:50 ostborn Exp $
 */
 
 #include <stdlib.h>
@@ -538,7 +538,7 @@ int mrecord_copy_web_extclf(mlogrec_web_extclf *dst, mlogrec_web_extclf *src) {
 	if (!src) return -1;
 
 #define FIELD_CPY(x) \
-	if (src->x->used) buffer_strcpy_len(dst->x, src->x->ptr, src->x->used);
+	if (src->x->used) buffer_copy_string_len(dst->x, src->x->ptr, src->x->used);
 
 	FIELD_CPY(ref_url);
 	FIELD_CPY(ref_getvars);
@@ -642,7 +642,7 @@ int mrecord_copy_web_ftp(mlogrec_web_ftp *dst, mlogrec_web_ftp *src) {
 	if (!src) return -1;
 
 #define FIELD_CPY(x) \
-	if (src->x->used) buffer_strcpy_len(dst->x, src->x->ptr, src->x->used);
+	if (src->x->used) buffer_copy_string_len(dst->x, src->x->ptr, src->x->used);
 
 	FIELD_CPY(req_group);
 #undef FIELD_CPY
@@ -660,7 +660,7 @@ int mrecord_copy_web(mlogrec_web *dst, mlogrec_web *src) {
 	if (!src) return -1;
 
 #define FIELD_CPY(x) \
-	if (src->x->used) buffer_strcpy_len(dst->x, src->x->ptr, src->x->used);
+	if (src->x->used) buffer_copy_string_len(dst->x, src->x->ptr, src->x->used);
 
 	FIELD_CPY(req_host_ip);
 	FIELD_CPY(req_host_name);
