@@ -22,7 +22,7 @@
     Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA
 
 **
-** $Id: mrecord.h,v 1.27 2003/04/18 18:22:46 ostborn Exp $
+** $Id: mrecord.h,v 1.31 2003/07/08 10:23:00 miham Exp $
 */
 
 #ifndef _M_RECORD_H_
@@ -70,6 +70,7 @@
 #define M_RECORD_TYPE_TRAFFIC_UNSET	0
 #define M_RECORD_TYPE_TRAFFIC_FLOW	1
 #define M_RECORD_TYPE_TRAFFIC_IPCHAINS	2
+#define	M_RECORD_TYPE_TRAFFIC_IPPL	3
 
 #define M_RECORD_TYPE_MAIL_UNSET        0
 #define M_RECORD_TYPE_MAIL_QMAIL_STATUS 1
@@ -179,7 +180,7 @@ typedef struct {
 typedef struct {
 	char 	*called_number;		/**< destination */
 	char	*calling_number;	/**< source */
-	int 	direction;		/**< incomming/outgoing call */
+	int 	direction;		/**< incoming/outgoing call */
 	time_t	duration;		/**< duration of the call */
 
 	int	ext_type;
@@ -209,7 +210,7 @@ typedef struct {
 typedef struct {
 	char *src;
 	char *dst;
-	unsigned long xfer_incomming;
+	unsigned long xfer_incoming;
 	unsigned long xfer_outgoing;
 
 	int	ext_type;
@@ -244,11 +245,47 @@ typedef struct {
 	int	rule;
 } mlogrec_traffic_ipchains;
 
+#define M_RECORD_IPPL_CONNSTATE_UNSET	0
+#define M_RECORD_IPPL_CONNATTEMPT	1
+#define M_RECORD_IPPL_CONNCLOSED	2
+
+/* actions specific to ipmon lines */
+#define M_RECORD_IPPL_PASSED            3
+#define M_RECORD_IPPL_BLOCKED           4
+#define M_RECORD_IPPL_SHORT_PACKET      5
+#define M_RECORD_IPPL_NO_MATCH          6
+#define M_RECORD_IPPL_LOG_RULE          7
+#define M_RECORD_IPPL_GLOBAL_LOGGING    8
+
+#define M_RECORD_IPPL_PROTOCOL_UNSET	0
+#define M_RECORD_IPPL_PROTOCOL_TCP	1
+#define M_RECORD_IPPL_PROTOCOL_UDP	2
+#define M_RECORD_IPPL_PROTOCOL_ICMP	4
+
+typedef struct {
+	/* For source port */
+	int	src_port;
+	/* For destination port */
+	int	dst_port;
+	/* For connection state */
+	int	conn_state;
+	/* For protocol-type */
+	int	prototype;
+	/* For IP opts */
+	int	has_ipopts;
+	/* For remote ident */
+	char*	remident;
+	/* For remote host */
+	char*	remhost;
+	/* For protocol-name */
+	char*	protoname;
+} mlogrec_traffic_ippl;
+
 typedef struct {
 	char	*receipient;		/**< (req) receipient */
 	char	*sender;		/**< (req) sender */
 	time_t	duration;		/**< (req) durection */
-	long	bytes_in;		/**< (req) traffic incomming */
+	long	bytes_in;		/**< (req) traffic incoming */
 	long	bytes_out;		/**< (req) traffic outgoing */
 
 	int status_dsn;
@@ -290,6 +327,7 @@ mlogrec_telecom_internal *mrecord_init_telecom_internal();
 mlogrec_traffic		*mrecord_init_traffic();
 mlogrec_traffic_flow	*mrecord_init_traffic_flow();
 mlogrec_traffic_ipchains *mrecord_init_traffic_ipchains();
+mlogrec_traffic_ippl    *mrecord_init_traffic_ippl();
 
 mlogrec_mail            *mrecord_init_mail();
 mlogrec_mail_qmail_status *mrecord_init_mail_qmail_status();
@@ -310,6 +348,7 @@ void mrecord_free_telecom_internal(mlogrec_telecom_internal *record);
 void mrecord_free_traffic(mlogrec_traffic *record);
 void mrecord_free_traffic_flow(mlogrec_traffic_flow *record);
 void mrecord_free_traffic_ipchains(mlogrec_traffic_ipchains *record);
+void mrecord_free_traffic_ippl(mlogrec_traffic_ippl *record);
 
 void mrecord_free_mail(mlogrec_mail * record);
 void mrecord_free_mail_qmail_status(mlogrec_mail_qmail_status * record);
