@@ -22,7 +22,7 @@
     Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA
 
 **
-** $Id: mresolver.c,v 1.9 2003/05/17 18:53:52 miham Exp $
+** $Id: mresolver.c,v 1.11 2004/08/27 18:32:51 ostborn Exp $
 */
 
 #include <sys/types.h>
@@ -73,8 +73,9 @@ const char* resolver_reverse_ip(const char *ip) {
 }
 
 int resolver_start(mconfig *conf, mlogrec *rec) {
-	mlogrec_web *recweb = NULL;
 #ifdef HAVE_LIBADNS
+	mlogrec_web *recweb = NULL;
+	
 	if (conf->enable_resolver &&
 	    rec->ext_type == M_RECORD_TYPE_WEB &&
 	    (recweb = rec->ext) != NULL && 
@@ -89,6 +90,7 @@ int resolver_start(mconfig *conf, mlogrec *rec) {
 
 			if (!mhash_in_hash(conf->query_hash, recweb->req_host_ip->ptr)) {
 				adns_query *query = malloc(sizeof(adns_query));
+				char *key;
 
 				adns_submit(*(conf->adns),
 					    conv_ip,
@@ -99,8 +101,8 @@ int resolver_start(mconfig *conf, mlogrec *rec) {
 					    );
 
 				/* put ip and query into a hash */
-
-				data = mdata_Query_create(recweb->req_host_ip->ptr, query);
+				key = splaytree_insert(conf->strings, recweb->req_host_ip->ptr);
+				data = mdata_Query_create(key, query);
 				mhash_insert_sorted(conf->query_hash, data);
 			}
 			/* don't free query !! it will be removed by mhash_free */
@@ -151,7 +153,7 @@ int resolver_finish(mconfig *conf, mlogrec *rec) {
 					fprintf(stderr, "--> %s\n", query->data.query.hostname);
 
 				if (!is_ip(query->data.query.hostname)) {
-					buffer_strcpy(recweb->req_host_name, query->data.query.hostname);
+					buffer_copy_string(recweb->req_host_name, query->data.query.hostname);
 				}
 			}
 		}
