@@ -22,7 +22,7 @@
     Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA
 
 **
-** $Id: mstate.c,v 1.66 2003/05/30 20:52:20 miham Exp $
+** $Id: mstate.c,v 1.68 2004/08/27 20:07:37 ostborn Exp $
 */
 
 #include <stdlib.h>
@@ -36,6 +36,9 @@
 #include <unistd.h>
 #include <assert.h>
 
+#undef MAX
+#undef MIN
+
 #include "config.h"
 
 #ifdef HAVE_LIBXML
@@ -65,7 +68,11 @@ mstate *mstate_init() {
 
 	state->ext		= NULL;
 	state->ext_type		= M_STATE_TYPE_UNSET;
-
+	
+	/* not in the XML file 
+	 * 
+	 * just used to reduce the mem-usage
+	 */
 	return state;
 }
 
@@ -113,6 +120,7 @@ mstate_web *mstate_init_web() {
 	state->req_meth_hash	= mhash_init( 4 );
 	state->status_hash	= mhash_init( 4 );
 	state->host_hash	= mhash_init( 4 /* 512 */ );
+	state->host_traffic	= mhash_init( 4 /* 512 */ );
 	state->ref_url_hash	= mhash_init( 4 /* 64 */ );
 	state->robots		= mhash_init( 4 );
 	state->bookmarks	= mhash_init( 4 );
@@ -127,6 +135,8 @@ mstate_web *mstate_init_web() {
 	state->vhost_hash	= mhash_init( 4 );
 	state->users     	= mhash_init( 4 );
 	state->location         = mhash_init( 4 );
+	
+	state->host_array       = marray_init();
 
 #if 0
 #define D(x) \
@@ -140,6 +150,7 @@ mstate_web *mstate_init_web() {
 	D(req_meth_hash	);
 	D(status_hash	);
 	D(host_hash	);
+	D(host_traffic	);
 	D(ref_url_hash	);
 	D(robots		);
 	D(bookmarks	);
@@ -172,6 +183,7 @@ void mstate_free_web(mstate_web *state) {
 	D(req_meth_hash	);
 	D(status_hash	);
 	D(host_hash	);
+	D(host_traffic	);
 	D(ref_url_hash	);
 	D(robots		);
 	D(bookmarks	);
@@ -187,12 +199,16 @@ void mstate_free_web(mstate_web *state) {
 	D(users	);
 #undef D
 #endif
+	
+	marray_free(state->host_array);
+	
 	mhash_free(state->os_hash);
 	mhash_free(state->ua_hash);
 	mhash_free(state->req_prot_hash);
 	mhash_free(state->req_meth_hash);
 	mhash_free(state->status_hash);
 	mhash_free(state->host_hash);
+	mhash_free(state->host_traffic);
 	mhash_free(state->req_url_hash);
 	mhash_free(state->ref_url_hash);
 	mhash_free(state->bookmarks);
@@ -210,7 +226,7 @@ void mstate_free_web(mstate_web *state) {
 	mhash_free(state->visit_hash);
 	mhash_free(state->users);
 	mhash_free(state->location);
-
+	
 	free(state);
 }
 
@@ -385,6 +401,10 @@ int mstate_write_web (mconfig *conf, mstate_web *state, gzFile *fd) {
 	gzprintf(fd, "<%s>\n", M_STATE_WEB_HOST);
 	mhash_write(fd, state->host_hash);
 	gzprintf(fd, "</%s>\n", M_STATE_WEB_HOST);
+	
+	gzprintf(fd, "<%s>\n", M_STATE_WEB_HOST_TRAFFIC);
+	mhash_write(fd, state->host_traffic);
+	gzprintf(fd, "</%s>\n", M_STATE_WEB_HOST_TRAFFIC);
 
 	gzprintf(fd, "<%s>\n", M_STATE_WEB_STATUS);
 	mhash_write(fd, state->status_hash);
@@ -743,10 +763,11 @@ int mstate_read_web (void *user_data, m_tag tagtype, const xmlChar *value, const
 		{ M_STATE_WEB_SRVHOST,      M_DATA_FIELDTYPE_HASH }, /* 22 */
 		{ M_STATE_WEB_REQ_USERS,    M_DATA_FIELDTYPE_HASH }, /* 23 */
 		{ M_STATE_WEB_LOCATION,     M_DATA_FIELDTYPE_HASH }, /* 24 */
+		{ M_STATE_WEB_HOST_TRAFFIC, M_DATA_FIELDTYPE_HASH }, /* 25 */
 		/* add new tags HERE and modify the wrap-around value in the switch() below */
 
 		/* support for old tags from 0.7.x */
-		{ "req_url",      M_DATA_FIELDTYPE_HASH }, /* 25 (wrap-around value)*/
+		{ "req_url",      M_DATA_FIELDTYPE_HASH }, /* 26 (wrap-around value)*/
 		{ "req_meth",     M_DATA_FIELDTYPE_HASH },
 		{ "req_prot",     M_DATA_FIELDTYPE_HASH },
 		{ "ref_url",      M_DATA_FIELDTYPE_HASH },
@@ -787,8 +808,8 @@ int mstate_read_web (void *user_data, m_tag tagtype, const xmlChar *value, const
 #define SET_DATA(x) \
 		m->st[m->st_depth].data = (((mstate_web *)(m->st[m->st_depth-1].data))->x);
 
-		/* wrap-around at 24 for the 0.7.x support */
-		switch (i % 25) {
+		/* wrap-around at 26 for the 0.7.x support */
+		switch (i % 26) {
 		case 0: SET_DATA(req_url_hash); break;
 		case 1: SET_DATA(req_meth_hash); break;
 		case 2: SET_DATA(req_prot_hash); break;
@@ -814,6 +835,7 @@ int mstate_read_web (void *user_data, m_tag tagtype, const xmlChar *value, const
 		case 22: SET_DATA(vhost_hash);break;
 		case 23: SET_DATA(users);break;
 		case 24: SET_DATA(location);break;
+		case 25: SET_DATA(host_traffic);break;
 		default:
 			return -1;
 		}
