@@ -22,7 +22,7 @@
     Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA
 
 **
-** $Id: generate.c,v 1.97 2003/07/31 23:55:47 ostborn Exp $
+** $Id: generate.c,v 1.100 2004/08/27 18:41:37 ostborn Exp $
 */
 
 #include <libintl.h>
@@ -53,6 +53,8 @@
 #include "pictures.h"
 #include "plugin_config.h"
 
+#include "generate.h"
+
 #define HIGHLIGHT	1
 #define GROUPING	2
 #define VISITS		4
@@ -201,7 +203,7 @@ static int show_mhash (mconfig *ext_conf, FILE *f, mhash *h, int count, int opt)
 					if (conf->assumedprotocol == NULL || strstr(data->key, "://")) {
 						fprintf(f,"<td><a href=\"%s\">%s</a></td>\n", data->key, enc_url);
 					} else {
-						fprintf(f,"<td><a href=\"%s://%s%s%s\">%s</a></td>\n", conf->assumedprotocol, conf->hostname, *data->key == '/' ? "" : "/", data->key, enc_url);
+						fprintf(f,"<td><a href=\"%s://%s%s%s\">%s</a></td>\n", conf->assumedprotocol, (conf->vhost_name->used ? conf->vhost_name->ptr : conf->hostname), *data->key == '/' ? "" : "/", data->key, enc_url);
 					}
 				} else {
 					/* added option to resolve tlds on the fly */
@@ -374,7 +376,7 @@ static int show_visit_path (mconfig *ext_conf, FILE *f, mhash *h, int count, int
 	return 0;
 }
 
-mhash *get_entry_pages(mhash *h) {
+mhash *get_entry_pages(mconfig *ext_conf, mhash *h) {
 	mhash *ret;
 	int i;
 
@@ -400,8 +402,9 @@ mhash *get_entry_pages(mhash *h) {
 
 			if (sl && sl->data) {
 				mdata *insd;
+				const char *key = splaytree_insert(ext_conf->strings, sl->data->key);
 
-				insd = mdata_Count_create(sl->data->key, l->data->data.sublist.count, M_DATA_STATE_PLAIN);
+				insd = mdata_Count_create(key, l->data->data.sublist.count, M_DATA_STATE_PLAIN);
 				mhash_insert_sorted(ret, insd);
 			}
 		}
@@ -410,7 +413,7 @@ mhash *get_entry_pages(mhash *h) {
 	return ret;
 }
 
-mhash *get_exit_pages(mhash *h) {
+mhash *get_exit_pages(mconfig *ext_conf, mhash *h) {
 	mhash *ret;
 	int i;
 
@@ -432,8 +435,9 @@ mhash *get_exit_pages(mhash *h) {
 			if (sl->data) {
 				mdata *sld = sl->data;
 				mdata *insd;
+				const char *key = splaytree_insert(ext_conf->strings, sld->key);
 				
-				insd = mdata_Count_create(sld->key, l->data->data.sublist.count, M_DATA_STATE_PLAIN);
+				insd = mdata_Count_create(key, l->data->data.sublist.count, M_DATA_STATE_PLAIN);
 				mhash_insert_sorted(ret, insd);
 			}
 		}
@@ -442,7 +446,7 @@ mhash *get_exit_pages(mhash *h) {
 	return ret;
 }
 
-mhash *get_visit_path_length(mhash *h) {
+mhash *get_visit_path_length(mconfig *ext_conf, mhash *h) {
 	mhash *ret;
 	int i;
 
@@ -458,6 +462,7 @@ mhash *get_visit_path_length(mhash *h) {
 			long c;
 			char str[255];
 			mdata *insd;
+			const char *key;
 
 			if (!l->data|| !l->data->data.sublist.sublist) continue;
 
@@ -465,8 +470,10 @@ mhash *get_visit_path_length(mhash *h) {
 			for (sl = data->data.sublist.sublist, c = 0; sl; sl = sl->next, c++);
 
 			snprintf(str, sizeof(str)-1, "%5ld", c);
+			
+			key = splaytree_insert(ext_conf->strings, str);
 
-			insd = mdata_Count_create(str, data->data.sublist.count, M_DATA_STATE_PLAIN);
+			insd = mdata_Count_create(key, data->data.sublist.count, M_DATA_STATE_PLAIN);
 			mhash_insert_sorted(ret, insd);
 		}
 	}
@@ -474,7 +481,7 @@ mhash *get_visit_path_length(mhash *h) {
 	return ret;
 }
 
-mhash *get_visit_duration(mhash *h) {
+mhash *get_visit_duration(mconfig *ext_conf, mhash *h) {
 	mhash *ret;
 	int i;
 
@@ -501,6 +508,7 @@ mhash *get_visit_duration(mhash *h) {
 
 			if (sld) {
 				time_t t1 = sld->data.brokenlink.timestamp, t2;
+				const char *key;
 
 				for (;sl->next; sl = sl->next);
 
@@ -511,8 +519,10 @@ mhash *get_visit_duration(mhash *h) {
 				} else {
 					snprintf(str, sizeof(str)-1, " < 1 %s", _("min"));
 				}
+				
+				key = splaytree_insert(ext_conf->strings, str);
 
-				insd = mdata_Count_create(str, data->data.sublist.count, M_DATA_STATE_PLAIN);
+				insd = mdata_Count_create(key, data->data.sublist.count, M_DATA_STATE_PLAIN);
 				mhash_insert_sorted(ret, insd);
 			}
 		}
@@ -607,7 +617,7 @@ double get_visit_full_duration(mhash *h) {
 	return d;
 }
 
-mhash *get_path_length(mhash *h) {
+mhash *get_path_length(mconfig *ext_conf, mhash *h) {
 	mhash *ret;
 	mlist *l;
 
@@ -619,22 +629,23 @@ mhash *get_path_length(mhash *h) {
 		if (l->data) {
 			mdata *data = l->data;
 			mlist *sl = data->data.sublist.sublist;
+			long c = 0;
+			char str[255];
+			mdata *insd;
+			const char *key;
 
-			if (sl) {
-				/* go to the last element */
-				long c = 0;
-				char str[255];
-				mdata *insd;
-				while (sl) {
-					c++;
-					sl = sl->next;
-				}
+			if (!sl) continue;
+			
+			/* go to the last element */
+				
+			for (; sl; c++, sl = sl->next);
 
-				snprintf(str, sizeof(str)-1, "%5ld", c);
+			snprintf(str, sizeof(str)-1, "%5ld", c);
+			
+			key = splaytree_insert(ext_conf->strings, str);
 
-				insd = mdata_Count_create(str, 1, M_DATA_STATE_PLAIN);
-				mhash_insert_sorted(ret, insd);
-			}
+			insd = mdata_Count_create(key, 1, M_DATA_STATE_PLAIN);
+			mhash_insert_sorted(ret, insd);
 		}
 	}
 
@@ -724,8 +735,13 @@ static void file_start(FILE *f, mconfig *ext_conf, time_t timestamp) {
 			conf->cont_charset,
 			conf->cont_language);
 
-		tmp = malloc( strlen( _("Statistics for %1$s") ) - 3 + strlen( conf->hostname ) );
-		sprintf( tmp, _("Statistics for %1$s"), conf->hostname );
+		if(conf->vhost_name->used) {
+		    tmp = malloc( strlen( _("Statistics for %1$s") ) - 3 + conf->vhost_name->used - 1 );
+		    sprintf( tmp, _("Statistics for %1$s"), conf->vhost_name->ptr );
+		} else {
+		    tmp = malloc( strlen( _("Statistics for %1$s") ) - 3 + strlen( conf->hostname ) );
+		    sprintf( tmp, _("Statistics for %1$s"), conf->hostname );
+		}
 		fprintf(f, "<h1>%s</h1>\n", tmp );
 		free(tmp);
 		if (timestamp != 0) {
@@ -810,8 +826,13 @@ static void file_start_index(FILE *f, mconfig *ext_conf, time_t timestamp) {
 			conf->cont_charset,
 			conf->cont_language);
 
-		tmp = malloc( strlen( _("Statistics for %1$s") ) - 3 + strlen( conf->hostname ) );
-		sprintf( tmp, _("Statistics for %1$s"), conf->hostname );
+		if(conf->vhost_name->used) {
+		    tmp = malloc( strlen( _("Statistics for %1$s") ) - 3 + conf->vhost_name->used - 1 );
+		    sprintf( tmp, _("Statistics for %1$s"), conf->vhost_name->ptr );
+		} else {
+		    tmp = malloc( strlen( _("Statistics for %1$s") ) - 3 + strlen( conf->hostname ) );
+		    sprintf( tmp, _("Statistics for %1$s"), conf->hostname );
+		}
 		fprintf(f, "<h1>%s</h1>\n", tmp );
 		free(tmp);
 		if (timestamp != 0) {
@@ -907,194 +928,229 @@ static int get_menu_items (mconfig *ext_conf, mstate *state, mlist *l) {
 	config_output *conf = ext_conf->plugin_conf;
 	int i = 0;
 	mstate_web *staweb = state->ext;
-
-
-	data = mdata_Count_create("/000", M_TYPE_PAGE, M_PAGE_INDEX);
+	const char *key;
+	
+	
+	key = splaytree_insert(ext_conf->strings, "/000");
+	data = mdata_Count_create(key, M_TYPE_PAGE, M_PAGE_INDEX);
 	mlist_insert(l, data);
-/* page 0 */
-	data = mdata_Count_create("/000/000", M_TYPE_PAGE, M_PAGE_000);
+	
+	/* page 0 */
+	key = splaytree_insert(ext_conf->strings, "/000/000");
+	data = mdata_Count_create(key, M_TYPE_PAGE, M_PAGE_000);
 	mlist_insert(l, data);
 
-	data = mdata_Count_create("/000/000/000", M_TYPE_REPORT, M_REPORT_SUMMARY);
+	key = splaytree_insert(ext_conf->strings, "/000/000/000");
+	data = mdata_Count_create(key, M_TYPE_REPORT, M_REPORT_SUMMARY);
 	mlist_insert(l, data);
 
-	data = mdata_Count_create("/000/000/001", M_TYPE_REPORT, M_REPORT_DAILY);
+	key = splaytree_insert(ext_conf->strings, "/000/000/001");
+	data = mdata_Count_create(key, M_TYPE_REPORT, M_REPORT_DAILY);
 	mlist_insert(l, data);
 
-	data = mdata_Count_create("/000/000/002", M_TYPE_REPORT, M_REPORT_HOURLY);
+	key = splaytree_insert(ext_conf->strings, "/000/000/002");
+	data = mdata_Count_create(key, M_TYPE_REPORT, M_REPORT_HOURLY);
 	mlist_insert(l, data);
 
 /* page 1 */
 	i = 0;
 	if (conf->max_req_urls && mhash_count(staweb->req_url_hash)) {
-		data = mdata_Count_create("/000/001/001", M_TYPE_REPORT, M_REPORT_REQ_URL);
+		key = splaytree_insert(ext_conf->strings, "/000/001/001");
+		data = mdata_Count_create(key, M_TYPE_REPORT, M_REPORT_REQ_URL);
 		mlist_insert(l, data);
 		i = 1;
 	}
 
 	if (conf->max_ref_urls && mhash_count(staweb->ref_url_hash)) {
-		data = mdata_Count_create("/000/001/002", M_TYPE_REPORT, M_REPORT_REF_URL);
+		key = splaytree_insert(ext_conf->strings, "/000/001/002");
+		data = mdata_Count_create(key, M_TYPE_REPORT, M_REPORT_REF_URL);
 		mlist_insert(l, data);
 		i = 1;
 	}
 
 	if (mhash_count(staweb->visits)) {
 		if (conf->max_entry_pages) {
-			data = mdata_Count_create("/000/001/003", M_TYPE_REPORT, M_REPORT_ENTRY_PAGES);
+			key = splaytree_insert(ext_conf->strings, "/000/001/003");
+			data = mdata_Count_create(key, M_TYPE_REPORT, M_REPORT_ENTRY_PAGES);
 			mlist_insert(l, data);
 			i = 1;
 		}
 
 		if (conf->max_exit_pages) {
-			data = mdata_Count_create("/000/001/004", M_TYPE_REPORT, M_REPORT_EXIT_PAGES);
+			key = splaytree_insert(ext_conf->strings, "/000/001/004");
+			data = mdata_Count_create(key, M_TYPE_REPORT, M_REPORT_EXIT_PAGES);
 			mlist_insert(l, data);
 			i = 1;
 		}
 
 		if (conf->max_visit_paths) {
-			data = mdata_Count_create("/000/001/005", M_TYPE_REPORT, M_REPORT_VISIT_PATH);
+			key = splaytree_insert(ext_conf->strings, "/000/001/005");
+			data = mdata_Count_create(key, M_TYPE_REPORT, M_REPORT_VISIT_PATH);
 			mlist_insert(l, data);
 			i = 1;
 		}
 
 		if (conf->max_visit_path_lengths) {
-			data = mdata_Count_create("/000/001/006", M_TYPE_REPORT, M_REPORT_VISIT_PATH_LENGTH);
+			key = splaytree_insert(ext_conf->strings, "/000/001/006");
+			data = mdata_Count_create(key, M_TYPE_REPORT, M_REPORT_VISIT_PATH_LENGTH);
 			mlist_insert(l, data);
 			i = 1;
 		}
 
 		if (conf->max_visit_durations) {
-			data = mdata_Count_create("/000/001/007", M_TYPE_REPORT, M_REPORT_VISIT_DURATION);
+			key = splaytree_insert(ext_conf->strings, "/000/001/007");
+			data = mdata_Count_create(key, M_TYPE_REPORT, M_REPORT_VISIT_DURATION);
 			mlist_insert(l, data);
 			i = 1;
 		}
 	}
 
 	if (conf->max_view_durations && mhash_count(staweb->views)) {
-		data = mdata_Count_create("/000/001/008", M_TYPE_REPORT, M_REPORT_VIEW_DURATION);
+		key = splaytree_insert(ext_conf->strings, "/000/001/008");
+		data = mdata_Count_create(key, M_TYPE_REPORT, M_REPORT_VIEW_DURATION);
 		mlist_insert(l, data);
 		i = 1;
 	}
 
 	if (conf->max_extensions && mhash_count(staweb->extension)) {
-		data = mdata_Count_create("/000/001/009", M_TYPE_REPORT, M_REPORT_EXTENSION);
+		key = splaytree_insert(ext_conf->strings, "/000/001/009");
+		data = mdata_Count_create(key, M_TYPE_REPORT, M_REPORT_EXTENSION);
 		mlist_insert(l, data);
 		i = 1;
 	}
 
 	if (conf->max_vhosts && mhash_count(staweb->vhost_hash)) {
-		data = mdata_Count_create("/000/001/010", M_TYPE_REPORT, M_REPORT_VHOSTS);
+		key = splaytree_insert(ext_conf->strings, "/000/001/010");
+		data = mdata_Count_create(key, M_TYPE_REPORT, M_REPORT_VHOSTS);
 		mlist_insert(l, data);
 		i = 1;
 	}
 
 	if (i) {
-		data = mdata_Count_create("/000/001", M_TYPE_PAGE, M_PAGE_001);
+		key = splaytree_insert(ext_conf->strings, "/000/001");
+		data = mdata_Count_create(key, M_TYPE_PAGE, M_PAGE_001);
 		mlist_insert(l, data);
 	}
 
 /* page 2 */
 	i = 0;
 	if (conf->max_os && mhash_count(staweb->os_hash)) {
-		data = mdata_Count_create("/000/002/001", M_TYPE_REPORT, M_REPORT_OS);
+		key = splaytree_insert(ext_conf->strings, "/000/002/001");
+		data = mdata_Count_create(key, M_TYPE_REPORT, M_REPORT_OS);
 		mlist_insert(l, data);
 		i = 1;
 	}
 
 	if (conf->max_hosts && mhash_count(staweb->host_hash)) {
-		data = mdata_Count_create("/000/002/002", M_TYPE_REPORT, M_REPORT_HOSTS);
+		key = splaytree_insert(ext_conf->strings, "/000/002/002");
+		data = mdata_Count_create(key, M_TYPE_REPORT, M_REPORT_HOSTS);
 		mlist_insert(l, data);
 		i = 1;
 	}
 
 	if (conf->max_ua && mhash_count(staweb->ua_hash)) {
-		data = mdata_Count_create("/000/002/003", M_TYPE_REPORT, M_REPORT_USERAGENT);
+		key = splaytree_insert(ext_conf->strings, "/000/002/003");
+		data = mdata_Count_create(key, M_TYPE_REPORT, M_REPORT_USERAGENT);
 		mlist_insert(l, data);
 		i = 1;
 	}
 
 	if (conf->max_countries && mhash_count(staweb->country_hash)) {
-		data = mdata_Count_create("/000/002/004", M_TYPE_REPORT, M_REPORT_COUNTRIES);
+		key = splaytree_insert(ext_conf->strings, "/000/002/004");
+		data = mdata_Count_create(key, M_TYPE_REPORT, M_REPORT_COUNTRIES);
 		mlist_insert(l, data);
 		i = 1;
 	}
 
 	if (i) {
-		data = mdata_Count_create("/000/002", M_TYPE_PAGE, M_PAGE_002);
+		key = splaytree_insert(ext_conf->strings, "/000/002");
+		data = mdata_Count_create(key, M_TYPE_PAGE, M_PAGE_002);
 		mlist_insert(l, data);
 	}
 /* page 3 */
 
 	i = 0;
 	if (conf->max_indexed_pages && mhash_count(staweb->indexed_pages)) {
-		data = mdata_Count_create("/000/003/001", M_TYPE_REPORT, M_REPORT_INDEXED);
+		key = splaytree_insert(ext_conf->strings, "/000/003/001");
+		data = mdata_Count_create(key, M_TYPE_REPORT, M_REPORT_INDEXED);
 		mlist_insert(l, data);
 		i = 1;
 	}
 
 	if (conf->max_robots && mhash_count(staweb->robots)) {
-		data = mdata_Count_create("/000/003/002", M_TYPE_REPORT, M_REPORT_ROBOTS);
+		key = splaytree_insert(ext_conf->strings, "/000/003/002");
+		data = mdata_Count_create(key, M_TYPE_REPORT, M_REPORT_ROBOTS);
 		mlist_insert(l, data);
 		i = 1;
 	}
 
 	if (conf->max_bookmarks && mhash_count(staweb->bookmarks)) {
-		data = mdata_Count_create("/000/003/003", M_TYPE_REPORT, M_REPORT_BOOKMARKS);
+		key = splaytree_insert(ext_conf->strings, "/000/003/003");
+		data = mdata_Count_create(key, M_TYPE_REPORT, M_REPORT_BOOKMARKS);
 		mlist_insert(l, data);
 		i = 1;
 	}
 
 	if (conf->max_search_engines && mhash_count(staweb->searchsite)) {
-		data = mdata_Count_create("/000/003/004", M_TYPE_REPORT, M_REPORT_SEARCH_ENGINE);
+		key = splaytree_insert(ext_conf->strings, "/000/003/004");
+		data = mdata_Count_create(key, M_TYPE_REPORT, M_REPORT_SEARCH_ENGINE);
 		mlist_insert(l, data);
 		i = 1;
 	}
 
 	if (conf->max_search_strings && mhash_count(staweb->searchstring)) {
-		data = mdata_Count_create("/000/003/005", M_TYPE_REPORT, M_REPORT_SEARCH_STRINGS);
+		key = splaytree_insert(ext_conf->strings, "/000/003/005");
+		data = mdata_Count_create(key, M_TYPE_REPORT, M_REPORT_SEARCH_STRINGS);
 		mlist_insert(l, data);
 		i = 1;
 	}
 
 	if (i) {
-		data = mdata_Count_create("/000/003", M_TYPE_PAGE, M_PAGE_003);
+		key = splaytree_insert(ext_conf->strings, "/000/003");
+		data = mdata_Count_create(key, M_TYPE_PAGE, M_PAGE_003);
 		mlist_insert(l, data);
 	}
 
 /* page 4 */
 	i = 0;
 	if (conf->max_req_prot && mhash_count(staweb->req_prot_hash)) {
-		data = mdata_Count_create("/000/004/001", M_TYPE_REPORT, M_REPORT_REQ_PROT);
+		key = splaytree_insert(ext_conf->strings, "/000/004/001");
+		data = mdata_Count_create(key, M_TYPE_REPORT, M_REPORT_REQ_PROT);
 		mlist_insert(l, data);
 		i = 1;
 	}
 
 	if (conf->max_req_meth && mhash_count(staweb->req_meth_hash)) {
-		data = mdata_Count_create("/000/004/002", M_TYPE_REPORT, M_REPORT_REQ_METH);
+		key = splaytree_insert(ext_conf->strings, "/000/004/002");
+		data = mdata_Count_create(key, M_TYPE_REPORT, M_REPORT_REQ_METH);
 		mlist_insert(l, data);
 		i = 1;
 	}
 
 	if (conf->max_status_codes && mhash_count(staweb->status_hash)) {
-		data = mdata_Count_create("/000/004/003", M_TYPE_REPORT, M_REPORT_STATUS_CODES);
+		key = splaytree_insert(ext_conf->strings, "/000/004/003");
+		data = mdata_Count_create(key, M_TYPE_REPORT, M_REPORT_STATUS_CODES);
 		mlist_insert(l, data);
 		i = 1;
 	}
 
 	if (conf->max_broken_links && mhash_count(staweb->status_missing_file)) {
-		data = mdata_Count_create("/000/004/004", M_TYPE_REPORT, M_REPORT_BROKEN_LINKS);
+		key = splaytree_insert(ext_conf->strings, "/000/004/004");
+		data = mdata_Count_create(key, M_TYPE_REPORT, M_REPORT_BROKEN_LINKS);
 		mlist_insert(l, data);
 		i = 1;
 	}
 
 	if (conf->max_internal_errors && mhash_count(staweb->status_internal_error)) {
-		data = mdata_Count_create("/000/004/005", M_TYPE_REPORT, M_REPORT_INTERNAL_ERROR);
+		key = splaytree_insert(ext_conf->strings, "/000/004/005");
+		data = mdata_Count_create(key, M_TYPE_REPORT, M_REPORT_INTERNAL_ERROR);
 		mlist_insert(l, data);
 		i = 1;
 	}
 
 	if (i) {
-		data = mdata_Count_create("/000/004", M_TYPE_PAGE, M_PAGE_004);
+		key = splaytree_insert(ext_conf->strings, "/000/004");
+		data = mdata_Count_create(key, M_TYPE_PAGE, M_PAGE_004);
 		mlist_insert(l, data);
 	}
 
@@ -1298,10 +1354,8 @@ static int write_menu (mconfig *ext_conf, mstate *state,FILE *f, mlist *l, char
 
 static int write_css(mconfig *ext_conf) {
 	char *filename;
-	int f;
+	int ret;
 	FILE *f2;
-	char buf[512+1];
-	int len;
 	config_output *conf = ext_conf->plugin_conf;
 
 	/* open the css file, search includepath as well */
@@ -1318,26 +1372,14 @@ static int write_css(mconfig *ext_conf) {
 	if (!filename) return -1;
 	sprintf(filename, "%s/modlogan.css", conf->outputdir);
 
-	f = open(filename, O_CREAT | O_EXCL | O_WRONLY, S_IROTH | S_IRGRP | S_IWUSR | S_IRUSR);
+	(void)unlink(filename);
+	ret = symlink(conf->cssfile, filename);
 	free(filename);
 
-	if (f != -1) {
-		if (ext_conf->debug_level > 2)
-			fprintf(stderr, "writing CSS-definition for %s\n", conf->outputdir);
-		while( (len = read(fileno(f2), buf, sizeof(buf)-1 )) != -1 ) {
-			if (len<=0) break;
-			write(f,buf,len);
-		}
-		close(f);
-	} else if (errno != EEXIST) {
+	if (ret != 0) {
 		fprintf(stderr, "writing CSS-definition for %s failed: %s\n",
 			conf->outputdir,
 			strerror(errno));
-	} else {
-		if (ext_conf->debug_level > 2)
-			fprintf(stderr, "writing CSS-definition for %s skipped: %s\n",
-				conf->outputdir,
-				strerror(errno));
 	}
 	/* Close the css source file */
 	fclose(f2);
@@ -1734,8 +1776,8 @@ static int generate_monthly_output(mconfig * ext_conf, mstate * state) {
 	reports[2].data = staweb->views;
 	reports[3].data = staweb->os_hash;
 	reports[4].data = staweb->host_hash;
-	reports[5].data = get_entry_pages(staweb->visits); /* free me */
-	reports[6].data = get_exit_pages(staweb->visits); /* free me */
+	reports[5].data = get_entry_pages(ext_conf, staweb->visits); /* free me */
+	reports[6].data = get_exit_pages(ext_conf, staweb->visits); /* free me */
 	reports[7].data = staweb->indexed_pages;
 	reports[8].data = staweb->ua_hash;
 	reports[9].data = staweb->req_prot_hash;
@@ -1747,8 +1789,8 @@ static int generate_monthly_output(mconfig * ext_conf, mstate * state) {
 	reports[15].data = staweb->searchstring;
 	reports[16].data = staweb->searchsite;
 	reports[17].data = staweb->extension;
-	reports[18].data = get_visit_duration(staweb->visits); /* free me */
-	reports[19].data = get_visit_path_length(staweb->visits); /* free me */
+	reports[18].data = get_visit_duration(ext_conf, staweb->visits); /* free me */
+	reports[19].data = get_visit_path_length(ext_conf, staweb->visits); /* free me */
 	reports[20].data = staweb->country_hash;
 	reports[21].data = staweb->vhost_hash;
 /*	reports[22].data = ;
@@ -2060,8 +2102,11 @@ static int generate_monthly_output(mconfig * ext_conf, mstate * state) {
 					_("Visits per Day"), sumdat.visits / last_day, maxdat.visits);
 				fprintf(f,"<tr><td class=\"%s\">&nbsp;</td><td>%s</td><td align=\"right\">%.0f</td><td align=\"right\">%.0f</td></tr>\n", "traffic",
 					_("Transfered Kbytes per Day"), (sumdat.xfersize / 1024) / last_day, maxdat.xfersize / 1024);
+#if 0
+				/* this value is fake, as me are not counting the host per day */
 				fprintf(f,"<tr><td class=\"%s\">&nbsp;</td><td>%s</td><td align=\"right\">%ld</td><td align=\"right\">%ld</td></tr>\n", "hosts",
 					_("Hosts per Day"), sumdat.hosts / last_day, maxdat.hosts);
+#endif
 
 				
 				fprintf(f,"<tr><td>&nbsp;</td><td>%s</td><td align=\"right\">", _("Time per visit"));
@@ -2663,6 +2708,7 @@ int mplugins_output_modlogan_generate_monthly_output(mconfig * ext_conf, mstate
 			}
 		}
 
+		buffer_copy_string(conf->vhost_name, subpath);
 		/* modify output directory */
 		free(conf->outputdir);
 		conf->outputdir = s;
