@@ -22,7 +22,7 @@
     Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA
 
 **
-** $Id: generate.h,v 1.6 2002/09/26 13:10:27 ostborn Exp $
+** $Id: generate.h,v 1.7 2004/08/27 18:41:37 ostborn Exp $
 */
 #ifndef _GENERATE_H_
 #define _GENERATE_H_
@@ -30,7 +30,7 @@
 #include "plugin_config.h"
 #include "mhash.h"
 
-mhash *get_visit_path_length(mhash *h);
-mhash *get_visit_duration(mhash *h);
+mhash *get_visit_path_length(mconfig *ext_config, mhash *h);
+mhash *get_visit_duration(mconfig *ext_config, mhash *h);
 
 #endif
