@@ -2,7 +2,7 @@
 ** Modular Logfile Analyzer
 ** Copyright 2000 Jan Kneschke <jan@kneschke.de>
 **
-** Homepage: http://www.kneschke.de/projekte/modlogan
+** Homepage: http://www.modlogan.org
 **
 
     This program is free software; you can redistribute it and/or modify
@@ -22,7 +22,7 @@
     Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA
 
 **
-** $Id: plugin_config.h,v 1.1 2001/02/10 13:45:26 jk Exp $
+** $Id: plugin_config.h,v 1.5 2002/10/23 15:05:36 le_zas Exp $
 */
 #ifndef _OUTPUT_PLUGIN_CONFIG_H_
 #define _OUTPUT_PLUGIN_CONFIG_H_
@@ -31,7 +31,12 @@
 #include "mlist.h"
 
 typedef struct {
+	char *outputdir;
 
+	void *old_conf;
 } config_output;
 
-#endif
\ No newline at end of file
+int mplugins_output_skeleton_patch_config(mconfig *ext_conf);
+int mplugins_output_skeleton_unpatch_config(mconfig *ext_conf);
+
+#endif
