@@ -22,7 +22,7 @@
     Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA
 
 **
-** $Id: generate.c,v 1.60 2003/08/01 01:25:31 ostborn Exp $
+** $Id: generate.c,v 1.64 2004/08/27 18:41:37 ostborn Exp $
 */
 
 #include <libintl.h>
@@ -102,15 +102,67 @@ char * generate_output_link (mconfig *ext_conf, int year, int month, const char
 	return fn;
 }
 
+char * generate_fulloutput_link (mconfig *ext_conf, int year, int month, const char *current) {
+	config_output *conf = ext_conf->plugin_conf;
+	tmpl_main *tmpl;
+	char date[7], *fn;
+
+	/* huge overkill, but dawm nice code */
+
+	sprintf(date, "%04d%02d",
+		year,
+		month);
+
+	if (conf->tmpl_output_link == NULL) {
+		tmpl = tmpl_init();
+		tmpl_load_string(tmpl,  conf->filename_pattern);
+		
+		conf->tmpl_output_link = tmpl;
+	} else {
+		tmpl = conf->tmpl_output_link;
+	}
+	tmpl_set_var(tmpl, "NAME", "full-");
+	tmpl_append_var(tmpl, "NAME", current);
+	tmpl_set_var(tmpl, "DATE", date);
+
+	if (tmpl_replace(tmpl, conf->tmp_buf)) {
+		tmpl_free(tmpl);
+		
+		conf->tmpl_output_link = NULL;
+		
+		return NULL;
+	}
+
+	fn = strdup(conf->tmp_buf->ptr);
+
+	return fn;
+}
+
+
 int generate_output_filename (mconfig *ext_conf, mstate *state, const char *current, buffer *output_filename) {
 	char *lnk = generate_output_link(ext_conf, state->year, state->month, current);
 	config_output *conf = ext_conf->plugin_conf;
 	
 	if (!lnk) return -1;
 
-	buffer_strcpy(output_filename, conf->outputdir);
-	buffer_strcat_len(output_filename, "/", 1);
-	buffer_strcat(output_filename, lnk);
+	buffer_copy_string(output_filename, conf->outputdir);
+	BUFFER_APPEND_SLASH(output_filename);
+	buffer_append_string(output_filename, lnk);
+	
+	free(lnk);
+
+	return 0;
+}
+
+int generate_fulloutput_filename (mconfig *ext_conf, mstate *state, const char *current, buffer *output_filename) {
+	char *lnk = generate_fulloutput_link(ext_conf, state->year, state->month, current);
+	config_output *conf = ext_conf->plugin_conf;
+	
+	if (!lnk) return -1;
+
+	buffer_copy_string(output_filename, conf->outputdir);
+	BUFFER_APPEND_SLASH(output_filename);
+	buffer_append_string(output_filename, lnk);
 	
 	free(lnk);
 
@@ -308,7 +360,7 @@ static char * generate_menu (mconfig *ext_conf, mstate *state, const char *curre
 	return s;
 }
 
-static char * generate_report (mconfig *ext_conf, mstate *state, tmpl_reports *reports,  const char *current) {
+static char * generate_report (mconfig *ext_conf, mstate *state, tmpl_reports *reports,  const char *current, int max) {
 	char *s = NULL;
 	int i;
 
@@ -327,7 +379,7 @@ static char * generate_report (mconfig *ext_conf, mstate *state, tmpl_reports *r
 	}
 
 	if (reports[i].func != NULL) {
-		if ((s = reports[i].func(ext_conf, state, current, 30 /* max-value */)) == NULL) {
+		if ((s = reports[i].func(ext_conf, state, current, max)) == NULL) {
 			M_DEBUG1(ext_conf->debug_level, M_DEBUG_SECTION_PARSING, M_DEBUG_LEVEL_ERRORS,
 				 "no chance for %s\n", current);
 		}
@@ -379,7 +431,7 @@ static int generate_monthly_output(mconfig *ext_conf, mstate *state) {
 		{ "GENERATEDAT", NULL }, /* hard coded to 1 */
 
 		/* hard values */
-		{ "MLA_URL", "http://www.modlogan.org" },
+		{ "MLA_URL", "http://www.modlogan.org/" },
 		{ "MLA_PACKAGE", PACKAGE },
 		{ "MLA_VERSION", VERSION },
 
@@ -579,7 +631,7 @@ static int generate_monthly_output(mconfig *ext_conf, mstate *state) {
 				} else if (0 == strcmp("REPORT", vars[i].key)) {
 					MTIMER_START(timer[10]);
 					
-					if ((s = generate_report(ext_conf, state, conf->avail_reports, l->data->key)) == NULL) {
+					if ((s = generate_report(ext_conf, state, conf->avail_reports, l->data->key, 30)) == NULL) {
 						M_DEBUG1(ext_conf->debug_level, M_DEBUG_SECTION_PARSING, M_DEBUG_LEVEL_ERRORS,
 							 "generating %s failed\n",
 							 vars[i].key);
@@ -677,6 +729,168 @@ static int generate_monthly_output(mconfig *ext_conf, mstate *state) {
 		MTIMER_STOP(timer[8]);
 		MTIMER_CALC(timer[8]);
 	}
+	
+	/* generate full reports */
+	for (l = conf->reports; conf->generate_full_reports && l && l->data; l = l->next) {
+		MTIMER_START(timer[7]);
+		
+		for (i = 0; conf->avail_reports[i].key; i++) {
+			if (0 == strcmp(conf->avail_reports[i].key, l->data->key)) {
+				break;
+			}
+		}
+
+		if (conf->avail_reports[i].key == NULL) {
+			/* report is unknown */
+			M_DEBUG1(ext_conf->debug_level, M_DEBUG_SECTION_PARSING, M_DEBUG_LEVEL_WARNINGS,
+					 "report-type '%s' is unknown - skipped\n",
+					 l->data->key);
+			continue;
+		}
+
+		/* set template variables */
+		for (i = 0; vars[i].key; i++) {
+			if (i != 0 && i != 1 && /* ignore GENERATEDAT and LASTRECORD as they are already set */
+			    vars[i].subst != NULL) {
+				if (0 != tmpl_set_var(tmpl, vars[i].key, vars[i].subst)) {
+#if 0
+					M_DEBUG1(ext_conf->debug_level, M_DEBUG_SECTION_PARSING, M_DEBUG_LEVEL_WARNINGS,
+						 "looks like {%s} isn't in the template\n",
+						 vars[i].key);
+#endif
+				} else {
+					/* everything ok */
+				}
+			} else if (vars[i].subst == NULL) {
+				/* perhaps this variable is handled by a function */
+				char *s = NULL;
+
+				if (0 == strcmp("TITLE", vars[i].key)) {
+					/* set the current title, from menu */
+					/* first search the report in the current menu tree */
+					
+					if ( (menunode = mtree_search(conf->menu, l->data->key)) ) {
+						tmpl_set_var(tmpl, vars[i].key, menunode->data->data.string.string);
+					} else {
+						/* no menu entry found for this report !? ... whatever */
+						tmpl_set_var(tmpl, vars[i].key, "Whatever...");
+					}
+				} else if (0 == strcmp("MENU", vars[i].key)) {
+					MTIMER_START(timer[9]);
+					
+					if ((s = generate_menu(ext_conf, state, l->data->key)) == NULL) {
+						M_DEBUG1(ext_conf->debug_level, M_DEBUG_SECTION_PARSING, M_DEBUG_LEVEL_ERRORS,
+							 "generating %s failed\n",
+							 vars[i].key);
+
+						return -1;
+					} else {
+						tmpl_set_var(tmpl, vars[i].key, s);
+						free(s);
+					}
+					MTIMER_STOP(timer[9]);
+					MTIMER_CALC(timer[9]);
+				} else if (0 == strcmp("REPORT", vars[i].key)) {
+					MTIMER_START(timer[10]);
+					
+					if ((s = generate_report(ext_conf, state, conf->avail_reports, l->data->key, -1)) == NULL) {
+						M_DEBUG1(ext_conf->debug_level, M_DEBUG_SECTION_PARSING, M_DEBUG_LEVEL_ERRORS,
+							 "generating %s failed\n",
+							 vars[i].key);
+
+						return -1;
+					} else {
+						tmpl_set_var(tmpl, vars[i].key, s);
+
+						free(s);
+					}
+					MTIMER_STOP(timer[10]);
+					MTIMER_CALC(timer[10]);
+				} else if (0 == strcmp("LNK_CURRENT", vars[i].key)) {
+					char *fn;
+					MTIMER_START(timer[11]);
+					
+					fn = generate_output_link(ext_conf, state->year, state->month, l->data->key);
+
+					tmpl_set_var(tmpl, vars[i].key, fn);
+					free(fn);
+					MTIMER_STOP(timer[11]);
+					MTIMER_CALC(timer[11]);
+				} else if (0 == strcmp("LNK_PREV", vars[i].key)) {
+					/* locate entry */
+					MTIMER_START(timer[12]);
+					
+					for (j = 0; j < cnt; j++) {
+						if (0 == strcmp(l->data->key, d[j]->key))
+							break;
+					}
+
+					/* found */
+					if (j != cnt && j > 0) {
+						fn= generate_output_link(ext_conf, state->year, state->month, d[j-1]->key);
+						tmpl_set_var(tmpl, vars[i].key, fn);
+						free(fn);
+					} else {
+						tmpl_set_var(tmpl, vars[i].key, conf->index_filename);
+					}
+					MTIMER_STOP(timer[12]);
+					MTIMER_CALC(timer[12]);
+				} else if (0 == strcmp("LNK_NEXT", vars[i].key)) {
+					/* locate entry */
+					MTIMER_START(timer[13]);
+					
+					for (j = 0; j < cnt; j++) {
+						if (0 == strcmp(l->data->key, d[j]->key))
+							break;
+					}
+
+					/* found */
+					if (j != cnt && j < cnt - 1) {
+						fn= generate_output_link(ext_conf, state->year, state->month, d[j+1]->key);
+						tmpl_set_var(tmpl, vars[i].key, fn);
+						free(fn);
+					} else {
+						tmpl_set_var(tmpl, vars[i].key, conf->index_filename);
+					}
+					MTIMER_STOP(timer[13]);
+					MTIMER_CALC(timer[13]);
+				}
+			}
+		}
+
+		MTIMER_STOP(timer[7]);
+		MTIMER_CALC(timer[7]);
+
+		MTIMER_START(timer[8]);
+
+		/* replace tags by the actual output */
+		if (0 == tmpl_replace(tmpl, conf->tmp_output)) {
+			/* index-file */
+			int fd;
+			
+			if (-1 == generate_fulloutput_filename(ext_conf, state, l->data->key, conf->tmpl_output_filename)) {
+				M_DEBUG1(ext_conf->debug_level, M_DEBUG_SECTION_PARSING, M_DEBUG_LEVEL_ERRORS,
+					 "no filename for output: %s\n",
+					 l->data->key);
+
+				return -1;
+			}
+
+			if ((fd = open(conf->tmpl_output_filename->ptr, O_WRONLY | O_CREAT | O_TRUNC, 0644)) < 0) {
+				M_DEBUG2(ext_conf->debug_level, M_DEBUG_SECTION_PARSING, M_DEBUG_LEVEL_ERRORS,
+					 "opening '%s' failed: %s\n",
+					 conf->tmpl_output_filename->ptr, strerror(errno));
+
+				return -1;
+			}
+			
+			write(fd, conf->tmp_output->ptr, conf->tmp_output->used - 1);
+			
+			close(fd);
+		}
+		MTIMER_STOP(timer[8]);
+		MTIMER_CALC(timer[8]);
+	}
 
 	MTIMER_STOP(timer[4]);
 	MTIMER_CALC(timer[4]);
@@ -941,7 +1155,6 @@ static int generate_history_output(mconfig *ext_conf, mlist *history) {
 	tmpl_main * tmpl;
 	char *fn;
 	int ret;
-	char *s;
 	int i;
 
 	char buf[255];
