@@ -22,11 +22,11 @@
     Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA
 
 **
-** $Id: pic_lines.c,v 1.4 2002/10/23 15:05:37 le_zas Exp $
+** $Id: pic_lines.c,v 1.5 2004/08/27 18:41:38 ostborn Exp $
 */
 #include <stdio.h>
 #include <stdlib.h>
-
+#include <string.h>
 #include <math.h>
 
 #include "config.h"
@@ -155,8 +155,8 @@ int create_lines(mconfig *ext_conf, mgraph *graph) {
 		}
 
 		y1 += strlen(graph->pairs[i]->name) * IM_FONT_WIDTH;
-		gdImageStringUp(im, gdFontSmall, x1+1, y1+1, graph->pairs[i]->name, col_border_sh);
-		gdImageStringUp(im, gdFontSmall, x1, y1, graph->pairs[i]->name, colors[i]);
+		gdImageStringUp(im, gdFontSmall, x1+1, y1+1, (char *)graph->pairs[i]->name, col_border_sh);
+		gdImageStringUp(im, gdFontSmall, x1, y1, (char *)graph->pairs[i]->name, colors[i]);
 	}
 
 /* header */
