@@ -22,7 +22,7 @@
     Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA
 
 **
-** $Id: plugin_config.c,v 1.40 2003/08/01 01:25:50 ostborn Exp $
+** $Id: plugin_config.c,v 1.43 2004/08/27 18:41:38 ostborn Exp $
 */
 
 #include <libintl.h>
@@ -194,6 +194,7 @@ int mplugins_output_template_parse_config(mconfig *ext_conf, const char *filenam
 
 		/* integer */
 		{"show_available_reports_and_die", M_CONFIG_TYPE_INT,	M_CONFIG_VALUE_OVERWRITE, &(conf->show_reports)},
+		{"generate_full_reports", M_CONFIG_TYPE_INT, M_CONFIG_VALUE_OVERWRITE, &(conf->generate_full_reports)},
 
 		/* string lists */
 		{"variable", M_CONFIG_TYPE_STRING_LIST, M_CONFIG_VALUE_APPEND, &(conf->variables)},
@@ -201,7 +202,6 @@ int mplugins_output_template_parse_config(mconfig *ext_conf, const char *filenam
 		{"menuentry", M_CONFIG_TYPE_STRING_LIST, M_CONFIG_VALUE_APPEND, &(conf->menuentry)},
 		{"menutitle", M_CONFIG_TYPE_STRING_LIST, M_CONFIG_VALUE_APPEND, &(conf->menutitle)},
 
-
 		{NULL, M_CONFIG_TYPE_INT, 0, NULL}
 	};
 
@@ -281,9 +281,10 @@ int prepare_menu_structure(mconfig *ext_conf, tmpl_reports *reports) {
 		if (mtree_is_empty(menu)) {
 			/* first element */
 			mdata *data;
+			char *key = splaytree_insert(ext_conf->strings, parent);
 			
 			/* name -- title */
-			data = mdata_String_create(parent, get_menu_title(ext_conf, reports, parent) /* title */ );
+			data = mdata_String_create(key, get_menu_title(ext_conf, reports, parent) /* title */ );
 
 			menu->data = data;
 		}
@@ -291,12 +292,13 @@ int prepare_menu_structure(mconfig *ext_conf, tmpl_reports *reports) {
 		if ((t = mtree_search(menu, parent))) {
 			mdata * data;
 			mtree * cd;
+			char *key = splaytree_insert(ext_conf->strings, child);
 
 			cd = mtree_init();
 
 			/* retreive the menutitle */
 
-			data = mdata_String_create(child, get_menu_title(ext_conf, reports, child) /* title */ );
+			data = mdata_String_create(key, get_menu_title(ext_conf, reports, child) /* title */ );
 			cd->data = data;
 
 			mtree_add_child(t, cd);
@@ -536,10 +538,13 @@ int mplugins_output_template_patch_config(mconfig *ext_conf) {
 		for (l = orig_conf->variables; l && l->data; l = l->next) {
 			mdata * data;
 			char *s;
+			char *key;
 			
 			s = mconfig_get_value(ext_conf, l->data->key);
 
-			data = mdata_Count_create(s, 1, M_DATA_STATE_PLAIN);
+			key = splaytree_insert(ext_conf->strings, s);
+			
+			data = mdata_Count_create(key, 1, M_DATA_STATE_PLAIN);
 			mlist_insert(conf->variables, data);
 
 			free(s);
