@@ -22,7 +22,7 @@
     Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA
 
 **
-** $Id: template.c,v 1.24 2003/08/01 01:28:27 ostborn Exp $
+** $Id: template.c,v 1.25 2004/03/18 02:27:09 ostborn Exp $
 */
 
 #include <libintl.h>
@@ -74,7 +74,7 @@ int tmpl_get_line_from_string (tmpl_string *conf) {
 
 	if (*(s + i) == '\n') i++;
 	
-	buffer_strcpy_len(conf->buffer, s, i);
+	buffer_copy_string_len(conf->buffer, s, i);
 
 	conf->str_pos += i;
 
@@ -224,7 +224,7 @@ int tmpl_current_block_append(tmpl_main *tmpl, const char *s) {
 	for (i = 0; i < tmpl->tmpl_blocks_pos; i++) {
 		if (0 == strcmp(tmpl->tmpl_blocks[i]->name, block)) {
 			
-			buffer_strcat(tmpl->tmpl_blocks[i]->value, s);
+			buffer_append_string(tmpl->tmpl_blocks[i]->value, s);
 			
 			break;
 		}
@@ -234,7 +234,7 @@ int tmpl_current_block_append(tmpl_main *tmpl, const char *s) {
 	if (i == tmpl->tmpl_blocks_pos) {
 		tmpl->tmpl_blocks[i]->name = strdup(block);
 		
-		buffer_strcpy(tmpl->tmpl_blocks[i]->value, s);
+		buffer_copy_string(tmpl->tmpl_blocks[i]->value, s);
 		
 		tmpl->tmpl_blocks_pos++;
 	}
@@ -712,7 +712,7 @@ int tmpl_replace_block(tmpl_main *tmpl, const char *block, buffer *replaced_bloc
 
 			/* before the { */
 			
-			buffer_strcat_len(str, start, open - start);
+			buffer_append_string_len(str, start, open - start);
 
 			/* find the key and substitute it */
 			for (i = 0; i < tmpl->tmpl_keys_pos; i++) {
@@ -721,9 +721,9 @@ int tmpl_replace_block(tmpl_main *tmpl, const char *block, buffer *replaced_bloc
 					fprintf(stderr, "%s.%d: %s, %s\n", __FILE__, __LINE__, tmpl->tmpl_keys[i]->name, tmpl->tmpl_keys[i]->value->ptr);
 #endif
 					if (tmpl->tmpl_keys[i]->value->used) {
-						buffer_strcat(str, tmpl->tmpl_keys[i]->value->ptr);
+						buffer_append_string(str, tmpl->tmpl_keys[i]->value->ptr);
 					} else if (tmpl->tmpl_keys[i]->defvalue) {
-						buffer_strcat(str, tmpl->tmpl_keys[i]->defvalue);
+						buffer_append_string(str, tmpl->tmpl_keys[i]->defvalue);
 					} else {
 #if 0
 						fprintf(stdout, "%s.%d: %s - no value\n",
@@ -740,7 +740,7 @@ int tmpl_replace_block(tmpl_main *tmpl, const char *block, buffer *replaced_bloc
 					
 				b = buffer_init();
 				
-				buffer_strcpy_len(b, open + 1, close - open - 1);
+				buffer_copy_string_len(b, open + 1, close - open - 1);
 				/* ok, we have to extract the key for fprintf */
 				M_DEBUG2(tmpl->debug_level, M_DEBUG_SECTION_PARSING, M_DEBUG_LEVEL_WARNINGS,
 					 "key '%s' not found in block '%s'\n",
@@ -753,7 +753,7 @@ int tmpl_replace_block(tmpl_main *tmpl, const char *block, buffer *replaced_bloc
 		}
 		
 		/* copy the rest to the end of the string */
-		buffer_strcat(str, start);
+		buffer_append_string(str, start);
 	}
 #ifdef MTIMER_ENABLED
 	MTIMER_STOP(timer);
@@ -794,7 +794,7 @@ int tmpl_set_var (tmpl_main *tmpl, const char *key, const char *value) {
 
 	for (i = 0; i < tmpl->tmpl_keys_pos; i++) {
 		if (0 == strcmp(tmpl->tmpl_keys[i]->name, key)) {
-			buffer_strcpy(tmpl->tmpl_keys[i]->value, value);
+			buffer_copy_string(tmpl->tmpl_keys[i]->value, value);
 			
 			break;
 		}
@@ -839,7 +839,7 @@ int tmpl_append_var (tmpl_main *tmpl, const char *key, const char *value) {
 	/* append the value to the specified variable */
 	for (i = 0; i < tmpl->tmpl_keys_pos; i++) {
 		if (0 == strcmp(tmpl->tmpl_keys[i]->name, key)) {
-			buffer_strcat(tmpl->tmpl_keys[i]->value, value);
+			buffer_append_string(tmpl->tmpl_keys[i]->value, value);
 			
 			break;
 		}
