@@ -22,7 +22,7 @@
     Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA
 
 **
-** $Id: template.h,v 1.9 2003/04/18 18:43:49 ostborn Exp $
+** $Id: template.h,v 1.11 2003/08/01 01:28:27 ostborn Exp $
 */
 #ifndef _TEMPLATE_H_
 #define _TEMPLATE_H_
@@ -44,25 +44,18 @@ typedef struct {
 	const char *string;
 	int str_pos;
 
-	char *buffer;
-	int buf_len;
+	buffer *buffer;
 } tmpl_string;
 
 typedef struct {
 	char *name;
-	char *value;
+	buffer *value;
 	char *defvalue;
-	
-	int value_size;
-	int value_used;
 } tmpl_key;
 
 typedef struct {
 	char *name;
-	char *value;
-	
-	int value_size;
-	int value_used;
+	buffer *value;
 } tmpl_block;
 
 typedef struct {
@@ -79,6 +72,7 @@ typedef struct {
 	char *tmpl_current_block;
 	
 	pcre *match_tag_block;
+	pcre *match_vars;
 	
 	buffer *tmp_buf;
 
