@@ -201,7 +201,7 @@ int show_mhash_web (mconfig *ext_conf, mstate *state, tmpl_main *tmpl, mhash *h,
 		md = mhash_sorted_to_marray(h, M_SORTBY_COUNT, M_SORTDIR_DESC);
 	}
 
-	for (i = 0; md[i] && (i < count); i++) {
+	for (i = 0; md[i] && (count < 0 || i < count); i++) {
 		mdata *data = md[i];
 
 		line_type = CT_LEFTLINE; /* start with left, linetype */
@@ -590,7 +590,7 @@ int show_status_mhash (mconfig *ext_conf, tmpl_main *tmpl, mhash *h, int count)
 	return 0;
 }
 
-mhash *get_entry_pages(mhash *h, mstate *state) {
+mhash *get_entry_pages(mconfig *ext_conf, mhash *h, mstate *state) {
 	mhash *ret;
 	int i;
 
@@ -613,8 +613,9 @@ mhash *get_entry_pages(mhash *h, mstate *state) {
 			if (sl && sl->data) {
 				mdata *sld = sl->data;
 				mdata *insd;
+				const char *key = splaytree_insert(ext_conf->strings, mdata_get_key(sld, state));
 				
-				insd = mdata_Count_create(mdata_get_key(sld, state), 1, M_DATA_STATE_PLAIN);
+				insd = mdata_Count_create(key, 1, M_DATA_STATE_PLAIN);
 				mhash_insert_sorted(ret, insd);
 			}
 		}
@@ -623,7 +624,7 @@ mhash *get_entry_pages(mhash *h, mstate *state) {
 	return ret;
 }
 
-mhash *get_exit_pages(mhash *h, mstate *state) {
+mhash *get_exit_pages(mconfig *ext_conf, mhash *h, mstate *state) {
 	mhash *ret;
 	int i;
 
@@ -644,8 +645,9 @@ mhash *get_exit_pages(mhash *h, mstate *state) {
 				if (sl->data) {
 					mdata *sld = sl->data;
 					mdata *insd;
+					const char *key = splaytree_insert(ext_conf->strings, mdata_get_key(sld, state));
 					
-					insd = mdata_Count_create(mdata_get_key(sld, state), 1, M_DATA_STATE_PLAIN);
+					insd = mdata_Count_create(key, 1, M_DATA_STATE_PLAIN);
 					mhash_insert_sorted(ret, insd);
 				}
 			}
@@ -655,7 +657,7 @@ mhash *get_exit_pages(mhash *h, mstate *state) {
 	return ret;
 }
 
-mhash *get_visit_path_length(mhash *h) {
+mhash *get_visit_path_length(mconfig *ext_conf, mhash *h) {
 	mhash *ret;
 	int i;
 
@@ -675,12 +677,15 @@ mhash *get_visit_path_length(mhash *h) {
 				long c = 0;
 				char str[255];
 				mdata *insd;
+				const char *key;
 				
 				for (; sl; c++, sl = sl->next);
 				
 				snprintf(str, 255, "%5ld", c);
+				
+				key = splaytree_insert(ext_conf->strings, str);
 
-				insd = mdata_Count_create(str, l->data->data.sublist.count, M_DATA_STATE_PLAIN);
+				insd = mdata_Count_create(key, l->data->data.sublist.count, M_DATA_STATE_PLAIN);
 				mhash_insert_sorted(ret, insd);
 			}
 		}
@@ -689,7 +694,7 @@ mhash *get_visit_path_length(mhash *h) {
 	return ret;
 }
 
-mhash *get_visit_duration(mhash *h, mstate *state) {
+mhash *get_visit_duration(mconfig *ext_conf, mhash *h, mstate *state) {
 	mhash *ret;
 	int i;
 
@@ -711,6 +716,7 @@ mhash *get_visit_duration(mhash *h, mstate *state) {
 				time_t t1, t2;
 				char str[255];
 				mdata *insd;
+				const char *key;
 
 				/* HARD breackpoint */
 				if (sl->data->type != M_DATA_TYPE_BROKENLINK) {
@@ -755,8 +761,10 @@ mhash *get_visit_duration(mhash *h, mstate *state) {
 					
 					return NULL;
 				}
+				
+				key = splaytree_insert(ext_conf->strings, str);
 
-				insd = mdata_Count_create(str, l->data->data.sublist.count, M_DATA_STATE_PLAIN);
+				insd = mdata_Count_create(key, l->data->data.sublist.count, M_DATA_STATE_PLAIN);
 				mhash_insert_sorted(ret, insd);
 			}
 		}
@@ -816,7 +824,7 @@ double get_visit_full_duration(mhash *h) {
 	return d;
 }
 
-mhash *get_path_length(mhash *h) {
+mhash *get_path_length(mconfig *ext_conf, mhash *h) {
 	mhash *ret;
 	mlist *l;
 
@@ -834,12 +842,15 @@ mhash *get_path_length(mhash *h) {
 				long c = 0;
 				char str[255];
 				mdata *insd;
+				const char *key;
 				
 				for (; sl; c++, sl = sl->next);
 
 				snprintf(str, 255, "%5ld", c);
+				
+				key = splaytree_insert(ext_conf->strings, str);
 
-				insd = mdata_Count_create(str, l->data->data.sublist.count, M_DATA_STATE_PLAIN);
+				insd = mdata_Count_create(key, l->data->data.sublist.count, M_DATA_STATE_PLAIN);
 				mhash_insert_sorted(ret, insd);
 			}
 		}
@@ -850,7 +861,7 @@ mhash *get_path_length(mhash *h) {
 	return ret;
 }
 
-mhash *get_location_subset(mhash *h, int opt) {
+mhash *get_location_subset(mconfig *ext_conf, mhash *h, int opt) {
 	mhash *ret;
 	int i;
 
@@ -866,7 +877,7 @@ mhash *get_location_subset(mhash *h, int opt) {
 			char md5str[33];
 			MD5_CTX context;
 			unsigned char digest[16];
-			char *r;
+			char *r, *key;
 			int j;
 
 			/* build key */
@@ -918,10 +929,11 @@ mhash *get_location_subset(mhash *h, int opt) {
 			for (j = 0, r = md5str; j < 16; j++, r += 2) {
 				sprintf(r, "%02x", digest[j]);
 			}
-			*r = '\0';	
+			*r = '\0';
 			
+			key = splaytree_insert(ext_conf->strings, md5str);
 				
-			insd = mdata_Location_create(md5str, data->data.location->count, 
+			insd = mdata_Location_create(key, data->data.location->count, 
 						     data->data.location->city,
 						     data->data.location->province,
 						     data->data.location->country,
@@ -949,6 +961,7 @@ const char* M_REPORT_OS                     = "web_user_os";
 const char* M_REPORT_OS_VISITS              = "web_user_os_visits";
 const char* M_REPORT_HOSTS                  = "web_user_host";
 const char* M_REPORT_HOSTS_VISITS           = "web_user_host_visits";
+const char* M_REPORT_HOSTS_TRAFFIC          = "web_user_host_traffic";
 const char* M_REPORT_USERAGENT              = "web_user_useragent";
 const char* M_REPORT_USERAGENT_VISITS       = "web_user_useragent_visits";
 const char* M_REPORT_BOOKMARKS              = "web_user_bookmarks";
@@ -1492,6 +1505,23 @@ const reports_def *get_reports_web (mconfig *ext_conf) {
 				{ NULL, NULL }
 			}
 		},
+		
+		/* 36 */
+		  /* id             title */
+		{ M_REPORT_HOSTS_TRAFFIC, _("Requesting Hosts by Traffic"),
+			/* options */
+			HIGHLIGHT | GROUPING | INDEX | PERCENT | VISITS | VISITS_TRAFFIC | SORT_BY_VCOUNT,
+				0, /* show graph */
+				NULL, /* graph function */
+			{ /* fields */
+				{ _("Hits"), "hits" },
+				{ _("Traffic"), "traffic" },
+				{ "%", "traffic" },
+				{ _("Host"), NULL },
+				{ NULL, NULL },
+				{ NULL, NULL }
+			}
+		},
 
 		{0, NULL, 0, 0, NULL,
 			{
@@ -2081,6 +2111,9 @@ char * generate_web(mconfig * ext_conf, mstate * state, const char *current, int
 	char *fn;
 	mhash *data;
 	cell_type line_type = CT_LINE; /* dummy, better a wrong value as an unknown value */
+	
+	size_t max_count;
+	
 #ifdef MTIMER_ENABLED
 	static mtimer timer;
 
@@ -2130,8 +2163,8 @@ char * generate_web(mconfig * ext_conf, mstate * state, const char *current, int
 	case 2: data = staweb->views; break;
 	case 3: data = staweb->os_hash; break;
 	case 4: data = staweb->host_hash; break;
-	case 5: data = get_entry_pages(staweb->visits, state); break; /* free me */
-	case 6: data = get_exit_pages(staweb->visits, state); break; /* free me */
+	case 5: data = get_entry_pages(ext_conf, staweb->visits, state); break; /* free me */
+	case 6: data = get_exit_pages(ext_conf, staweb->visits, state); break; /* free me */
 	case 7: data = staweb->indexed_pages; break;
 	case 8: data = staweb->ua_hash; break;
 	case 9: data = staweb->req_prot_hash; break;
@@ -2143,8 +2176,8 @@ char * generate_web(mconfig * ext_conf, mstate * state, const char *current, int
 	case 15: data = staweb->searchstring; break;
 	case 16: data = staweb->searchsite; break;
 	case 17: data = staweb->extension; break;
-	case 18: data = get_visit_duration(staweb->visits, state); break; /* free me */
-	case 19: data = get_visit_path_length(staweb->visits); break; /* free me */
+	case 18: data = get_visit_duration(ext_conf, staweb->visits, state); break; /* free me */
+	case 19: data = get_visit_path_length(ext_conf, staweb->visits); break; /* free me */
 	case 20: data = staweb->country_hash; break;
 	case 21: data = staweb->vhost_hash; break;
 	case 22: data = staweb->req_url_hash; break;
@@ -2157,10 +2190,11 @@ char * generate_web(mconfig * ext_conf, mstate * state, const char *current, int
 	case 29: data = staweb->views; break;
 	case 30: data = staweb->users; break;
 	case 31: data = staweb->users; break;
-	case 32: data = get_location_subset(staweb->location, LOCATION_CITY | LOCATION_PROVINCE | LOCATION_COUNTRY); break;
-	case 33: data = get_location_subset(staweb->location, LOCATION_PROVINCE | LOCATION_COUNTRY); break; /* free me */
-	case 34: data = get_location_subset(staweb->location, LOCATION_COUNTRY); break; /* free me */
-	case 35: data = get_location_subset(staweb->location, LOCATION_COUNTRY | LOCATION_PROVIDER); break; /* free me */
+	case 32: data = get_location_subset(ext_conf, staweb->location, LOCATION_CITY | LOCATION_PROVINCE | LOCATION_COUNTRY); break;
+	case 33: data = get_location_subset(ext_conf, staweb->location, LOCATION_PROVINCE | LOCATION_COUNTRY); break; /* free me */
+	case 34: data = get_location_subset(ext_conf, staweb->location, LOCATION_COUNTRY); break; /* free me */
+	case 35: data = get_location_subset(ext_conf, staweb->location, LOCATION_COUNTRY | LOCATION_PROVIDER); break; /* free me */
+	case 36: data = staweb->host_traffic; break;
 	default:
 		M_DEBUG1(ext_conf->debug_level, M_DEBUG_SECTION_PARSING, M_DEBUG_LEVEL_ERRORS,
 			 "report '%s' no found here - what's up ??\n", current);
@@ -2187,7 +2221,10 @@ char * generate_web(mconfig * ext_conf, mstate * state, const char *current, int
 	free(fn);
 
 	/* only create the report if we have data */
-	if (mhash_count(data)) {
+	
+	max_count = mhash_count(data);
+	
+	if (max_count) {
 		if (reports[i].show_graph && reports[i].draw_graph) {
 			char *ref = reports[i].draw_graph(ext_conf, state);
 
@@ -2253,7 +2290,7 @@ char * generate_web(mconfig * ext_conf, mstate * state, const char *current, int
 		/* Generate the FOOTER of the Report
 		   -----------------------------------------------------------------------
 		*/
-		if (max > BOTTOM_THRESHOLD) {
+		if (max_count > BOTTOM_THRESHOLD) {
 
 			line_type = CT_LEFTFOOTER;
 
@@ -2297,8 +2334,23 @@ char * generate_web(mconfig * ext_conf, mstate * state, const char *current, int
 		parse_table_row(tmpl);
 	}
 
-	snprintf(buf, 255,  "%d", w);
+	
 	tmpl_set_var(tmpl, TABLE_TITLE, reports[i].title);
+	if (max > 0) {
+		char *lnk = generate_fulloutput_link(ext_conf, state->year, state->month, current);
+		
+		snprintf(buf, sizeof(buf) - 1,  " (%d / %d)", MIN(max, max_count), max_count);
+		
+		tmpl_append_var(tmpl, TABLE_TITLE, buf);
+		
+		tmpl_append_var(tmpl, TABLE_TITLE, " [<a class=\"hdrlnk\" href=\"");
+		tmpl_append_var(tmpl, TABLE_TITLE, lnk);
+		tmpl_append_var(tmpl, TABLE_TITLE, "\">show full report</a>]");
+		
+		free(lnk);
+	}
+	
+	snprintf(buf, sizeof(buf) - 1,  "%d", w);
 	tmpl_set_var(tmpl, TABLE_COL_SPAN, buf);
 	
 	if (0 == tmpl_replace(tmpl, conf->tmp_buf)) {
