@@ -6,8 +6,8 @@
 #include "generate.h"
 #include "template.h"
 
-mhash *get_visit_path_length(mhash *h);
-mhash *get_visit_duration(mhash *h, mstate *state);
+mhash *get_visit_path_length(mconfig *ext_conf, mhash *h);
+mhash *get_visit_duration(mconfig *ext_conf, mhash *h, mstate *state);
 char * generate_web(mconfig * ext_conf, mstate * state, const char *current, int max);
 int mplugins_output_generate_history_output_web(mconfig *ext_conf, mlist *history, tmpl_main *tmpl);
 
