@@ -2,7 +2,7 @@
 ** Modular Logfile Analyzer
 ** Copyright 2000 Jan Kneschke <jan@kneschke.de>
 **
-** Homepage: http://www.kneschke.de/projekte/modlogan
+** Homepage: http://www.modlogan.org
 **
 
     This program is free software; you can redistribute it and/or modify
@@ -22,7 +22,7 @@
     Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA
 
 **
-** $Id: plugin_config.h,v 1.3 2001/08/28 23:14:26 jk Exp $
+** $Id: plugin_config.h,v 1.5 2002/09/26 13:10:28 ostborn Exp $
 */
 #ifndef _OUTPUT_PLUGIN_CONFIG_H_
 #define _OUTPUT_PLUGIN_CONFIG_H_
@@ -31,8 +31,8 @@
 #include "mlist.h"
 
 typedef struct {
-	
 	char *hostname;
+	char *outputdir;
 } config_output;
 
 int mplugins_output_text_generate_monthly_output(mconfig *ext_conf, mstate *state, const char *subpath);
