@@ -22,7 +22,7 @@
     Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA
 
 **
-** $Id: generate.c,v 1.39 2003/01/06 11:19:21 ostborn Exp $
+** $Id: generate.c,v 1.40 2004/08/27 18:41:38 ostborn Exp $
 */
 
 #include <libintl.h>
@@ -140,7 +140,7 @@ int show_mhash (mconfig *ext_conf, FILE *f, mhash *h, int count, int opt) {
 	return 0;
 }
 
-int mhash_status_unfold_sorted_limited(mhash *h, mlist *l, int count ) {
+int mhash_status_unfold_sorted_limited(mconfig *ext_conf, mhash *h, mlist *l, int count ) {
 	int i, j;
 	mdata *data, *ins_data;
 	char __dummy__[] = "999";
@@ -168,7 +168,8 @@ int mhash_status_unfold_sorted_limited(mhash *h, mlist *l, int count ) {
 
 		if (data) {
 			if (data->type == M_DATA_TYPE_COUNT) {
-				ins_data = mdata_Count_create(data->key, data->data.count.count, M_DATA_STATE_PLAIN);
+				const char *key = splaytree_insert(ext_conf->strings, data->key);
+				ins_data = mdata_Count_create(key, data->data.count.count, M_DATA_STATE_PLAIN);
 
 				mlist_insert(l, ins_data);
 			} else {
@@ -181,7 +182,7 @@ int mhash_status_unfold_sorted_limited(mhash *h, mlist *l, int count ) {
 	return 0;
 }
 
-int show_status_mhash (FILE *f, mhash *h, int count) {
+int show_status_mhash (mconfig *ext_conf, FILE *f, mhash *h, int count) {
 	mlist *l, *first;
 	int i = 0;
 
@@ -189,7 +190,7 @@ int show_status_mhash (FILE *f, mhash *h, int count) {
 
 	first = l = mlist_init();
 
-	mhash_status_unfold_sorted_limited(h, l, count);
+	mhash_status_unfold_sorted_limited(ext_conf, h, l, count);
 
 	while (l && (i++ < count)) {
 		mdata *data = l->data;
@@ -547,7 +548,7 @@ int mplugins_output_webalizer_generate_monthly_output(mconfig *ext_conf, mstate
 			_("Hits"),
 			_("Status Code")
 			);
-		show_status_mhash(f,staweb->status_hash, conf->max_status_codes);
+		show_status_mhash(ext_conf, f,staweb->status_hash, conf->max_status_codes);
 		table_end(f);
 	}
 
