@@ -22,7 +22,7 @@
     Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA
 
 **
-** $Id: process.c,v 1.11 2003/01/06 11:19:53 ostborn Exp $
+** $Id: process.c,v 1.12 2004/08/27 20:06:19 ostborn Exp $
 */
 
 #include <libintl.h>
@@ -220,7 +220,8 @@ int mplugins_processor_mail_insert_record(mconfig *ext_conf, mlist *state_list,
 	recmail = record->ext;
 
 	if (!data) {
-		data = mdata_State_create("",NULL,NULL);
+		const char *key = splaytree_insert(ext_conf->strings, "");
+		data = mdata_State_create(key,NULL,NULL);
 		assert(data);
 		mlist_insert(state_list, data);
 	}
@@ -272,11 +273,13 @@ int mplugins_processor_mail_insert_record(mconfig *ext_conf, mlist *state_list,
 
 					/* set direct email-addr */
 					if ((grouped = group_field(ext_conf, recmail->receipient, M_MAIL_GROUP_RECEIPIENT))) {
-						data = mdata_Visited_create(grouped, 1, M_DATA_STATE_PLAIN, recmail->bytes_out);
+						const char *key = splaytree_insert(ext_conf->strings, grouped);
+						data = mdata_Visited_create(key, 1, M_DATA_STATE_PLAIN, recmail->bytes_out);
 						
 						free(grouped);
 					} else {
-						data = mdata_Visited_create(recmail->receipient, 1, M_DATA_STATE_PLAIN, recmail->bytes_out);
+						const char *key = splaytree_insert(ext_conf->strings, recmail->receipient);
+						data = mdata_Visited_create(key, 1, M_DATA_STATE_PLAIN, recmail->bytes_out);
 					}
 					mhash_insert_sorted(stamail->receipient, data);
 
@@ -284,11 +287,13 @@ int mplugins_processor_mail_insert_record(mconfig *ext_conf, mlist *state_list,
 					if ((domain = strchr(recmail->receipient, '@')) != NULL) {
 						domain++;
 						if ((grouped = group_field(ext_conf, domain, M_MAIL_GROUP_DOMAIN))) {
-							data = mdata_Visited_create(grouped, 1, M_DATA_STATE_PLAIN, recmail->bytes_out);
+							const char *key = splaytree_insert(ext_conf->strings, grouped);
+							data = mdata_Visited_create(key, 1, M_DATA_STATE_PLAIN, recmail->bytes_out);
 							
 							free(grouped);
 						} else {
-							data = mdata_Visited_create(domain, 1, M_DATA_STATE_PLAIN, recmail->bytes_out);
+							const char *key = splaytree_insert(ext_conf->strings, domain);
+							data = mdata_Visited_create(key, 1, M_DATA_STATE_PLAIN, recmail->bytes_out);
 						}
 						mhash_insert_sorted(stamail->recp_domain, data);
 					}
@@ -303,10 +308,12 @@ int mplugins_processor_mail_insert_record(mconfig *ext_conf, mlist *state_list,
 				if (recmail->sender && !hide_field(ext_conf, recmail->sender, M_MAIL_HIDE_SENDER)) {
 					char *grouped, *domain;
 					if ((grouped = group_field(ext_conf, recmail->sender, M_MAIL_GROUP_SENDER))) {
-						data = mdata_Visited_create(grouped, 1, M_DATA_STATE_PLAIN, recmail->bytes_in);
+						const char *key = splaytree_insert(ext_conf->strings, grouped);
+						data = mdata_Visited_create(key, 1, M_DATA_STATE_PLAIN, recmail->bytes_in);
 						free(grouped);
 					} else {
-						data = mdata_Visited_create(recmail->sender, 1, M_DATA_STATE_PLAIN, recmail->bytes_in);
+						const char *key = splaytree_insert(ext_conf->strings, recmail->sender);
+						data = mdata_Visited_create(key, 1, M_DATA_STATE_PLAIN, recmail->bytes_in);
 					}
 					mhash_insert_sorted(stamail->sender, data);
 
@@ -314,10 +321,12 @@ int mplugins_processor_mail_insert_record(mconfig *ext_conf, mlist *state_list,
 					if ((domain = strchr(recmail->sender, '@')) != NULL) {
 						domain++;
 						if ((grouped = group_field(ext_conf, domain, M_MAIL_GROUP_DOMAIN))) {
-							data = mdata_Visited_create(grouped, 1, M_DATA_STATE_PLAIN, recmail->bytes_in);
+							const char *key = splaytree_insert(ext_conf->strings, grouped);
+							data = mdata_Visited_create(key, 1, M_DATA_STATE_PLAIN, recmail->bytes_in);
 							free(grouped);
 						} else {
-							data = mdata_Visited_create(domain, 1, M_DATA_STATE_PLAIN, recmail->bytes_in);
+							const char *key = splaytree_insert(ext_conf->strings, domain);
+							data = mdata_Visited_create(key, 1, M_DATA_STATE_PLAIN, recmail->bytes_in);
 						}
 						mhash_insert_sorted(stamail->send_domain, data);
 					}
@@ -346,15 +355,18 @@ int mplugins_processor_mail_insert_record(mconfig *ext_conf, mlist *state_list,
 	if (recmail->ext_type == M_RECORD_TYPE_MAIL_VIRUS) {
 		mlogrec_mail_virus *recvirus = recmail->ext;
 		if (recvirus->virus) {
-			data = mdata_Count_create(recvirus->virus, 1, M_DATA_STATE_PLAIN);
+			const char *key = splaytree_insert(ext_conf->strings, recvirus->virus);
+			data = mdata_Count_create(key, 1, M_DATA_STATE_PLAIN);
 			mhash_insert_sorted(stamail->virus, data);
 		}
 		if (recvirus->subject) {
-			data = mdata_Count_create(recvirus->subject, 1, M_DATA_STATE_PLAIN);
+			const char *key = splaytree_insert(ext_conf->strings, recvirus->subject);
+			data = mdata_Count_create(key, 1, M_DATA_STATE_PLAIN);
 			mhash_insert_sorted(stamail->subject, data);
 		}
 		if (recvirus->scanner) {
-			data = mdata_Count_create(recvirus->scanner, 1, M_DATA_STATE_PLAIN);
+			const char *key = splaytree_insert(ext_conf->strings, recvirus->scanner);
+			data = mdata_Count_create(key, 1, M_DATA_STATE_PLAIN);
 			mhash_insert_sorted(stamail->scanner, data);
 		}
 	}
