@@ -22,7 +22,7 @@
     Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA
 
 **
-** $Id: process.c,v 1.12 2002/10/23 15:05:40 le_zas Exp $
+** $Id: process.c,v 1.13 2004/08/27 20:06:18 ostborn Exp $
 */
 
 #include <libintl.h>
@@ -57,7 +57,8 @@ int mplugins_processor_insert_record(mconfig *ext_conf, mlist *state_list, mlogr
 	mstate *state = NULL;
 
 	if (!data) {
-		data = mdata_State_create("",NULL,NULL);
+		const char *key = splaytree_insert(ext_conf->strings, "");
+		data = mdata_State_create(key,NULL,NULL);
 		mlist_insert(state_list, data);
 	}
 
@@ -109,12 +110,14 @@ int mplugins_processor_insert_record(mconfig *ext_conf, mlist *state_list, mlogr
 	}
 
 	if (rectel->called_number) {
-		data = mdata_Count_create(rectel->called_number, 1, M_DATA_STATE_PLAIN);
+		const char *key = splaytree_insert(ext_conf->strings, rectel->called_number);
+		data = mdata_Count_create(key, 1, M_DATA_STATE_PLAIN);
 		mhash_insert_sorted(statel->called_numbers, data);
 	}
 
 	if (rectel->calling_number) {
-		data = mdata_Count_create(rectel->calling_number, 1, M_DATA_STATE_PLAIN);
+		const char *key = splaytree_insert(ext_conf->strings, rectel->calling_number);
+		data = mdata_Count_create(key, 1, M_DATA_STATE_PLAIN);
 		mhash_insert_sorted(statel->calling_numbers, data);
 	}
 
