@@ -22,13 +22,14 @@
     Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA
 
 **
-** $Id: plugin_config.h,v 1.26 2003/04/18 18:45:05 ostborn Exp $
+** $Id: plugin_config.h,v 1.27 2004/03/18 02:28:58 ostborn Exp $
 */
 #ifndef _PROCESSOR_PLUGIN_CONFIG_H_
 #define _PROCESSOR_PLUGIN_CONFIG_H_
 
 #include <stdio.h>
 #include <pcre.h>
+#include <time.h>
 
 #include "buffer.h"
 #include "mlist.h"
@@ -38,14 +39,14 @@
 #endif
 
 typedef struct {
-	char *key;
-	void *value;
-	long long tstmp;
+	buffer *key;
+	buffer *value;
+	time_t tstmp;
 } m_cache_entry;
 
 typedef struct {
 	m_cache_entry **entry;
-	long long last_tstmp;
+	time_t last_tstmp;
 } m_cache;
 
 typedef struct {
