@@ -22,7 +22,7 @@
     Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA
 
 **
-** $Id: process.c,v 1.70 2003/07/18 11:41:39 ostborn Exp $
+** $Id: process.c,v 1.73 2004/08/27 20:06:17 ostborn Exp $
 */
 
 #include <libintl.h>
@@ -402,7 +402,7 @@ int is_grouped (mconfig *ext_conf, buffer *grouped, mlist *l, const char *str) {
 	}
 	
 	if (r) {
-		buffer_strcpy(grouped, r);
+		buffer_copy_string(grouped, r);
 		free(r);
 		return 1;
 	} else {
@@ -518,9 +518,11 @@ int insert_view_to_views(mconfig *ext_conf, mstate *state, time_t last_timestamp
 			}
 
 			if (is_grouped_field(ext_conf, conf->grouped, last_url, M_WEB_GROUP_REQ_URL)) {
-				data = mdata_Visited_create(conf->grouped->ptr, duration, M_DATA_STATE_GROUPED, is_hit ? 1 : 0);
+				const char *key = splaytree_insert(ext_conf->strings, conf->grouped->ptr);
+				data = mdata_Visited_create(key, duration, M_DATA_STATE_GROUPED, is_hit ? 1 : 0);
 			} else {
-				data = mdata_Visited_create(last_url, duration, M_DATA_STATE_PLAIN, is_hit ? 1 : 0);
+				const char *key = splaytree_insert(ext_conf->strings, last_url);
+				data = mdata_Visited_create(key, duration, M_DATA_STATE_PLAIN, is_hit ? 1 : 0);
 			}
 			mhash_insert_sorted(staweb->views, data);
 		}
@@ -545,14 +547,15 @@ int append_hit_to_visit(mconfig *ext_conf, mstate *state, mlogrec *record, mdata
 	if (recweb->ext_type == M_RECORD_TYPE_WEB_EXTCLF) {
 		recext = recweb->ext;
 	}
-
+	
 	/* set last visited page */
 	if (!hide_field(ext_conf,recweb->req_url->ptr, M_WEB_HIDE_REQ_URL)) {
 		if (visit->data.visit->type == M_DATA_VISIT_ROBOT) {
 			mdata *data;
+			const char *key = splaytree_insert(ext_conf->strings, recweb->req_url->ptr);
 			/* add the page the index pages */
 
-			data = mdata_Count_create(recweb->req_url->ptr, 1, M_DATA_STATE_PLAIN);
+			data = mdata_Count_create(key, 1, M_DATA_STATE_PLAIN);
 			mhash_insert_sorted(staweb->indexed_pages, data);
 		}
 
@@ -560,8 +563,10 @@ int append_hit_to_visit(mconfig *ext_conf, mstate *state, mlogrec *record, mdata
 		    visit->data.visit->count < conf->max_hits_per_visit) {
 			mdata * hit;
 			/* add the hits to the list of pages for this visit */
+			const char *key = splaytree_insert(ext_conf->strings, recweb->req_url->ptr);
+			const char *ref = splaytree_insert(ext_conf->strings, "");
 			
-			hit = mdata_BrokenLink_create(recweb->req_url->ptr, 1, M_DATA_STATE_PLAIN, record->timestamp, NULL);
+			hit = mdata_BrokenLink_create(key, 1, M_DATA_STATE_PLAIN, record->timestamp, ref);
 			mlist_append(visit->data.visit->hits, hit);
 
 			/* using the count value as the number of elements in data.visit->hits */
@@ -578,11 +583,19 @@ int append_hit_to_visit(mconfig *ext_conf, mstate *state, mlogrec *record, mdata
 
 int cleanup_visits(mconfig *ext_conf, mstate *state, time_t last_timestamp) {
 	config_processor *conf = ext_conf->plugin_conf;
-	mstate_web *staweb = state->ext;
-	mhash *h = staweb->visit_hash;
+	mstate_web *staweb;
+	mhash *h;
 	int debug_me = conf->debug_visits;
 	int j;
 	static int vc = 0;
+	
+	if (!state) return -1;
+	
+	staweb = state->ext;
+	
+	if (!staweb) return -1;
+	
+	h = staweb->visit_hash;
 
 	for ( j = 0; j < h->size; j++) {
 		if (h->data[j]->list) {
@@ -606,6 +619,8 @@ int cleanup_visits(mconfig *ext_conf, mstate *state, time_t last_timestamp) {
 					unsigned char digest[16];
 					char *r;
 					
+					const char *key;
+					
 					if (debug_me) {
 						fprintf(stderr, "process.is_visit: <- %20s (%20s), time: %ld - %ld\n",
 							data->key,
@@ -627,7 +642,7 @@ int cleanup_visits(mconfig *ext_conf, mstate *state, time_t last_timestamp) {
 					MD5Init(&context);
 
 					for (act = vlist; act && act->data; act = act->next) {
-						char *key = NULL;
+						const char *key = NULL;
 						
 						key = act->data->key;
 						
@@ -643,8 +658,10 @@ int cleanup_visits(mconfig *ext_conf, mstate *state, time_t last_timestamp) {
 					*r = '\0';
 
 					for (l = vlist; l; l = l->next) vc++;
+					
+					key = splaytree_insert(ext_conf->strings, md5str);
 
-					d = mdata_SubList_create(md5str, vlist);
+					d = mdata_SubList_create(key, vlist);
 					mhash_insert_sorted(staweb->visits, d);
 
 					act = hl;
@@ -730,7 +747,10 @@ int is_visit(mconfig *ext_conf, mstate *state,mlogrec *record) {
 	/* clean up visits every 100 lines */
 
 	if (((lc + 1) % 1000) == 0) {
-		cleanup_visits(ext_conf, state, record->timestamp);
+		if (0 != cleanup_visits(ext_conf, state, record->timestamp)) {
+			M_DEBUG0(ext_conf->debug_level, M_DEBUG_SECTION_PROCESSING, M_DEBUG_LEVEL_ERRORS,
+				 "cleaning up visits failed");
+		}
 	}
 
 	MTIMER_STOP(t[0]);
@@ -766,7 +786,8 @@ int is_visit(mconfig *ext_conf, mstate *state,mlogrec *record) {
 			if (!hide_field(ext_conf,recweb->req_url->ptr, M_WEB_HIDE_REQ_URL)) {
 				int type = is_robot(recweb->req_url);
 				mdata *data;
-
+				const char *key, *ua;
+				
 				MTIMER_START(t[1]);
 
 				visited = 1;
@@ -778,9 +799,12 @@ int is_visit(mconfig *ext_conf, mstate *state,mlogrec *record) {
 						(recext && recext->req_useragent->used) ? recext->req_useragent->ptr : NULL,
 						record->timestamp);
 				}
+				
+				key = splaytree_insert(ext_conf->strings, md5str);
+				ua = splaytree_insert(ext_conf->strings, (recext && recext->req_useragent->used) ? recext->req_useragent->ptr : "");
 
-				data = mdata_Visit_create(md5str,
-							  (recext && recext->req_useragent->used) ? recext->req_useragent->ptr : NULL,
+				data = mdata_Visit_create(key,
+							  ua,
 							  1, record->timestamp,
 							  0, type);
 
@@ -811,6 +835,7 @@ int is_visit(mconfig *ext_conf, mstate *state,mlogrec *record) {
 	} else if (!hide_field(ext_conf, recweb->req_url->ptr, M_WEB_HIDE_REQ_URL)) {
 		int type = is_robot(recweb->req_url);
 		mdata *data;
+		const char *key, *ua;
 
 		MTIMER_START(t[1]);
 
@@ -823,9 +848,12 @@ int is_visit(mconfig *ext_conf, mstate *state,mlogrec *record) {
 				(recext && recext->req_useragent->used) ? recext->req_useragent->ptr : NULL,
 				record->timestamp);
 		}
+		
+		key = splaytree_insert(ext_conf->strings, md5str);
+		ua = splaytree_insert(ext_conf->strings, (recext && recext->req_useragent->used) ? recext->req_useragent->ptr : "");
 
-		data = mdata_Visit_create(md5str,
-					  (recext && recext->req_useragent->used) ? recext->req_useragent->ptr : NULL,
+		data = mdata_Visit_create(key,
+					  ua,
 					  1, record->timestamp,
 					  0, type);
 
@@ -869,9 +897,9 @@ int process_searchengine(mconfig *ext_conf, mstate *state, mlogrec_web_extclf *r
 
 	full = buffer_init();
 	buffer_prepare_copy(full, record->ref_url->used + record->ref_getvars->used + 1);
-	buffer_strcpy_len(full, record->ref_url->ptr, record->ref_url->used - 1);
-	buffer_strcat_len(full, "?", 1);
-	buffer_strcat_len(full, record->ref_getvars->ptr, record->ref_getvars->used - 1);
+	buffer_copy_string_buffer(full, record->ref_url);
+	BUFFER_APPEND_STRING_CONST(full, "?");
+	buffer_append_string_buffer(full, record->ref_getvars);
 
 	if (ignore_field(ext_conf, full, M_WEB_IGNORE_SEARCHENGINE)) {
 		buffer_free(full);
@@ -910,13 +938,15 @@ int process_searchengine(mconfig *ext_conf, mstate *state, mlogrec_web_extclf *r
 
 			if ((is_grouped_field(ext_conf, conf->grouped, searchstring, M_WEB_GROUP_SEARCHSTRING))) {
 				mdata * mdata;
+				const char *key = splaytree_insert(ext_conf->strings, conf->grouped->ptr);
 
-				mdata = mdata_Count_create(conf->grouped->ptr, 1, M_DATA_STATE_GROUPED);
+				mdata = mdata_Count_create(key, 1, M_DATA_STATE_GROUPED);
 				mhash_insert_sorted(staweb->searchstring, mdata);
 			} else {
 				mdata * mdata;
+				const char *key = splaytree_insert(ext_conf->strings, searchstring);
 
-				mdata = mdata_Count_create(searchstring, 1, M_DATA_STATE_PLAIN);
+				mdata = mdata_Count_create(key, 1, M_DATA_STATE_PLAIN);
 				mhash_insert_sorted(staweb->searchstring, mdata);
 			}
 
@@ -925,13 +955,15 @@ int process_searchengine(mconfig *ext_conf, mstate *state, mlogrec_web_extclf *r
 			/* get searchengine */
 			if ((is_grouped_field(ext_conf, conf->grouped, full->ptr, M_WEB_GROUP_SEARCHENGINE))) {
 				mdata * mdata;
+				const char *key = splaytree_insert(ext_conf->strings, conf->grouped->ptr);
 
-				mdata = mdata_Count_create(conf->grouped->ptr, 1, M_DATA_STATE_GROUPED);
+				mdata = mdata_Count_create(key, 1, M_DATA_STATE_GROUPED);
 				mhash_insert_sorted(staweb->searchsite, mdata);
 			} else {
 				mdata * mdata;
+				const char *key = splaytree_insert(ext_conf->strings, record->ref_url->ptr);
 
-				mdata = mdata_Count_create(record->ref_url->ptr, 1, M_DATA_STATE_PLAIN);
+				mdata = mdata_Count_create(key, 1, M_DATA_STATE_PLAIN);
 				mhash_insert_sorted(staweb->searchsite, mdata);
 				
 				if (conf->log_ungrouped_FILE) {
@@ -956,12 +988,12 @@ int process_searchengine(mconfig *ext_conf, mstate *state, mlogrec_web_extclf *r
  * http://WWW.KDE.ORG/aBc -> http://www.kde.org/aBc
  */
 
-char *urltolower(char *str) {
-	char *s = str, *c;
+char *urltolower(buffer *str) {
+	char *s = str->ptr, *c;
 
-	if (!str) return NULL;
+	if (!str->used) return NULL;
 
-	if (NULL != (c = strstr(str, "://"))) {
+	if (NULL != (c = strstr(str->ptr, "://"))) {
 		/* transform protocoll */
 		for (;*s && *s != '/'; s++) {
 			*s = tolower(*s);
@@ -976,7 +1008,7 @@ char *urltolower(char *str) {
 		*s = tolower(*s);
 	}
 
-	return str;
+	return s;
 }
 
 mstate *splitter(mconfig *ext_conf, mlist *state_list, mlogrec *record) {
@@ -1092,7 +1124,10 @@ mstate *splitter(mconfig *ext_conf, mlist *state_list, mlogrec *record) {
 		}
 
 		if (!state) {
-			mdata *data = mdata_State_create(name, NULL, NULL);
+			const char *key = splaytree_insert(ext_conf->strings, name);
+			mdata *data;
+			
+			data = mdata_State_create(key, NULL, NULL);
 			mlist_insert_sorted(state_list, data);
 
 			state = data->data.state.state;
@@ -1169,10 +1204,10 @@ int mplugins_processor_web_insert_record(mconfig *ext_conf, mlist *state_list, m
 
 	MTIMER_START(t[0]);
 
-	if (recweb->req_url->used) urltolower(recweb->req_url->ptr);
-	if (recweb->req_host_name->used) urltolower(recweb->req_host_name->ptr);
+	urltolower(recweb->req_url);
+	urltolower(recweb->req_host_name);
 
-	if (recext != NULL && recext->ref_url->used) urltolower(recext->ref_url->ptr);
+	if (recext != NULL) urltolower(recext->ref_url);
 
 /* skip ignored records */
 
@@ -1233,50 +1268,61 @@ int mplugins_processor_web_insert_record(mconfig *ext_conf, mlist *state_list, m
 
 	MTIMER_START(t[2]);
 	if (recweb->req_protocol->used) {
-		data = mdata_Count_create(recweb->req_protocol->ptr, 1, M_DATA_STATE_PLAIN);
+		const char *key = splaytree_insert(ext_conf->strings, recweb->req_protocol->ptr);
+		data = mdata_Count_create(key, 1, M_DATA_STATE_PLAIN);
 		mhash_insert_sorted(staweb->req_prot_hash, data);
 	}
 
 /* User Method for this query (GET, POST, PUT, HEAD, OPTIONS) */
 	if (recweb->req_method->used) {
-		data = mdata_Count_create(recweb->req_method->ptr, 1, M_DATA_STATE_PLAIN);
+		const char *key = splaytree_insert(ext_conf->strings, recweb->req_method->ptr);
+		data = mdata_Count_create(key, 1, M_DATA_STATE_PLAIN);
 		mhash_insert_sorted(staweb->req_meth_hash, data);
 	}
 
 	if (recweb->req_status && recweb->req_url->used) {
 		char buf[4];
+		const char *key;
 
 		sprintf(buf, "%3d", recweb->req_status);
+		
+		key = splaytree_insert(ext_conf->strings, buf);
 
-		data = mdata_Count_create(buf, 1, M_DATA_STATE_PLAIN);
+		data = mdata_Count_create(key, 1, M_DATA_STATE_PLAIN);
 		mhash_insert_sorted(staweb->status_hash, data);
 
 /* FIXME: specific to HTTP */
 		switch (recweb->req_status) {
-			case 404:
-				if (!hide_field(ext_conf, recweb->req_url->ptr, M_WEB_HIDE_BROKENLINK)
-				    && (recext == NULL || recext->ref_url->used == 0 || !hide_field(ext_conf, recext->ref_url->ptr, M_WEB_HIDE_BROKENLINK_REF))) {
-					mdata *link;
-
-					if ((is_grouped_field(ext_conf, conf->grouped, recweb->req_url->ptr, M_WEB_GROUP_BROKENLINK))) {
-						link = mdata_BrokenLink_create(conf->grouped->ptr, 1, M_DATA_STATE_GROUPED, 
-									       record->timestamp, recext != NULL && recext->ref_url->used ? recext->ref_url->ptr : NULL);
-					} else {
-						link = mdata_BrokenLink_create(recweb->req_url->ptr, 1, M_DATA_STATE_PLAIN, 
-									       record->timestamp, recext != NULL && recext->ref_url->used ? recext->ref_url->ptr : NULL);
-					}
-					mhash_insert_sorted(staweb->status_missing_file, link);
-				}
-				break;
-			case 500:
-			{
+		case 404:
+			if (!hide_field(ext_conf, recweb->req_url->ptr, M_WEB_HIDE_BROKENLINK)
+			    && (recext == NULL || recext->ref_url->used == 0 || !hide_field(ext_conf, recext->ref_url->ptr, M_WEB_HIDE_BROKENLINK_REF))) {
 				mdata *link;
 				
-				link = mdata_BrokenLink_create(recweb->req_url->ptr, 1, M_DATA_STATE_PLAIN, 
-							       record->timestamp, recext != NULL && recext->ref_url->used ? recext->ref_url->ptr : NULL);
-				mhash_insert_sorted(staweb->status_internal_error, link);
-				break;
+				if ((is_grouped_field(ext_conf, conf->grouped, recweb->req_url->ptr, M_WEB_GROUP_BROKENLINK))) {
+					const char *key = splaytree_insert(ext_conf->strings, conf->grouped->ptr);
+					const char *ref = splaytree_insert(ext_conf->strings, (recext && recext->ref_url->used) ? recext->ref_url->ptr : "");
+					link = mdata_BrokenLink_create(key, 1, M_DATA_STATE_GROUPED, 
+								       record->timestamp, ref);
+				} else {
+					const char *key = splaytree_insert(ext_conf->strings, recweb->req_url->ptr);
+					const char *ref = splaytree_insert(ext_conf->strings, (recext && recext->ref_url->used) ? recext->ref_url->ptr : "");
+					link = mdata_BrokenLink_create(key, 1, M_DATA_STATE_PLAIN, 
+								       record->timestamp, ref);
+				}
+				mhash_insert_sorted(staweb->status_missing_file, link);
 			}
+			break;
+		case 500: {
+			mdata *link;
+			
+			const char *key = splaytree_insert(ext_conf->strings, recweb->req_url->ptr);
+			const char *ref = splaytree_insert(ext_conf->strings, (recext && recext->ref_url->used) ? recext->ref_url->ptr : "");
+			
+			link = mdata_BrokenLink_create(key, 1, M_DATA_STATE_PLAIN, 
+						       record->timestamp, ref);
+			mhash_insert_sorted(staweb->status_internal_error, link);
+			break;
+		}
 		}
 	}
 
@@ -1296,26 +1342,39 @@ int mplugins_processor_web_insert_record(mconfig *ext_conf, mlist *state_list, m
 		 */
 
 		if (recweb->req_host_name->used) {
-			char *entry;
-			/* check the cache for the hostname */
-			entry = NULL;
-			for (i = 0; i < conf->host_cache_max; i++) {
-				if (conf->host_cache->entry[i]->key && 0 == strcmp(recweb->req_host_name->ptr, conf->host_cache->entry[i]->key)) {
-					entry = conf->host_cache->entry[i]->value;
+			char *entry, *key;
+			
+			/* 
+			 * is_grouped_field() is expensive, caching reduces the problem here
+			 * 
+			 */
+			
+			/* cache decision */
+			for (i = 0, entry = NULL; i < conf->host_cache_max; i++) {
+				if (conf->host_cache->entry[i]->key->used && 
+				    recweb->req_host_name->used == conf->host_cache->entry[i]->key->used &&
+				    0 == strcmp(recweb->req_host_name->ptr, conf->host_cache->entry[i]->key->ptr)) {
+					entry = conf->host_cache->entry[i]->value->ptr;
 					break;
 				}
 			}
 
 			if (entry) {
-				data = mdata_Visited_create(entry, 1, M_DATA_STATE_GROUPED, isvisit);
+				/* hit */
+				const char *key = splaytree_insert(ext_conf->strings, entry);
+				data = mdata_Visited_create(key, 1, M_DATA_STATE_GROUPED, isvisit);
 			} else if ((is_grouped_field(ext_conf, conf->grouped, recweb->req_host_name->ptr, M_WEB_GROUP_HOST))) {
+				/* miss - grouped */
 				int oldest = -1;
-				int oldest_tstmp = conf->host_cache->last_tstmp;
+				time_t oldest_tstmp = conf->host_cache->last_tstmp;
+				const char *key = splaytree_insert(ext_conf->strings, conf->grouped->ptr);
 
-				data = mdata_Visited_create(conf->grouped->ptr, 1, M_DATA_STATE_GROUPED, isvisit);
+				data = mdata_Visited_create(key, 1, M_DATA_STATE_GROUPED, isvisit);
 
 				/* insert into the cache */
 				for (i = 0; i < conf->host_cache_max; i++) {
+					if (0 == conf->host_cache->entry[i]->key->used) continue;
+					
 					if (conf->host_cache->entry[i]->tstmp < oldest_tstmp) {
 						oldest = i;
 						oldest_tstmp = conf->host_cache->entry[i]->tstmp;
@@ -1324,22 +1383,27 @@ int mplugins_processor_web_insert_record(mconfig *ext_conf, mlist *state_list, m
 
 				/* free the oldest entry and insert */
 				if (oldest != -1) {
-					if (conf->host_cache->entry[oldest]->key) free(conf->host_cache->entry[oldest]->key);
-					if (conf->host_cache->entry[oldest]->value) free(conf->host_cache->entry[oldest]->value);
-					conf->host_cache->entry[oldest]->key = strdup(recweb->req_host_name->ptr);
-					conf->host_cache->entry[oldest]->value = strdup(conf->grouped->ptr);
+					buffer_copy_string_buffer(conf->host_cache->entry[oldest]->key, recweb->req_host_name);
+					buffer_copy_string_buffer(conf->host_cache->entry[oldest]->value, conf->grouped);
 					conf->host_cache->entry[oldest]->tstmp = conf->host_cache->last_tstmp++;
 				}
 			} else {
-				data = mdata_Visited_create(recweb->req_host_name->ptr, 1, M_DATA_STATE_PLAIN, isvisit);
+				/* miss - not grouped */
+				const char *key = splaytree_insert(ext_conf->strings, recweb->req_host_name->ptr);
+				data = mdata_Visited_create(key, 1, M_DATA_STATE_PLAIN, isvisit);
 			}
+#if 1
 			mhash_insert_sorted(staweb->host_hash, data);
+#else
+			marray_insert(staweb->host_array, data);
+#endif
 
 			/* splitting the TLD from the FQDN */
 			if ((entry = strrchr(recweb->req_host_name->ptr, '.'))) {
 				if (misoname(entry + 1)) {
-					data = mdata_Visited_create(isondx(entry + 1) != M_RESOLV_UNRESOLVED ?
-								    entry + 1 : UNRESOLVED_TLD,
+					key = splaytree_insert(ext_conf->strings, isondx(entry + 1) != M_RESOLV_UNRESOLVED ? entry + 1 : UNRESOLVED_TLD);
+					
+					data = mdata_Visited_create(key,
 								    1,
 								    M_DATA_STATE_PLAIN,
 								    isvisit);
@@ -1347,45 +1411,49 @@ int mplugins_processor_web_insert_record(mconfig *ext_conf, mlist *state_list, m
 					mhash_insert_sorted(staweb->country_hash, data);
 				}
 			}
+			
+			/* 
+			 * proxies-reports want 
+			 * - traffic by req-host
+			 * 
+			 */
+			key = splaytree_insert(ext_conf->strings, recweb->req_host_name->ptr);
+			data = mdata_Visited_create(key, 1, M_DATA_STATE_PLAIN, recweb->xfersize);
+			mhash_insert_sorted(staweb->host_traffic, data);
 		} else {
 			/* no countries */
-			data = mdata_Visited_create(recweb->req_host_ip->ptr, 1, M_DATA_STATE_PLAIN, isvisit);
-
+			const char *key = splaytree_insert(ext_conf->strings, recweb->req_host_ip->ptr);
+			data = mdata_Visited_create(key, 1, M_DATA_STATE_PLAIN, isvisit);
 			mhash_insert_sorted(staweb->host_hash, data);
+			
+			data = mdata_Visited_create(key, 1, M_DATA_STATE_PLAIN, recweb->xfersize);
+			mhash_insert_sorted(staweb->host_traffic, data);
 		}
 		
 		if (recweb->req_host_ip) {
 #ifdef HAVE_LIBLOCALIZER
 			if (conf->localizer) {
 				long ip = localizer_ip2int(recweb->req_host_ip->ptr);
-				int j;
-				if ((j = localizer_search(conf->localizer, ip)) != -1) {
+				l_data_export ld;
+				
+				if (0 == (localizer_search(conf->localizer, ip, &ld))) {
 					/* md5 */
 					char md5str[33];
 					MD5_CTX context;
 					unsigned char digest[16];
-					char *r;
+					char *r, *key;
 
 					/* build key */
 
 					md5str[0] = '\0';
 					MD5Init(&context);
-
-					MD5Update(&context, 
-						  STRING(conf->localizer, conf->localizer->ndat[j]->city), 
-						  strlen(STRING(conf->localizer, conf->localizer->ndat[j]->city)));
-					
-					MD5Update(&context, 
-						  STRING(conf->localizer, conf->localizer->ndat[j]->province), 
-						  strlen(STRING(conf->localizer, conf->localizer->ndat[j]->province)));
-					
-					MD5Update(&context, 
-						  STRING(conf->localizer, conf->localizer->ndat[j]->country), 
-						  strlen(STRING(conf->localizer, conf->localizer->ndat[j]->country)));
-					
-					MD5Update(&context, 
-						  STRING(conf->localizer, conf->localizer->ndat[j]->provider), 
-						  strlen(STRING(conf->localizer, conf->localizer->ndat[j]->provider)));
+#define M(x) \
+	MD5Update(&context, ld.x, strlen(ld.x));
+					M(city);
+					M(province);
+					M(country);
+					M(provider);
+#undef M
 
 					MD5Final(digest, &context);
 					for (i = 0, r = md5str; i < 16; i++, r += 2) {
@@ -1393,12 +1461,12 @@ int mplugins_processor_web_insert_record(mconfig *ext_conf, mlist *state_list, m
 					}
 					*r = '\0';
 					
-					data = mdata_Location_create(md5str, 1, 
-								     STRING(conf->localizer, conf->localizer->ndat[j]->city),
-								     STRING(conf->localizer, conf->localizer->ndat[j]->province),
-								     STRING(conf->localizer, conf->localizer->ndat[j]->country),
-								     STRING(conf->localizer, conf->localizer->ndat[j]->provider)
-								     );
+					key = splaytree_insert(ext_conf->strings, md5str);
+					data = mdata_Location_create(key, 1, 
+								     ld.city,
+								     ld.province,
+								     ld.country,
+								     ld.provider);
 					
 					mhash_insert_sorted(staweb->location, data);
 				}
@@ -1424,9 +1492,12 @@ int mplugins_processor_web_insert_record(mconfig *ext_conf, mlist *state_list, m
 
 		if ((c1 = strstr(recweb->req_url->ptr, "favicon.ico")) ) {
 			char c2 = *c1;
+			const char *key;
 
 			*c1 = '\0';
-			data = mdata_Count_create(recweb->req_url->ptr, 1, M_DATA_STATE_PLAIN);
+			
+			key = splaytree_insert(ext_conf->strings, recweb->req_url->ptr);
+			data = mdata_Count_create(key, 1, M_DATA_STATE_PLAIN);
 			mhash_insert_sorted(staweb->bookmarks, data);
 			*c1 = c2;
 		} else if (is_robot(recweb->req_url)) {
@@ -1435,7 +1506,8 @@ int mplugins_processor_web_insert_record(mconfig *ext_conf, mlist *state_list, m
 				if (ext_conf->debug_level > 10)
 					fprintf(stderr, "%s requested w/o useragent set - ignored.\n", recweb->req_url->ptr);
 			} else {
-				data = mdata_Count_create(recext->req_useragent->ptr, 1, M_DATA_STATE_PLAIN);
+				const char *key = splaytree_insert(ext_conf->strings, recext->req_useragent->ptr);
+				data = mdata_Count_create(key, 1, M_DATA_STATE_PLAIN);
 				mhash_insert_sorted(staweb->robots, data);
 			}
 		}
@@ -1445,7 +1517,8 @@ int mplugins_processor_web_insert_record(mconfig *ext_conf, mlist *state_list, m
 		    !hide_field(ext_conf, recweb->req_url->ptr, M_WEB_HIDE_EXTENSION)) {
 
 			if ((is_grouped_field(ext_conf, conf->grouped, recweb->req_url->ptr, M_WEB_GROUP_EXTENSION))) {
-				data = mdata_Visited_create(conf->grouped->ptr, 1, M_DATA_STATE_GROUPED, recweb->xfersize);
+				const char *key = splaytree_insert(ext_conf->strings, conf->grouped->ptr);
+				data = mdata_Visited_create(key, 1, M_DATA_STATE_GROUPED, recweb->xfersize);
 				mhash_insert_sorted(staweb->extension, data);
 			} else {
 				if (ext_conf->debug_level > 5)
@@ -1457,9 +1530,11 @@ int mplugins_processor_web_insert_record(mconfig *ext_conf, mlist *state_list, m
 		/* hide url */
 		if (!hide_field(ext_conf, recweb->req_url->ptr, M_WEB_HIDE_REQ_URL)) {
 			if ((is_grouped_field(ext_conf, conf->grouped, recweb->req_url->ptr, M_WEB_GROUP_REQ_URL))) {
-				data = mdata_Visited_create(conf->grouped->ptr, 1, M_DATA_STATE_GROUPED, recweb->xfersize);
+				const char *key = splaytree_insert(ext_conf->strings, conf->grouped->ptr);
+				data = mdata_Visited_create(key, 1, M_DATA_STATE_GROUPED, recweb->xfersize);
 			} else {
-				data = mdata_Visited_create(recweb->req_url->ptr, 1, M_DATA_STATE_PLAIN, recweb->xfersize);
+				const char *key = splaytree_insert(ext_conf->strings, recweb->req_url->ptr);
+				data = mdata_Visited_create(key, 1, M_DATA_STATE_PLAIN, recweb->xfersize);
 			}
 			
 			mhash_insert_sorted(staweb->req_url_hash, data);
@@ -1472,10 +1547,11 @@ int mplugins_processor_web_insert_record(mconfig *ext_conf, mlist *state_list, m
 	/* more traffic-wise reports */
 	if (recweb->req_user->used) {
 		/* handle the users traffic */
-		data = mdata_Visited_create(recweb->req_user->ptr, 1, M_DATA_STATE_PLAIN, recweb->xfersize);
+		const char *key = splaytree_insert(ext_conf->strings, recweb->req_user->ptr);
+		data = mdata_Visited_create(key, 1, M_DATA_STATE_PLAIN, recweb->xfersize);
 		mhash_insert_sorted(staweb->users, data);
 	}
-
+	
 /*
 ** Extensions
 */
@@ -1486,9 +1562,11 @@ int mplugins_processor_web_insert_record(mconfig *ext_conf, mlist *state_list, m
 
 		if (recext->req_useros->used) {
 			if ((is_grouped_field(ext_conf, conf->grouped, recext->req_useros->ptr, M_WEB_GROUP_OS))) {
-				data = mdata_Visited_create(conf->grouped->ptr, 1, M_DATA_STATE_GROUPED, isvisit);
+				const char *key = splaytree_insert(ext_conf->strings, conf->grouped->ptr);
+				data = mdata_Visited_create(key, 1, M_DATA_STATE_GROUPED, isvisit);
 			} else {
-				data = mdata_Visited_create(recext->req_useros->ptr, 1, M_DATA_STATE_PLAIN, isvisit);
+				const char *key = splaytree_insert(ext_conf->strings, recext->req_useros->ptr);
+				data = mdata_Visited_create(key, 1, M_DATA_STATE_PLAIN, isvisit);
 			}
 			mhash_insert_sorted(staweb->os_hash, data);
 		}
@@ -1496,9 +1574,11 @@ int mplugins_processor_web_insert_record(mconfig *ext_conf, mlist *state_list, m
 /* User Agent */
 		if (recext->req_useragent->used) {
 			if ((is_grouped_field(ext_conf, conf->grouped, recext->req_useragent->ptr, M_WEB_GROUP_UA))) {
-				data = mdata_Visited_create(conf->grouped->ptr, 1, M_DATA_STATE_GROUPED, isvisit);
+				const char *key = splaytree_insert(ext_conf->strings, conf->grouped->ptr);
+				data = mdata_Visited_create(key, 1, M_DATA_STATE_GROUPED, isvisit);
 			} else {
-				data = mdata_Visited_create(recext->req_useragent->ptr, 1, M_DATA_STATE_PLAIN, isvisit);
+				const char *key = splaytree_insert(ext_conf->strings, recext->req_useragent->ptr);
+				data = mdata_Visited_create(key, 1, M_DATA_STATE_PLAIN, isvisit);
 			}
 			mhash_insert_sorted(staweb->ua_hash, data);
 		}
@@ -1509,16 +1589,19 @@ int mplugins_processor_web_insert_record(mconfig *ext_conf, mlist *state_list, m
 				process_searchengine(ext_conf, state, recext);
 
 				if ((is_grouped_field(ext_conf, conf->grouped, recext->ref_url->ptr, M_WEB_GROUP_REFERRER))) {
-					data = mdata_Count_create(conf->grouped->ptr, 1, M_DATA_STATE_GROUPED);
+					const char *key = splaytree_insert(ext_conf->strings, conf->grouped->ptr);
+					data = mdata_Count_create(key, 1, M_DATA_STATE_GROUPED);
 				} else {
-					data = mdata_Count_create(recext->ref_url->ptr, 1, M_DATA_STATE_PLAIN);
+					const char *key = splaytree_insert(ext_conf->strings, recext->ref_url->ptr);
+					data = mdata_Count_create(key, 1, M_DATA_STATE_PLAIN);
 				}
 				mhash_insert_sorted(staweb->ref_url_hash, data);
 			}
 		}
 
 		if (recext->srv_host->used) {
-			data = mdata_Visited_create(recext->srv_host->ptr, 1, M_DATA_STATE_PLAIN, isvisit);
+			const char *key = splaytree_insert(ext_conf->strings, recext->srv_host->ptr);
+			data = mdata_Visited_create(key, 1, M_DATA_STATE_PLAIN, isvisit);
 			mhash_insert_sorted(staweb->vhost_hash, data);
 		}
 		
